@@ -49,13 +49,9 @@ impl From<CLK_FANOUT_EN_A> for bool {
     }
 }
 #[doc = "Fields `CLK_FANOUT(0-2)_EN` reader - Gating for CLK_FANOUT"]
-pub struct CLK_FANOUT_EN_R(crate::FieldReader<bool>);
+pub type CLK_FANOUT_EN_R = crate::BitReader<CLK_FANOUT_EN_A>;
 impl CLK_FANOUT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        CLK_FANOUT_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CLK_FANOUT_EN_A {
         match self.bits {
@@ -66,31 +62,18 @@ impl CLK_FANOUT_EN_R {
     #[doc = "Checks if the value of the field is `OFF`"]
     #[inline(always)]
     pub fn is_off(&self) -> bool {
-        **self == CLK_FANOUT_EN_A::OFF
+        *self == CLK_FANOUT_EN_A::OFF
     }
     #[doc = "Checks if the value of the field is `ON`"]
     #[inline(always)]
     pub fn is_on(&self) -> bool {
-        **self == CLK_FANOUT_EN_A::ON
+        *self == CLK_FANOUT_EN_A::ON
     }
 }
-impl core::ops::Deref for CLK_FANOUT_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `CLK_FANOUT(0-2)_EN` const generic writer - Gating for CLK_FANOUT"]
-pub struct CLK_FANOUT_EN_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> CLK_FANOUT_EN_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CLK_FANOUT_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `CLK_FANOUT(0-2)_EN` writer - Gating for CLK_FANOUT"]
+pub type CLK_FANOUT_EN_W<'a, const O: u8> =
+    crate::BitWriter<'a, u32, CCU_FAN_SPEC, CLK_FANOUT_EN_A, O>;
+impl<'a, const O: u8> CLK_FANOUT_EN_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn off(self) -> &'a mut W {
@@ -101,22 +84,6 @@ impl<'a, const O: usize> CLK_FANOUT_EN_W<'a, O> {
     pub fn on(self) -> &'a mut W {
         self.variant(CLK_FANOUT_EN_A::ON)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -144,13 +111,9 @@ impl From<CLK_FANOUT_SEL_A> for u8 {
     }
 }
 #[doc = "Fields `CLK_FANOUT(0-2)_SEL` reader - "]
-pub struct CLK_FANOUT_SEL_R(crate::FieldReader<u8>);
+pub type CLK_FANOUT_SEL_R = crate::FieldReader<u8, CLK_FANOUT_SEL_A>;
 impl CLK_FANOUT_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        CLK_FANOUT_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<CLK_FANOUT_SEL_A> {
         match self.bits {
@@ -167,56 +130,43 @@ impl CLK_FANOUT_SEL_R {
     #[doc = "Checks if the value of the field is `CLK32K`"]
     #[inline(always)]
     pub fn is_clk32k(&self) -> bool {
-        **self == CLK_FANOUT_SEL_A::CLK32K
+        *self == CLK_FANOUT_SEL_A::CLK32K
     }
     #[doc = "Checks if the value of the field is `CLK12M`"]
     #[inline(always)]
     pub fn is_clk12m(&self) -> bool {
-        **self == CLK_FANOUT_SEL_A::CLK12M
+        *self == CLK_FANOUT_SEL_A::CLK12M
     }
     #[doc = "Checks if the value of the field is `CLK16M`"]
     #[inline(always)]
     pub fn is_clk16m(&self) -> bool {
-        **self == CLK_FANOUT_SEL_A::CLK16M
+        *self == CLK_FANOUT_SEL_A::CLK16M
     }
     #[doc = "Checks if the value of the field is `CLK24M`"]
     #[inline(always)]
     pub fn is_clk24m(&self) -> bool {
-        **self == CLK_FANOUT_SEL_A::CLK24M
+        *self == CLK_FANOUT_SEL_A::CLK24M
     }
     #[doc = "Checks if the value of the field is `CLK25M`"]
     #[inline(always)]
     pub fn is_clk25m(&self) -> bool {
-        **self == CLK_FANOUT_SEL_A::CLK25M
+        *self == CLK_FANOUT_SEL_A::CLK25M
     }
     #[doc = "Checks if the value of the field is `CLK27M`"]
     #[inline(always)]
     pub fn is_clk27m(&self) -> bool {
-        **self == CLK_FANOUT_SEL_A::CLK27M
+        *self == CLK_FANOUT_SEL_A::CLK27M
     }
     #[doc = "Checks if the value of the field is `PCLK`"]
     #[inline(always)]
     pub fn is_pclk(&self) -> bool {
-        **self == CLK_FANOUT_SEL_A::PCLK
+        *self == CLK_FANOUT_SEL_A::PCLK
     }
 }
-impl core::ops::Deref for CLK_FANOUT_SEL_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `CLK_FANOUT(0-2)_SEL` const generic writer - "]
-pub struct CLK_FANOUT_SEL_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> CLK_FANOUT_SEL_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CLK_FANOUT_SEL_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
+#[doc = "Fields `CLK_FANOUT(0-2)_SEL` writer - "]
+pub type CLK_FANOUT_SEL_W<'a, const O: u8> =
+    crate::FieldWriter<'a, u32, CCU_FAN_SPEC, u8, CLK_FANOUT_SEL_A, 3, O>;
+impl<'a, const O: u8> CLK_FANOUT_SEL_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn clk32k(self) -> &'a mut W {
@@ -252,17 +202,11 @@ impl<'a, const O: usize> CLK_FANOUT_SEL_W<'a, O> {
     pub fn pclk(self) -> &'a mut W {
         self.variant(CLK_FANOUT_SEL_A::PCLK)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << O)) | ((value as u32 & 7) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "Gating for CLK_FANOUT"]
     #[inline(always)]
-    pub unsafe fn clk_fanout_en(&self, n: usize) -> CLK_FANOUT_EN_R {
+    pub unsafe fn clk_fanout_en(&self, n: u8) -> CLK_FANOUT_EN_R {
         CLK_FANOUT_EN_R::new(((self.bits >> (n + 21)) & 1) != 0)
     }
     #[doc = "Bit 21 - Gating for CLK_FANOUT"]
@@ -282,7 +226,7 @@ impl R {
     }
     #[doc = ""]
     #[inline(always)]
-    pub unsafe fn clk_fanout_sel(&self, n: usize) -> CLK_FANOUT_SEL_R {
+    pub unsafe fn clk_fanout_sel(&self, n: u8) -> CLK_FANOUT_SEL_R {
         CLK_FANOUT_SEL_R::new(((self.bits >> (n * 3)) & 7) as u8)
     }
     #[doc = "Bits 0:2"]
@@ -304,43 +248,43 @@ impl R {
 impl W {
     #[doc = "Gating for CLK_FANOUT"]
     #[inline(always)]
-    pub unsafe fn clk_fanout_en<const O: usize>(&mut self) -> CLK_FANOUT_EN_W<O> {
-        CLK_FANOUT_EN_W { w: self }
+    pub unsafe fn clk_fanout_en<const O: u8>(&mut self) -> CLK_FANOUT_EN_W<O> {
+        CLK_FANOUT_EN_W::new(self)
     }
     #[doc = "Bit 21 - Gating for CLK_FANOUT"]
     #[inline(always)]
     pub fn clk_fanout0_en(&mut self) -> CLK_FANOUT_EN_W<21> {
-        CLK_FANOUT_EN_W { w: self }
+        CLK_FANOUT_EN_W::new(self)
     }
     #[doc = "Bit 22 - Gating for CLK_FANOUT"]
     #[inline(always)]
     pub fn clk_fanout1_en(&mut self) -> CLK_FANOUT_EN_W<22> {
-        CLK_FANOUT_EN_W { w: self }
+        CLK_FANOUT_EN_W::new(self)
     }
     #[doc = "Bit 23 - Gating for CLK_FANOUT"]
     #[inline(always)]
     pub fn clk_fanout2_en(&mut self) -> CLK_FANOUT_EN_W<23> {
-        CLK_FANOUT_EN_W { w: self }
+        CLK_FANOUT_EN_W::new(self)
     }
     #[doc = ""]
     #[inline(always)]
-    pub unsafe fn clk_fanout_sel<const O: usize>(&mut self) -> CLK_FANOUT_SEL_W<O> {
-        CLK_FANOUT_SEL_W { w: self }
+    pub unsafe fn clk_fanout_sel<const O: u8>(&mut self) -> CLK_FANOUT_SEL_W<O> {
+        CLK_FANOUT_SEL_W::new(self)
     }
     #[doc = "Bits 0:2"]
     #[inline(always)]
     pub fn clk_fanout0_sel(&mut self) -> CLK_FANOUT_SEL_W<0> {
-        CLK_FANOUT_SEL_W { w: self }
+        CLK_FANOUT_SEL_W::new(self)
     }
     #[doc = "Bits 3:5"]
     #[inline(always)]
     pub fn clk_fanout1_sel(&mut self) -> CLK_FANOUT_SEL_W<3> {
-        CLK_FANOUT_SEL_W { w: self }
+        CLK_FANOUT_SEL_W::new(self)
     }
     #[doc = "Bits 6:8"]
     #[inline(always)]
     pub fn clk_fanout2_sel(&mut self) -> CLK_FANOUT_SEL_W<6> {
-        CLK_FANOUT_SEL_W { w: self }
+        CLK_FANOUT_SEL_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
