@@ -49,13 +49,9 @@ impl From<CLK_GATING_A> for bool {
     }
 }
 #[doc = "Field `CLK_GATING` reader - Gating Clock"]
-pub struct CLK_GATING_R(crate::FieldReader<bool>);
+pub type CLK_GATING_R = crate::BitReader<CLK_GATING_A>;
 impl CLK_GATING_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        CLK_GATING_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CLK_GATING_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl CLK_GATING_R {
     #[doc = "Checks if the value of the field is `OFF`"]
     #[inline(always)]
     pub fn is_off(&self) -> bool {
-        **self == CLK_GATING_A::OFF
+        *self == CLK_GATING_A::OFF
     }
     #[doc = "Checks if the value of the field is `ON`"]
     #[inline(always)]
     pub fn is_on(&self) -> bool {
-        **self == CLK_GATING_A::ON
-    }
-}
-impl core::ops::Deref for CLK_GATING_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CLK_GATING_A::ON
     }
 }
 #[doc = "Field `CLK_GATING` writer - Gating Clock"]
-pub struct CLK_GATING_W<'a> {
-    w: &'a mut W,
-}
+pub type CLK_GATING_W<'a> = crate::BitWriter<'a, u32, DRAM_CLK_SPEC, CLK_GATING_A, 31>;
 impl<'a> CLK_GATING_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CLK_GATING_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn off(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> CLK_GATING_W<'a> {
     pub fn on(self) -> &'a mut W {
         self.variant(CLK_GATING_A::ON)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "SDRCLK Configuration 0 Update\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<SDRCLK_UPD_A> for bool {
     }
 }
 #[doc = "Field `SDRCLK_UPD` reader - SDRCLK Configuration 0 Update"]
-pub struct SDRCLK_UPD_R(crate::FieldReader<bool>);
+pub type SDRCLK_UPD_R = crate::BitReader<SDRCLK_UPD_A>;
 impl SDRCLK_UPD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SDRCLK_UPD_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SDRCLK_UPD_A {
         match self.bits {
@@ -150,31 +112,17 @@ impl SDRCLK_UPD_R {
     #[doc = "Checks if the value of the field is `INVALID`"]
     #[inline(always)]
     pub fn is_invalid(&self) -> bool {
-        **self == SDRCLK_UPD_A::INVALID
+        *self == SDRCLK_UPD_A::INVALID
     }
     #[doc = "Checks if the value of the field is `VALID`"]
     #[inline(always)]
     pub fn is_valid(&self) -> bool {
-        **self == SDRCLK_UPD_A::VALID
-    }
-}
-impl core::ops::Deref for SDRCLK_UPD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SDRCLK_UPD_A::VALID
     }
 }
 #[doc = "Field `SDRCLK_UPD` writer - SDRCLK Configuration 0 Update"]
-pub struct SDRCLK_UPD_W<'a> {
-    w: &'a mut W,
-}
+pub type SDRCLK_UPD_W<'a> = crate::BitWriter<'a, u32, DRAM_CLK_SPEC, SDRCLK_UPD_A, 27>;
 impl<'a> SDRCLK_UPD_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SDRCLK_UPD_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn invalid(self) -> &'a mut W {
@@ -185,22 +133,6 @@ impl<'a> SDRCLK_UPD_W<'a> {
     pub fn valid(self) -> &'a mut W {
         self.variant(SDRCLK_UPD_A::VALID)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
-        self.w
-    }
 }
 #[doc = "Clock Source Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -222,13 +154,9 @@ impl From<CLK_SRC_SEL_A> for u8 {
     }
 }
 #[doc = "Field `CLK_SRC_SEL` reader - Clock Source Select"]
-pub struct CLK_SRC_SEL_R(crate::FieldReader<u8>);
+pub type CLK_SRC_SEL_R = crate::FieldReader<u8, CLK_SRC_SEL_A>;
 impl CLK_SRC_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        CLK_SRC_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<CLK_SRC_SEL_A> {
         match self.bits {
@@ -242,41 +170,27 @@ impl CLK_SRC_SEL_R {
     #[doc = "Checks if the value of the field is `PLL_DDR`"]
     #[inline(always)]
     pub fn is_pll_ddr(&self) -> bool {
-        **self == CLK_SRC_SEL_A::PLL_DDR
+        *self == CLK_SRC_SEL_A::PLL_DDR
     }
     #[doc = "Checks if the value of the field is `PLL_AUDIO1_DIV2`"]
     #[inline(always)]
     pub fn is_pll_audio1_div2(&self) -> bool {
-        **self == CLK_SRC_SEL_A::PLL_AUDIO1_DIV2
+        *self == CLK_SRC_SEL_A::PLL_AUDIO1_DIV2
     }
     #[doc = "Checks if the value of the field is `PLL_PERI_2X`"]
     #[inline(always)]
     pub fn is_pll_peri_2x(&self) -> bool {
-        **self == CLK_SRC_SEL_A::PLL_PERI_2X
+        *self == CLK_SRC_SEL_A::PLL_PERI_2X
     }
     #[doc = "Checks if the value of the field is `PLL_PERI_800M`"]
     #[inline(always)]
     pub fn is_pll_peri_800m(&self) -> bool {
-        **self == CLK_SRC_SEL_A::PLL_PERI_800M
-    }
-}
-impl core::ops::Deref for CLK_SRC_SEL_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CLK_SRC_SEL_A::PLL_PERI_800M
     }
 }
 #[doc = "Field `CLK_SRC_SEL` writer - Clock Source Select"]
-pub struct CLK_SRC_SEL_W<'a> {
-    w: &'a mut W,
-}
+pub type CLK_SRC_SEL_W<'a> = crate::FieldWriter<'a, u32, DRAM_CLK_SPEC, u8, CLK_SRC_SEL_A, 3, 24>;
 impl<'a> CLK_SRC_SEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CLK_SRC_SEL_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn pll_ddr(self) -> &'a mut W {
@@ -297,12 +211,6 @@ impl<'a> CLK_SRC_SEL_W<'a> {
     pub fn pll_peri_800m(self) -> &'a mut W {
         self.variant(CLK_SRC_SEL_A::PLL_PERI_800M)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << 24)) | ((value as u32 & 7) << 24);
-        self.w
-    }
 }
 #[doc = "Factor N\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -324,13 +232,9 @@ impl From<DRAM_DIV2_A> for u8 {
     }
 }
 #[doc = "Field `DRAM_DIV2` reader - Factor N"]
-pub struct DRAM_DIV2_R(crate::FieldReader<u8>);
+pub type DRAM_DIV2_R = crate::FieldReader<u8, DRAM_DIV2_A>;
 impl DRAM_DIV2_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        DRAM_DIV2_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DRAM_DIV2_A {
         match self.bits {
@@ -344,41 +248,27 @@ impl DRAM_DIV2_R {
     #[doc = "Checks if the value of the field is `N1`"]
     #[inline(always)]
     pub fn is_n1(&self) -> bool {
-        **self == DRAM_DIV2_A::N1
+        *self == DRAM_DIV2_A::N1
     }
     #[doc = "Checks if the value of the field is `N2`"]
     #[inline(always)]
     pub fn is_n2(&self) -> bool {
-        **self == DRAM_DIV2_A::N2
+        *self == DRAM_DIV2_A::N2
     }
     #[doc = "Checks if the value of the field is `N4`"]
     #[inline(always)]
     pub fn is_n4(&self) -> bool {
-        **self == DRAM_DIV2_A::N4
+        *self == DRAM_DIV2_A::N4
     }
     #[doc = "Checks if the value of the field is `N8`"]
     #[inline(always)]
     pub fn is_n8(&self) -> bool {
-        **self == DRAM_DIV2_A::N8
-    }
-}
-impl core::ops::Deref for DRAM_DIV2_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DRAM_DIV2_A::N8
     }
 }
 #[doc = "Field `DRAM_DIV2` writer - Factor N"]
-pub struct DRAM_DIV2_W<'a> {
-    w: &'a mut W,
-}
+pub type DRAM_DIV2_W<'a> = crate::FieldWriterSafe<'a, u32, DRAM_CLK_SPEC, u8, DRAM_DIV2_A, 2, 8>;
 impl<'a> DRAM_DIV2_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DRAM_DIV2_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn n1(self) -> &'a mut W {
@@ -399,40 +289,11 @@ impl<'a> DRAM_DIV2_W<'a> {
     pub fn n8(self) -> &'a mut W {
         self.variant(DRAM_DIV2_A::N8)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 8)) | ((value as u32 & 3) << 8);
-        self.w
-    }
 }
 #[doc = "Field `DRAM_DIV1` reader - Factor M"]
-pub struct DRAM_DIV1_R(crate::FieldReader<u8>);
-impl DRAM_DIV1_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        DRAM_DIV1_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DRAM_DIV1_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DRAM_DIV1_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `DRAM_DIV1` writer - Factor M"]
-pub struct DRAM_DIV1_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DRAM_DIV1_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
-        self.w
-    }
-}
+pub type DRAM_DIV1_W<'a> = crate::FieldWriter<'a, u32, DRAM_CLK_SPEC, u8, u8, 2, 0>;
 impl R {
     #[doc = "Bit 31 - Gating Clock"]
     #[inline(always)]
@@ -464,27 +325,27 @@ impl W {
     #[doc = "Bit 31 - Gating Clock"]
     #[inline(always)]
     pub fn clk_gating(&mut self) -> CLK_GATING_W {
-        CLK_GATING_W { w: self }
+        CLK_GATING_W::new(self)
     }
     #[doc = "Bit 27 - SDRCLK Configuration 0 Update"]
     #[inline(always)]
     pub fn sdrclk_upd(&mut self) -> SDRCLK_UPD_W {
-        SDRCLK_UPD_W { w: self }
+        SDRCLK_UPD_W::new(self)
     }
     #[doc = "Bits 24:26 - Clock Source Select"]
     #[inline(always)]
     pub fn clk_src_sel(&mut self) -> CLK_SRC_SEL_W {
-        CLK_SRC_SEL_W { w: self }
+        CLK_SRC_SEL_W::new(self)
     }
     #[doc = "Bits 8:9 - Factor N"]
     #[inline(always)]
     pub fn dram_div2(&mut self) -> DRAM_DIV2_W {
-        DRAM_DIV2_W { w: self }
+        DRAM_DIV2_W::new(self)
     }
     #[doc = "Bits 0:1 - Factor M"]
     #[inline(always)]
     pub fn dram_div1(&mut self) -> DRAM_DIV1_W {
-        DRAM_DIV1_W { w: self }
+        DRAM_DIV1_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
