@@ -49,13 +49,9 @@ impl From<ERROR_FLAG_A> for bool {
     }
 }
 #[doc = "Field `ERROR_FLAG` reader - Error Flag"]
-pub struct ERROR_FLAG_R(crate::FieldReader<bool>);
+pub type ERROR_FLAG_R = crate::BitReader<ERROR_FLAG_A>;
 impl ERROR_FLAG_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        ERROR_FLAG_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ERROR_FLAG_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl ERROR_FLAG_R {
     #[doc = "Checks if the value of the field is `W0C`"]
     #[inline(always)]
     pub fn is_w0c(&self) -> bool {
-        **self == ERROR_FLAG_A::W0C
+        *self == ERROR_FLAG_A::W0C
     }
     #[doc = "Checks if the value of the field is `ERROR`"]
     #[inline(always)]
     pub fn is_error(&self) -> bool {
-        **self == ERROR_FLAG_A::ERROR
-    }
-}
-impl core::ops::Deref for ERROR_FLAG_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == ERROR_FLAG_A::ERROR
     }
 }
 #[doc = "Field `ERROR_FLAG` writer - Error Flag"]
-pub struct ERROR_FLAG_W<'a> {
-    w: &'a mut W,
-}
+pub type ERROR_FLAG_W<'a> = crate::BitWriter0C<'a, u32, FRE_DET_CTRL_SPEC, ERROR_FLAG_A, 31>;
 impl<'a> ERROR_FLAG_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ERROR_FLAG_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn w0c(self) -> &'a mut W {
@@ -101,50 +83,11 @@ impl<'a> ERROR_FLAG_W<'a> {
     pub fn error(self) -> &'a mut W {
         self.variant(ERROR_FLAG_A::ERROR)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "Field `DET_TIME` reader - Detect Time"]
-pub struct DET_TIME_R(crate::FieldReader<u8>);
-impl DET_TIME_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        DET_TIME_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DET_TIME_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DET_TIME_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `DET_TIME` writer - Detect Time"]
-pub struct DET_TIME_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DET_TIME_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x1f << 4)) | ((value as u32 & 0x1f) << 4);
-        self.w
-    }
-}
+pub type DET_TIME_W<'a> = crate::FieldWriter<'a, u32, FRE_DET_CTRL_SPEC, u8, u8, 5, 4>;
 #[doc = "Frequence Detect IRQ Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FRE_DET_IRQ_EN_A {
@@ -160,13 +103,9 @@ impl From<FRE_DET_IRQ_EN_A> for bool {
     }
 }
 #[doc = "Field `FRE_DET_IRQ_EN` reader - Frequence Detect IRQ Enable"]
-pub struct FRE_DET_IRQ_EN_R(crate::FieldReader<bool>);
+pub type FRE_DET_IRQ_EN_R = crate::BitReader<FRE_DET_IRQ_EN_A>;
 impl FRE_DET_IRQ_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FRE_DET_IRQ_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FRE_DET_IRQ_EN_A {
         match self.bits {
@@ -177,31 +116,17 @@ impl FRE_DET_IRQ_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == FRE_DET_IRQ_EN_A::DISABLE
+        *self == FRE_DET_IRQ_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == FRE_DET_IRQ_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for FRE_DET_IRQ_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FRE_DET_IRQ_EN_A::ENABLE
     }
 }
 #[doc = "Field `FRE_DET_IRQ_EN` writer - Frequence Detect IRQ Enable"]
-pub struct FRE_DET_IRQ_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type FRE_DET_IRQ_EN_W<'a> = crate::BitWriter<'a, u32, FRE_DET_CTRL_SPEC, FRE_DET_IRQ_EN_A, 1>;
 impl<'a> FRE_DET_IRQ_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FRE_DET_IRQ_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -212,22 +137,6 @@ impl<'a> FRE_DET_IRQ_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(FRE_DET_IRQ_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
-        self.w
-    }
 }
 #[doc = "Frequence Detect Function Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -244,13 +153,9 @@ impl From<FRE_DET_FUN_EN_A> for bool {
     }
 }
 #[doc = "Field `FRE_DET_FUN_EN` reader - Frequence Detect Function Enable"]
-pub struct FRE_DET_FUN_EN_R(crate::FieldReader<bool>);
+pub type FRE_DET_FUN_EN_R = crate::BitReader<FRE_DET_FUN_EN_A>;
 impl FRE_DET_FUN_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FRE_DET_FUN_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FRE_DET_FUN_EN_A {
         match self.bits {
@@ -261,31 +166,17 @@ impl FRE_DET_FUN_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == FRE_DET_FUN_EN_A::DISABLE
+        *self == FRE_DET_FUN_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == FRE_DET_FUN_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for FRE_DET_FUN_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FRE_DET_FUN_EN_A::ENABLE
     }
 }
 #[doc = "Field `FRE_DET_FUN_EN` writer - Frequence Detect Function Enable"]
-pub struct FRE_DET_FUN_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type FRE_DET_FUN_EN_W<'a> = crate::BitWriter<'a, u32, FRE_DET_CTRL_SPEC, FRE_DET_FUN_EN_A, 0>;
 impl<'a> FRE_DET_FUN_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FRE_DET_FUN_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -296,22 +187,6 @@ impl<'a> FRE_DET_FUN_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(FRE_DET_FUN_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 31 - Error Flag"]
@@ -339,22 +214,22 @@ impl W {
     #[doc = "Bit 31 - Error Flag"]
     #[inline(always)]
     pub fn error_flag(&mut self) -> ERROR_FLAG_W {
-        ERROR_FLAG_W { w: self }
+        ERROR_FLAG_W::new(self)
     }
     #[doc = "Bits 4:8 - Detect Time"]
     #[inline(always)]
     pub fn det_time(&mut self) -> DET_TIME_W {
-        DET_TIME_W { w: self }
+        DET_TIME_W::new(self)
     }
     #[doc = "Bit 1 - Frequence Detect IRQ Enable"]
     #[inline(always)]
     pub fn fre_det_irq_en(&mut self) -> FRE_DET_IRQ_EN_W {
-        FRE_DET_IRQ_EN_W { w: self }
+        FRE_DET_IRQ_EN_W::new(self)
     }
     #[doc = "Bit 0 - Frequence Detect Function Enable"]
     #[inline(always)]
     pub fn fre_det_fun_en(&mut self) -> FRE_DET_FUN_EN_W {
-        FRE_DET_FUN_EN_W { w: self }
+        FRE_DET_FUN_EN_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
