@@ -35,106 +35,17 @@ impl From<crate::W<PLL_AUDIO0_PAT1_CTRL_SPEC>> for W {
     }
 }
 #[doc = "Field `DITHER_EN` reader - Dither Enable"]
-pub struct DITHER_EN_R(crate::FieldReader<bool>);
-impl DITHER_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DITHER_EN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DITHER_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DITHER_EN_R = crate::BitReader<bool>;
 #[doc = "Field `DITHER_EN` writer - Dither Enable"]
-pub struct DITHER_EN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DITHER_EN_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
-        self.w
-    }
-}
+pub type DITHER_EN_W<'a> = crate::BitWriter<'a, u32, PLL_AUDIO0_PAT1_CTRL_SPEC, bool, 24>;
 #[doc = "Field `FRAC_EN` reader - Fraction Enable"]
-pub struct FRAC_EN_R(crate::FieldReader<bool>);
-impl FRAC_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FRAC_EN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for FRAC_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type FRAC_EN_R = crate::BitReader<bool>;
 #[doc = "Field `FRAC_EN` writer - Fraction Enable"]
-pub struct FRAC_EN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> FRAC_EN_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
-        self.w
-    }
-}
+pub type FRAC_EN_W<'a> = crate::BitWriter<'a, u32, PLL_AUDIO0_PAT1_CTRL_SPEC, bool, 20>;
 #[doc = "Field `FRAC_IN` reader - Fraction In"]
-pub struct FRAC_IN_R(crate::FieldReader<u32>);
-impl FRAC_IN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u32) -> Self {
-        FRAC_IN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for FRAC_IN_R {
-    type Target = crate::FieldReader<u32>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type FRAC_IN_R = crate::FieldReader<u32, u32>;
 #[doc = "Field `FRAC_IN` writer - Fraction In"]
-pub struct FRAC_IN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> FRAC_IN_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x0001_ffff) | (value as u32 & 0x0001_ffff);
-        self.w
-    }
-}
+pub type FRAC_IN_W<'a> = crate::FieldWriter<'a, u32, PLL_AUDIO0_PAT1_CTRL_SPEC, u32, u32, 17, 0>;
 impl R {
     #[doc = "Bit 24 - Dither Enable"]
     #[inline(always)]
@@ -156,17 +67,17 @@ impl W {
     #[doc = "Bit 24 - Dither Enable"]
     #[inline(always)]
     pub fn dither_en(&mut self) -> DITHER_EN_W {
-        DITHER_EN_W { w: self }
+        DITHER_EN_W::new(self)
     }
     #[doc = "Bit 20 - Fraction Enable"]
     #[inline(always)]
     pub fn frac_en(&mut self) -> FRAC_EN_W {
-        FRAC_EN_W { w: self }
+        FRAC_EN_W::new(self)
     }
     #[doc = "Bits 0:16 - Fraction In"]
     #[inline(always)]
     pub fn frac_in(&mut self) -> FRAC_IN_W {
-        FRAC_IN_W { w: self }
+        FRAC_IN_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
