@@ -35,42 +35,9 @@ impl From<crate::W<PLL_AUDIO1_PAT0_CTRL_SPEC>> for W {
     }
 }
 #[doc = "Field `SIG_DELT_PAT_EN` reader - Sigma-Delta Pattern Enable"]
-pub struct SIG_DELT_PAT_EN_R(crate::FieldReader<bool>);
-impl SIG_DELT_PAT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SIG_DELT_PAT_EN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for SIG_DELT_PAT_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type SIG_DELT_PAT_EN_R = crate::BitReader<bool>;
 #[doc = "Field `SIG_DELT_PAT_EN` writer - Sigma-Delta Pattern Enable"]
-pub struct SIG_DELT_PAT_EN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> SIG_DELT_PAT_EN_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
-}
+pub type SIG_DELT_PAT_EN_W<'a> = crate::BitWriter<'a, u32, PLL_AUDIO1_PAT0_CTRL_SPEC, bool, 31>;
 #[doc = "Spread Frequency Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
@@ -91,13 +58,9 @@ impl From<SPR_FREQ_MODE_A> for u8 {
     }
 }
 #[doc = "Field `SPR_FREQ_MODE` reader - Spread Frequency Mode"]
-pub struct SPR_FREQ_MODE_R(crate::FieldReader<u8>);
+pub type SPR_FREQ_MODE_R = crate::FieldReader<u8, SPR_FREQ_MODE_A>;
 impl SPR_FREQ_MODE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        SPR_FREQ_MODE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SPR_FREQ_MODE_A {
         match self.bits {
@@ -111,41 +74,28 @@ impl SPR_FREQ_MODE_R {
     #[doc = "Checks if the value of the field is `DC0`"]
     #[inline(always)]
     pub fn is_dc0(&self) -> bool {
-        **self == SPR_FREQ_MODE_A::DC0
+        *self == SPR_FREQ_MODE_A::DC0
     }
     #[doc = "Checks if the value of the field is `DC1`"]
     #[inline(always)]
     pub fn is_dc1(&self) -> bool {
-        **self == SPR_FREQ_MODE_A::DC1
+        *self == SPR_FREQ_MODE_A::DC1
     }
     #[doc = "Checks if the value of the field is `TRIANGULAR_1`"]
     #[inline(always)]
     pub fn is_triangular_1(&self) -> bool {
-        **self == SPR_FREQ_MODE_A::TRIANGULAR_1
+        *self == SPR_FREQ_MODE_A::TRIANGULAR_1
     }
     #[doc = "Checks if the value of the field is `TRIANGULAR_N`"]
     #[inline(always)]
     pub fn is_triangular_n(&self) -> bool {
-        **self == SPR_FREQ_MODE_A::TRIANGULAR_N
-    }
-}
-impl core::ops::Deref for SPR_FREQ_MODE_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SPR_FREQ_MODE_A::TRIANGULAR_N
     }
 }
 #[doc = "Field `SPR_FREQ_MODE` writer - Spread Frequency Mode"]
-pub struct SPR_FREQ_MODE_W<'a> {
-    w: &'a mut W,
-}
+pub type SPR_FREQ_MODE_W<'a> =
+    crate::FieldWriterSafe<'a, u32, PLL_AUDIO1_PAT0_CTRL_SPEC, u8, SPR_FREQ_MODE_A, 2, 29>;
 impl<'a> SPR_FREQ_MODE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SPR_FREQ_MODE_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn dc0(self) -> &'a mut W {
@@ -166,40 +116,11 @@ impl<'a> SPR_FREQ_MODE_W<'a> {
     pub fn triangular_n(self) -> &'a mut W {
         self.variant(SPR_FREQ_MODE_A::TRIANGULAR_N)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 29)) | ((value as u32 & 3) << 29);
-        self.w
-    }
 }
 #[doc = "Field `WAVE_STEP` reader - Wave Step"]
-pub struct WAVE_STEP_R(crate::FieldReader<u16>);
-impl WAVE_STEP_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        WAVE_STEP_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for WAVE_STEP_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type WAVE_STEP_R = crate::FieldReader<u16, u16>;
 #[doc = "Field `WAVE_STEP` writer - Wave Step"]
-pub struct WAVE_STEP_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> WAVE_STEP_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01ff << 20)) | ((value as u32 & 0x01ff) << 20);
-        self.w
-    }
-}
+pub type WAVE_STEP_W<'a> = crate::FieldWriter<'a, u32, PLL_AUDIO1_PAT0_CTRL_SPEC, u16, u16, 9, 20>;
 #[doc = "SDM Clock Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SDM_CLK_SEL_A {
@@ -215,13 +136,9 @@ impl From<SDM_CLK_SEL_A> for bool {
     }
 }
 #[doc = "Field `SDM_CLK_SEL` reader - SDM Clock Select"]
-pub struct SDM_CLK_SEL_R(crate::FieldReader<bool>);
+pub type SDM_CLK_SEL_R = crate::BitReader<SDM_CLK_SEL_A>;
 impl SDM_CLK_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SDM_CLK_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SDM_CLK_SEL_A {
         match self.bits {
@@ -232,31 +149,18 @@ impl SDM_CLK_SEL_R {
     #[doc = "Checks if the value of the field is `F_24_M`"]
     #[inline(always)]
     pub fn is_f_24_m(&self) -> bool {
-        **self == SDM_CLK_SEL_A::F_24_M
+        *self == SDM_CLK_SEL_A::F_24_M
     }
     #[doc = "Checks if the value of the field is `F_12_M`"]
     #[inline(always)]
     pub fn is_f_12_m(&self) -> bool {
-        **self == SDM_CLK_SEL_A::F_12_M
-    }
-}
-impl core::ops::Deref for SDM_CLK_SEL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SDM_CLK_SEL_A::F_12_M
     }
 }
 #[doc = "Field `SDM_CLK_SEL` writer - SDM Clock Select"]
-pub struct SDM_CLK_SEL_W<'a> {
-    w: &'a mut W,
-}
+pub type SDM_CLK_SEL_W<'a> =
+    crate::BitWriter<'a, u32, PLL_AUDIO1_PAT0_CTRL_SPEC, SDM_CLK_SEL_A, 19>;
 impl<'a> SDM_CLK_SEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SDM_CLK_SEL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn f_24_m(self) -> &'a mut W {
@@ -267,22 +171,6 @@ impl<'a> SDM_CLK_SEL_W<'a> {
     pub fn f_12_m(self) -> &'a mut W {
         self.variant(SDM_CLK_SEL_A::F_12_M)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 19)) | ((value as u32 & 1) << 19);
-        self.w
-    }
 }
 #[doc = "Frequency\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -304,13 +192,9 @@ impl From<FREQ_A> for u8 {
     }
 }
 #[doc = "Field `FREQ` reader - Frequency"]
-pub struct FREQ_R(crate::FieldReader<u8>);
+pub type FREQ_R = crate::FieldReader<u8, FREQ_A>;
 impl FREQ_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        FREQ_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FREQ_A {
         match self.bits {
@@ -324,41 +208,27 @@ impl FREQ_R {
     #[doc = "Checks if the value of the field is `F_31_5_K`"]
     #[inline(always)]
     pub fn is_f_31_5_k(&self) -> bool {
-        **self == FREQ_A::F_31_5_K
+        *self == FREQ_A::F_31_5_K
     }
     #[doc = "Checks if the value of the field is `F_32_K`"]
     #[inline(always)]
     pub fn is_f_32_k(&self) -> bool {
-        **self == FREQ_A::F_32_K
+        *self == FREQ_A::F_32_K
     }
     #[doc = "Checks if the value of the field is `F_32_5_K`"]
     #[inline(always)]
     pub fn is_f_32_5_k(&self) -> bool {
-        **self == FREQ_A::F_32_5_K
+        *self == FREQ_A::F_32_5_K
     }
     #[doc = "Checks if the value of the field is `F_33_K`"]
     #[inline(always)]
     pub fn is_f_33_k(&self) -> bool {
-        **self == FREQ_A::F_33_K
-    }
-}
-impl core::ops::Deref for FREQ_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FREQ_A::F_33_K
     }
 }
 #[doc = "Field `FREQ` writer - Frequency"]
-pub struct FREQ_W<'a> {
-    w: &'a mut W,
-}
+pub type FREQ_W<'a> = crate::FieldWriterSafe<'a, u32, PLL_AUDIO1_PAT0_CTRL_SPEC, u8, FREQ_A, 2, 17>;
 impl<'a> FREQ_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FREQ_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn f_31_5_k(self) -> &'a mut W {
@@ -379,40 +249,11 @@ impl<'a> FREQ_W<'a> {
     pub fn f_33_k(self) -> &'a mut W {
         self.variant(FREQ_A::F_33_K)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 17)) | ((value as u32 & 3) << 17);
-        self.w
-    }
 }
 #[doc = "Field `WAVE_BOT` reader - Wave Bottom"]
-pub struct WAVE_BOT_R(crate::FieldReader<u32>);
-impl WAVE_BOT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u32) -> Self {
-        WAVE_BOT_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for WAVE_BOT_R {
-    type Target = crate::FieldReader<u32>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type WAVE_BOT_R = crate::FieldReader<u32, u32>;
 #[doc = "Field `WAVE_BOT` writer - Wave Bottom"]
-pub struct WAVE_BOT_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> WAVE_BOT_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x0001_ffff) | (value as u32 & 0x0001_ffff);
-        self.w
-    }
-}
+pub type WAVE_BOT_W<'a> = crate::FieldWriter<'a, u32, PLL_AUDIO1_PAT0_CTRL_SPEC, u32, u32, 17, 0>;
 impl R {
     #[doc = "Bit 31 - Sigma-Delta Pattern Enable"]
     #[inline(always)]
@@ -449,32 +290,32 @@ impl W {
     #[doc = "Bit 31 - Sigma-Delta Pattern Enable"]
     #[inline(always)]
     pub fn sig_delt_pat_en(&mut self) -> SIG_DELT_PAT_EN_W {
-        SIG_DELT_PAT_EN_W { w: self }
+        SIG_DELT_PAT_EN_W::new(self)
     }
     #[doc = "Bits 29:30 - Spread Frequency Mode"]
     #[inline(always)]
     pub fn spr_freq_mode(&mut self) -> SPR_FREQ_MODE_W {
-        SPR_FREQ_MODE_W { w: self }
+        SPR_FREQ_MODE_W::new(self)
     }
     #[doc = "Bits 20:28 - Wave Step"]
     #[inline(always)]
     pub fn wave_step(&mut self) -> WAVE_STEP_W {
-        WAVE_STEP_W { w: self }
+        WAVE_STEP_W::new(self)
     }
     #[doc = "Bit 19 - SDM Clock Select"]
     #[inline(always)]
     pub fn sdm_clk_sel(&mut self) -> SDM_CLK_SEL_W {
-        SDM_CLK_SEL_W { w: self }
+        SDM_CLK_SEL_W::new(self)
     }
     #[doc = "Bits 17:18 - Frequency"]
     #[inline(always)]
     pub fn freq(&mut self) -> FREQ_W {
-        FREQ_W { w: self }
+        FREQ_W::new(self)
     }
     #[doc = "Bits 0:16 - Wave Bottom"]
     #[inline(always)]
     pub fn wave_bot(&mut self) -> WAVE_BOT_W {
-        WAVE_BOT_W { w: self }
+        WAVE_BOT_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
