@@ -49,13 +49,9 @@ impl From<PLL_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_EN` reader - PLL Enable"]
-pub struct PLL_EN_R(crate::FieldReader<bool>);
+pub type PLL_EN_R = crate::BitReader<PLL_EN_A>;
 impl PLL_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PLL_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PLL_EN_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl PLL_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == PLL_EN_A::DISABLE
+        *self == PLL_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == PLL_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for PLL_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PLL_EN_A::ENABLE
     }
 }
 #[doc = "Field `PLL_EN` writer - PLL Enable"]
-pub struct PLL_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type PLL_EN_W<'a> = crate::BitWriter<'a, u32, PLL_PERI_CTRL_SPEC, PLL_EN_A, 31>;
 impl<'a> PLL_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PLL_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> PLL_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(PLL_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "LDO Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<PLL_LDO_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_LDO_EN` reader - LDO Enable"]
-pub struct PLL_LDO_EN_R(crate::FieldReader<bool>);
+pub type PLL_LDO_EN_R = crate::BitReader<PLL_LDO_EN_A>;
 impl PLL_LDO_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PLL_LDO_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PLL_LDO_EN_A {
         match self.bits {
@@ -150,31 +112,17 @@ impl PLL_LDO_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == PLL_LDO_EN_A::DISABLE
+        *self == PLL_LDO_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == PLL_LDO_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for PLL_LDO_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PLL_LDO_EN_A::ENABLE
     }
 }
 #[doc = "Field `PLL_LDO_EN` writer - LDO Enable"]
-pub struct PLL_LDO_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type PLL_LDO_EN_W<'a> = crate::BitWriter<'a, u32, PLL_PERI_CTRL_SPEC, PLL_LDO_EN_A, 30>;
 impl<'a> PLL_LDO_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PLL_LDO_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -185,22 +133,6 @@ impl<'a> PLL_LDO_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(PLL_LDO_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
-        self.w
-    }
 }
 #[doc = "Lock Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -217,13 +149,9 @@ impl From<LOCK_ENABLE_A> for bool {
     }
 }
 #[doc = "Field `LOCK_ENABLE` reader - Lock Enable"]
-pub struct LOCK_ENABLE_R(crate::FieldReader<bool>);
+pub type LOCK_ENABLE_R = crate::BitReader<LOCK_ENABLE_A>;
 impl LOCK_ENABLE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        LOCK_ENABLE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LOCK_ENABLE_A {
         match self.bits {
@@ -234,31 +162,17 @@ impl LOCK_ENABLE_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == LOCK_ENABLE_A::DISABLE
+        *self == LOCK_ENABLE_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == LOCK_ENABLE_A::ENABLE
-    }
-}
-impl core::ops::Deref for LOCK_ENABLE_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == LOCK_ENABLE_A::ENABLE
     }
 }
 #[doc = "Field `LOCK_ENABLE` writer - Lock Enable"]
-pub struct LOCK_ENABLE_W<'a> {
-    w: &'a mut W,
-}
+pub type LOCK_ENABLE_W<'a> = crate::BitWriter<'a, u32, PLL_PERI_CTRL_SPEC, LOCK_ENABLE_A, 29>;
 impl<'a> LOCK_ENABLE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LOCK_ENABLE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -269,22 +183,6 @@ impl<'a> LOCK_ENABLE_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(LOCK_ENABLE_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
-        self.w
-    }
 }
 #[doc = "PLL Lock Status\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -301,13 +199,9 @@ impl From<LOCK_A> for bool {
     }
 }
 #[doc = "Field `LOCK` reader - PLL Lock Status"]
-pub struct LOCK_R(crate::FieldReader<bool>);
+pub type LOCK_R = crate::BitReader<LOCK_A>;
 impl LOCK_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        LOCK_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LOCK_A {
         match self.bits {
@@ -318,19 +212,12 @@ impl LOCK_R {
     #[doc = "Checks if the value of the field is `UNLOCKED`"]
     #[inline(always)]
     pub fn is_unlocked(&self) -> bool {
-        **self == LOCK_A::UNLOCKED
+        *self == LOCK_A::UNLOCKED
     }
     #[doc = "Checks if the value of the field is `LOCKED`"]
     #[inline(always)]
     pub fn is_locked(&self) -> bool {
-        **self == LOCK_A::LOCKED
-    }
-}
-impl core::ops::Deref for LOCK_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == LOCK_A::LOCKED
     }
 }
 #[doc = "PLL Output Gating Enable\n\nValue on reset: 0"]
@@ -348,13 +235,9 @@ impl From<PLL_OUTPUT_GATE_A> for bool {
     }
 }
 #[doc = "Field `PLL_OUTPUT_GATE` reader - PLL Output Gating Enable"]
-pub struct PLL_OUTPUT_GATE_R(crate::FieldReader<bool>);
+pub type PLL_OUTPUT_GATE_R = crate::BitReader<PLL_OUTPUT_GATE_A>;
 impl PLL_OUTPUT_GATE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PLL_OUTPUT_GATE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PLL_OUTPUT_GATE_A {
         match self.bits {
@@ -365,31 +248,18 @@ impl PLL_OUTPUT_GATE_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == PLL_OUTPUT_GATE_A::DISABLE
+        *self == PLL_OUTPUT_GATE_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == PLL_OUTPUT_GATE_A::ENABLE
-    }
-}
-impl core::ops::Deref for PLL_OUTPUT_GATE_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PLL_OUTPUT_GATE_A::ENABLE
     }
 }
 #[doc = "Field `PLL_OUTPUT_GATE` writer - PLL Output Gating Enable"]
-pub struct PLL_OUTPUT_GATE_W<'a> {
-    w: &'a mut W,
-}
+pub type PLL_OUTPUT_GATE_W<'a> =
+    crate::BitWriter<'a, u32, PLL_PERI_CTRL_SPEC, PLL_OUTPUT_GATE_A, 27>;
 impl<'a> PLL_OUTPUT_GATE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PLL_OUTPUT_GATE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -400,22 +270,6 @@ impl<'a> PLL_OUTPUT_GATE_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(PLL_OUTPUT_GATE_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
-        self.w
-    }
 }
 #[doc = "PLL SDM Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -432,13 +286,9 @@ impl From<PLL_SDM_EN_A> for bool {
     }
 }
 #[doc = "Field `PLL_SDM_EN` reader - PLL SDM Enable"]
-pub struct PLL_SDM_EN_R(crate::FieldReader<bool>);
+pub type PLL_SDM_EN_R = crate::BitReader<PLL_SDM_EN_A>;
 impl PLL_SDM_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PLL_SDM_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PLL_SDM_EN_A {
         match self.bits {
@@ -449,31 +299,17 @@ impl PLL_SDM_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == PLL_SDM_EN_A::DISABLE
+        *self == PLL_SDM_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == PLL_SDM_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for PLL_SDM_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PLL_SDM_EN_A::ENABLE
     }
 }
 #[doc = "Field `PLL_SDM_EN` writer - PLL SDM Enable"]
-pub struct PLL_SDM_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type PLL_SDM_EN_W<'a> = crate::BitWriter<'a, u32, PLL_PERI_CTRL_SPEC, PLL_SDM_EN_A, 24>;
 impl<'a> PLL_SDM_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PLL_SDM_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -484,104 +320,19 @@ impl<'a> PLL_SDM_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(PLL_SDM_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
-        self.w
-    }
 }
 #[doc = "Field `PLL_P1` reader - PLL Output Div P1"]
-pub struct PLL_P1_R(crate::FieldReader<u8>);
-impl PLL_P1_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PLL_P1_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for PLL_P1_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PLL_P1_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `PLL_P1` writer - PLL Output Div P1"]
-pub struct PLL_P1_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PLL_P1_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << 20)) | ((value as u32 & 7) << 20);
-        self.w
-    }
-}
+pub type PLL_P1_W<'a> = crate::FieldWriter<'a, u32, PLL_PERI_CTRL_SPEC, u8, u8, 3, 20>;
 #[doc = "Field `PLL_P0` reader - PLL Output Div P0"]
-pub struct PLL_P0_R(crate::FieldReader<u8>);
-impl PLL_P0_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PLL_P0_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for PLL_P0_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PLL_P0_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `PLL_P0` writer - PLL Output Div P0"]
-pub struct PLL_P0_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PLL_P0_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << 16)) | ((value as u32 & 7) << 16);
-        self.w
-    }
-}
+pub type PLL_P0_W<'a> = crate::FieldWriter<'a, u32, PLL_PERI_CTRL_SPEC, u8, u8, 3, 16>;
 #[doc = "Field `PLL_N` reader - PLL N"]
-pub struct PLL_N_R(crate::FieldReader<u8>);
-impl PLL_N_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PLL_N_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for PLL_N_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PLL_N_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `PLL_N` writer - PLL N"]
-pub struct PLL_N_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PLL_N_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0xff << 8)) | ((value as u32 & 0xff) << 8);
-        self.w
-    }
-}
+pub type PLL_N_W<'a> = crate::FieldWriter<'a, u32, PLL_PERI_CTRL_SPEC, u8, u8, 8, 8>;
 #[doc = "PLL Unlock Level\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
@@ -600,13 +351,9 @@ impl From<PLL_UNLOCK_MDSEL_A> for u8 {
     }
 }
 #[doc = "Field `PLL_UNLOCK_MDSEL` reader - PLL Unlock Level"]
-pub struct PLL_UNLOCK_MDSEL_R(crate::FieldReader<u8>);
+pub type PLL_UNLOCK_MDSEL_R = crate::FieldReader<u8, PLL_UNLOCK_MDSEL_A>;
 impl PLL_UNLOCK_MDSEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PLL_UNLOCK_MDSEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PLL_UNLOCK_MDSEL_A> {
         match self.bits {
@@ -619,36 +366,23 @@ impl PLL_UNLOCK_MDSEL_R {
     #[doc = "Checks if the value of the field is `CC_21_29`"]
     #[inline(always)]
     pub fn is_cc_21_29(&self) -> bool {
-        **self == PLL_UNLOCK_MDSEL_A::CC_21_29
+        *self == PLL_UNLOCK_MDSEL_A::CC_21_29
     }
     #[doc = "Checks if the value of the field is `CC_22_28`"]
     #[inline(always)]
     pub fn is_cc_22_28(&self) -> bool {
-        **self == PLL_UNLOCK_MDSEL_A::CC_22_28
+        *self == PLL_UNLOCK_MDSEL_A::CC_22_28
     }
     #[doc = "Checks if the value of the field is `CC_20_30`"]
     #[inline(always)]
     pub fn is_cc_20_30(&self) -> bool {
-        **self == PLL_UNLOCK_MDSEL_A::CC_20_30
-    }
-}
-impl core::ops::Deref for PLL_UNLOCK_MDSEL_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PLL_UNLOCK_MDSEL_A::CC_20_30
     }
 }
 #[doc = "Field `PLL_UNLOCK_MDSEL` writer - PLL Unlock Level"]
-pub struct PLL_UNLOCK_MDSEL_W<'a> {
-    w: &'a mut W,
-}
+pub type PLL_UNLOCK_MDSEL_W<'a> =
+    crate::FieldWriter<'a, u32, PLL_PERI_CTRL_SPEC, u8, PLL_UNLOCK_MDSEL_A, 2, 6>;
 impl<'a> PLL_UNLOCK_MDSEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PLL_UNLOCK_MDSEL_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn cc_21_29(self) -> &'a mut W {
@@ -664,12 +398,6 @@ impl<'a> PLL_UNLOCK_MDSEL_W<'a> {
     pub fn cc_20_30(self) -> &'a mut W {
         self.variant(PLL_UNLOCK_MDSEL_A::CC_20_30)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 6)) | ((value as u32 & 3) << 6);
-        self.w
-    }
 }
 #[doc = "PLL Lock Level\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -686,13 +414,9 @@ impl From<PLL_LOCK_MDSEL_A> for bool {
     }
 }
 #[doc = "Field `PLL_LOCK_MDSEL` reader - PLL Lock Level"]
-pub struct PLL_LOCK_MDSEL_R(crate::FieldReader<bool>);
+pub type PLL_LOCK_MDSEL_R = crate::BitReader<PLL_LOCK_MDSEL_A>;
 impl PLL_LOCK_MDSEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PLL_LOCK_MDSEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PLL_LOCK_MDSEL_A {
         match self.bits {
@@ -703,31 +427,17 @@ impl PLL_LOCK_MDSEL_R {
     #[doc = "Checks if the value of the field is `CC_24_26`"]
     #[inline(always)]
     pub fn is_cc_24_26(&self) -> bool {
-        **self == PLL_LOCK_MDSEL_A::CC_24_26
+        *self == PLL_LOCK_MDSEL_A::CC_24_26
     }
     #[doc = "Checks if the value of the field is `CC_23_27`"]
     #[inline(always)]
     pub fn is_cc_23_27(&self) -> bool {
-        **self == PLL_LOCK_MDSEL_A::CC_23_27
-    }
-}
-impl core::ops::Deref for PLL_LOCK_MDSEL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PLL_LOCK_MDSEL_A::CC_23_27
     }
 }
 #[doc = "Field `PLL_LOCK_MDSEL` writer - PLL Lock Level"]
-pub struct PLL_LOCK_MDSEL_W<'a> {
-    w: &'a mut W,
-}
+pub type PLL_LOCK_MDSEL_W<'a> = crate::BitWriter<'a, u32, PLL_PERI_CTRL_SPEC, PLL_LOCK_MDSEL_A, 5>;
 impl<'a> PLL_LOCK_MDSEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PLL_LOCK_MDSEL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn cc_24_26(self) -> &'a mut W {
@@ -738,60 +448,11 @@ impl<'a> PLL_LOCK_MDSEL_W<'a> {
     pub fn cc_23_27(self) -> &'a mut W {
         self.variant(PLL_LOCK_MDSEL_A::CC_23_27)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
-        self.w
-    }
 }
 #[doc = "Field `PLL_INPUT_DIV2` reader - PLL Input Div M"]
-pub struct PLL_INPUT_DIV2_R(crate::FieldReader<bool>);
-impl PLL_INPUT_DIV2_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PLL_INPUT_DIV2_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for PLL_INPUT_DIV2_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PLL_INPUT_DIV2_R = crate::BitReader<bool>;
 #[doc = "Field `PLL_INPUT_DIV2` writer - PLL Input Div M"]
-pub struct PLL_INPUT_DIV2_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PLL_INPUT_DIV2_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
-        self.w
-    }
-}
+pub type PLL_INPUT_DIV2_W<'a> = crate::BitWriter<'a, u32, PLL_PERI_CTRL_SPEC, bool, 1>;
 impl R {
     #[doc = "Bit 31 - PLL Enable"]
     #[inline(always)]
@@ -858,57 +519,57 @@ impl W {
     #[doc = "Bit 31 - PLL Enable"]
     #[inline(always)]
     pub fn pll_en(&mut self) -> PLL_EN_W {
-        PLL_EN_W { w: self }
+        PLL_EN_W::new(self)
     }
     #[doc = "Bit 30 - LDO Enable"]
     #[inline(always)]
     pub fn pll_ldo_en(&mut self) -> PLL_LDO_EN_W {
-        PLL_LDO_EN_W { w: self }
+        PLL_LDO_EN_W::new(self)
     }
     #[doc = "Bit 29 - Lock Enable"]
     #[inline(always)]
     pub fn lock_enable(&mut self) -> LOCK_ENABLE_W {
-        LOCK_ENABLE_W { w: self }
+        LOCK_ENABLE_W::new(self)
     }
     #[doc = "Bit 27 - PLL Output Gating Enable"]
     #[inline(always)]
     pub fn pll_output_gate(&mut self) -> PLL_OUTPUT_GATE_W {
-        PLL_OUTPUT_GATE_W { w: self }
+        PLL_OUTPUT_GATE_W::new(self)
     }
     #[doc = "Bit 24 - PLL SDM Enable"]
     #[inline(always)]
     pub fn pll_sdm_en(&mut self) -> PLL_SDM_EN_W {
-        PLL_SDM_EN_W { w: self }
+        PLL_SDM_EN_W::new(self)
     }
     #[doc = "Bits 20:22 - PLL Output Div P1"]
     #[inline(always)]
     pub fn pll_p1(&mut self) -> PLL_P1_W {
-        PLL_P1_W { w: self }
+        PLL_P1_W::new(self)
     }
     #[doc = "Bits 16:18 - PLL Output Div P0"]
     #[inline(always)]
     pub fn pll_p0(&mut self) -> PLL_P0_W {
-        PLL_P0_W { w: self }
+        PLL_P0_W::new(self)
     }
     #[doc = "Bits 8:15 - PLL N"]
     #[inline(always)]
     pub fn pll_n(&mut self) -> PLL_N_W {
-        PLL_N_W { w: self }
+        PLL_N_W::new(self)
     }
     #[doc = "Bits 6:7 - PLL Unlock Level"]
     #[inline(always)]
     pub fn pll_unlock_mdsel(&mut self) -> PLL_UNLOCK_MDSEL_W {
-        PLL_UNLOCK_MDSEL_W { w: self }
+        PLL_UNLOCK_MDSEL_W::new(self)
     }
     #[doc = "Bit 5 - PLL Lock Level"]
     #[inline(always)]
     pub fn pll_lock_mdsel(&mut self) -> PLL_LOCK_MDSEL_W {
-        PLL_LOCK_MDSEL_W { w: self }
+        PLL_LOCK_MDSEL_W::new(self)
     }
     #[doc = "Bit 1 - PLL Input Div M"]
     #[inline(always)]
     pub fn pll_input_div2(&mut self) -> PLL_INPUT_DIV2_W {
-        PLL_INPUT_DIV2_W { w: self }
+        PLL_INPUT_DIV2_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
