@@ -49,13 +49,9 @@ impl From<GATING_A> for bool {
     }
 }
 #[doc = "Field `GATING` reader - Gating Clock"]
-pub struct GATING_R(crate::FieldReader<bool>);
+pub type GATING_R = crate::BitReader<GATING_A>;
 impl GATING_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        GATING_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> GATING_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl GATING_R {
     #[doc = "Checks if the value of the field is `MASK`"]
     #[inline(always)]
     pub fn is_mask(&self) -> bool {
-        **self == GATING_A::MASK
+        *self == GATING_A::MASK
     }
     #[doc = "Checks if the value of the field is `PASS`"]
     #[inline(always)]
     pub fn is_pass(&self) -> bool {
-        **self == GATING_A::PASS
-    }
-}
-impl core::ops::Deref for GATING_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == GATING_A::PASS
     }
 }
 #[doc = "Field `GATING` writer - Gating Clock"]
-pub struct GATING_W<'a> {
-    w: &'a mut W,
-}
+pub type GATING_W<'a> = crate::BitWriter<'a, u32, RISCV_GATING_SPEC, GATING_A, 31>;
 impl<'a> GATING_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: GATING_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn mask(self) -> &'a mut W {
@@ -101,50 +83,11 @@ impl<'a> GATING_W<'a> {
     pub fn pass(self) -> &'a mut W {
         self.variant(GATING_A::PASS)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "Field `GATING_FIELD` reader - "]
-pub struct GATING_FIELD_R(crate::FieldReader<u16>);
-impl GATING_FIELD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        GATING_FIELD_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for GATING_FIELD_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type GATING_FIELD_R = crate::FieldReader<u16, u16>;
 #[doc = "Field `GATING_FIELD` writer - "]
-pub struct GATING_FIELD_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> GATING_FIELD_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0xffff) | (value as u32 & 0xffff);
-        self.w
-    }
-}
+pub type GATING_FIELD_W<'a> = crate::FieldWriter<'a, u32, RISCV_GATING_SPEC, u16, u16, 16, 0>;
 impl R {
     #[doc = "Bit 31 - Gating Clock"]
     #[inline(always)]
@@ -161,12 +104,12 @@ impl W {
     #[doc = "Bit 31 - Gating Clock"]
     #[inline(always)]
     pub fn gating(&mut self) -> GATING_W {
-        GATING_W { w: self }
+        GATING_W::new(self)
     }
     #[doc = "Bits 0:15"]
     #[inline(always)]
     pub fn gating_field(&mut self) -> GATING_FIELD_W {
-        GATING_FIELD_W { w: self }
+        GATING_FIELD_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
