@@ -49,13 +49,9 @@ impl From<CLK_GATING_A> for bool {
     }
 }
 #[doc = "Field `CLK_GATING` reader - Gating Clock"]
-pub struct CLK_GATING_R(crate::FieldReader<bool>);
+pub type CLK_GATING_R = crate::BitReader<CLK_GATING_A>;
 impl CLK_GATING_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        CLK_GATING_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CLK_GATING_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl CLK_GATING_R {
     #[doc = "Checks if the value of the field is `OFF`"]
     #[inline(always)]
     pub fn is_off(&self) -> bool {
-        **self == CLK_GATING_A::OFF
+        *self == CLK_GATING_A::OFF
     }
     #[doc = "Checks if the value of the field is `ON`"]
     #[inline(always)]
     pub fn is_on(&self) -> bool {
-        **self == CLK_GATING_A::ON
-    }
-}
-impl core::ops::Deref for CLK_GATING_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CLK_GATING_A::ON
     }
 }
 #[doc = "Field `CLK_GATING` writer - Gating Clock"]
-pub struct CLK_GATING_W<'a> {
-    w: &'a mut W,
-}
+pub type CLK_GATING_W<'a> = crate::BitWriter<'a, u32, TPADC_CLK_SPEC, CLK_GATING_A, 31>;
 impl<'a> CLK_GATING_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CLK_GATING_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn off(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> CLK_GATING_W<'a> {
     pub fn on(self) -> &'a mut W {
         self.variant(CLK_GATING_A::ON)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "Clock Source Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -134,13 +100,9 @@ impl From<CLK_SRC_SEL_A> for u8 {
     }
 }
 #[doc = "Field `CLK_SRC_SEL` reader - Clock Source Select"]
-pub struct CLK_SRC_SEL_R(crate::FieldReader<u8>);
+pub type CLK_SRC_SEL_R = crate::FieldReader<u8, CLK_SRC_SEL_A>;
 impl CLK_SRC_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        CLK_SRC_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<CLK_SRC_SEL_A> {
         match self.bits {
@@ -152,31 +114,17 @@ impl CLK_SRC_SEL_R {
     #[doc = "Checks if the value of the field is `HOSC`"]
     #[inline(always)]
     pub fn is_hosc(&self) -> bool {
-        **self == CLK_SRC_SEL_A::HOSC
+        *self == CLK_SRC_SEL_A::HOSC
     }
     #[doc = "Checks if the value of the field is `PLL_AUDIO0_1X`"]
     #[inline(always)]
     pub fn is_pll_audio0_1x(&self) -> bool {
-        **self == CLK_SRC_SEL_A::PLL_AUDIO0_1X
-    }
-}
-impl core::ops::Deref for CLK_SRC_SEL_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CLK_SRC_SEL_A::PLL_AUDIO0_1X
     }
 }
 #[doc = "Field `CLK_SRC_SEL` writer - Clock Source Select"]
-pub struct CLK_SRC_SEL_W<'a> {
-    w: &'a mut W,
-}
+pub type CLK_SRC_SEL_W<'a> = crate::FieldWriter<'a, u32, TPADC_CLK_SPEC, u8, CLK_SRC_SEL_A, 3, 24>;
 impl<'a> CLK_SRC_SEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CLK_SRC_SEL_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn hosc(self) -> &'a mut W {
@@ -187,12 +135,6 @@ impl<'a> CLK_SRC_SEL_W<'a> {
     pub fn pll_audio0_1x(self) -> &'a mut W {
         self.variant(CLK_SRC_SEL_A::PLL_AUDIO0_1X)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << 24)) | ((value as u32 & 7) << 24);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 31 - Gating Clock"]
@@ -210,12 +152,12 @@ impl W {
     #[doc = "Bit 31 - Gating Clock"]
     #[inline(always)]
     pub fn clk_gating(&mut self) -> CLK_GATING_W {
-        CLK_GATING_W { w: self }
+        CLK_GATING_W::new(self)
     }
     #[doc = "Bits 24:26 - Clock Source Select"]
     #[inline(always)]
     pub fn clk_src_sel(&mut self) -> CLK_SRC_SEL_W {
-        CLK_SRC_SEL_W { w: self }
+        CLK_SRC_SEL_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
