@@ -49,13 +49,9 @@ impl From<UART_RST_A> for bool {
     }
 }
 #[doc = "Fields `UART(0-5)_RST` reader - Reset"]
-pub struct UART_RST_R(crate::FieldReader<bool>);
+pub type UART_RST_R = crate::BitReader<UART_RST_A>;
 impl UART_RST_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        UART_RST_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> UART_RST_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl UART_RST_R {
     #[doc = "Checks if the value of the field is `ASSERT`"]
     #[inline(always)]
     pub fn is_assert(&self) -> bool {
-        **self == UART_RST_A::ASSERT
+        *self == UART_RST_A::ASSERT
     }
     #[doc = "Checks if the value of the field is `DEASSERT`"]
     #[inline(always)]
     pub fn is_deassert(&self) -> bool {
-        **self == UART_RST_A::DEASSERT
+        *self == UART_RST_A::DEASSERT
     }
 }
-impl core::ops::Deref for UART_RST_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `UART(0-5)_RST` const generic writer - Reset"]
-pub struct UART_RST_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> UART_RST_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: UART_RST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `UART(0-5)_RST` writer - Reset"]
+pub type UART_RST_W<'a, const O: u8> = crate::BitWriter<'a, u32, UART_BGR_SPEC, UART_RST_A, O>;
+impl<'a, const O: u8> UART_RST_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn assert(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a, const O: usize> UART_RST_W<'a, O> {
     pub fn deassert(self) -> &'a mut W {
         self.variant(UART_RST_A::DEASSERT)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 #[doc = "Gating Clock\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<UART_GATING_A> for bool {
     }
 }
 #[doc = "Fields `UART(0-5)_GATING` reader - Gating Clock"]
-pub struct UART_GATING_R(crate::FieldReader<bool>);
+pub type UART_GATING_R = crate::BitReader<UART_GATING_A>;
 impl UART_GATING_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        UART_GATING_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> UART_GATING_A {
         match self.bits {
@@ -150,31 +112,18 @@ impl UART_GATING_R {
     #[doc = "Checks if the value of the field is `MASK`"]
     #[inline(always)]
     pub fn is_mask(&self) -> bool {
-        **self == UART_GATING_A::MASK
+        *self == UART_GATING_A::MASK
     }
     #[doc = "Checks if the value of the field is `PASS`"]
     #[inline(always)]
     pub fn is_pass(&self) -> bool {
-        **self == UART_GATING_A::PASS
+        *self == UART_GATING_A::PASS
     }
 }
-impl core::ops::Deref for UART_GATING_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `UART(0-5)_GATING` const generic writer - Gating Clock"]
-pub struct UART_GATING_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> UART_GATING_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: UART_GATING_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `UART(0-5)_GATING` writer - Gating Clock"]
+pub type UART_GATING_W<'a, const O: u8> =
+    crate::BitWriter<'a, u32, UART_BGR_SPEC, UART_GATING_A, O>;
+impl<'a, const O: u8> UART_GATING_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn mask(self) -> &'a mut W {
@@ -185,27 +134,11 @@ impl<'a, const O: usize> UART_GATING_W<'a, O> {
     pub fn pass(self) -> &'a mut W {
         self.variant(UART_GATING_A::PASS)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "Reset"]
     #[inline(always)]
-    pub unsafe fn uart_rst(&self, n: usize) -> UART_RST_R {
+    pub unsafe fn uart_rst(&self, n: u8) -> UART_RST_R {
         UART_RST_R::new(((self.bits >> (n + 16)) & 1) != 0)
     }
     #[doc = "Bit 16 - Reset"]
@@ -240,7 +173,7 @@ impl R {
     }
     #[doc = "Gating Clock"]
     #[inline(always)]
-    pub unsafe fn uart_gating(&self, n: usize) -> UART_GATING_R {
+    pub unsafe fn uart_gating(&self, n: u8) -> UART_GATING_R {
         UART_GATING_R::new(((self.bits >> n) & 1) != 0)
     }
     #[doc = "Bit 0 - Gating Clock"]
@@ -277,73 +210,73 @@ impl R {
 impl W {
     #[doc = "Reset"]
     #[inline(always)]
-    pub unsafe fn uart_rst<const O: usize>(&mut self) -> UART_RST_W<O> {
-        UART_RST_W { w: self }
+    pub unsafe fn uart_rst<const O: u8>(&mut self) -> UART_RST_W<O> {
+        UART_RST_W::new(self)
     }
     #[doc = "Bit 16 - Reset"]
     #[inline(always)]
     pub fn uart0_rst(&mut self) -> UART_RST_W<16> {
-        UART_RST_W { w: self }
+        UART_RST_W::new(self)
     }
     #[doc = "Bit 17 - Reset"]
     #[inline(always)]
     pub fn uart1_rst(&mut self) -> UART_RST_W<17> {
-        UART_RST_W { w: self }
+        UART_RST_W::new(self)
     }
     #[doc = "Bit 18 - Reset"]
     #[inline(always)]
     pub fn uart2_rst(&mut self) -> UART_RST_W<18> {
-        UART_RST_W { w: self }
+        UART_RST_W::new(self)
     }
     #[doc = "Bit 19 - Reset"]
     #[inline(always)]
     pub fn uart3_rst(&mut self) -> UART_RST_W<19> {
-        UART_RST_W { w: self }
+        UART_RST_W::new(self)
     }
     #[doc = "Bit 20 - Reset"]
     #[inline(always)]
     pub fn uart4_rst(&mut self) -> UART_RST_W<20> {
-        UART_RST_W { w: self }
+        UART_RST_W::new(self)
     }
     #[doc = "Bit 21 - Reset"]
     #[inline(always)]
     pub fn uart5_rst(&mut self) -> UART_RST_W<21> {
-        UART_RST_W { w: self }
+        UART_RST_W::new(self)
     }
     #[doc = "Gating Clock"]
     #[inline(always)]
-    pub unsafe fn uart_gating<const O: usize>(&mut self) -> UART_GATING_W<O> {
-        UART_GATING_W { w: self }
+    pub unsafe fn uart_gating<const O: u8>(&mut self) -> UART_GATING_W<O> {
+        UART_GATING_W::new(self)
     }
     #[doc = "Bit 0 - Gating Clock"]
     #[inline(always)]
     pub fn uart0_gating(&mut self) -> UART_GATING_W<0> {
-        UART_GATING_W { w: self }
+        UART_GATING_W::new(self)
     }
     #[doc = "Bit 1 - Gating Clock"]
     #[inline(always)]
     pub fn uart1_gating(&mut self) -> UART_GATING_W<1> {
-        UART_GATING_W { w: self }
+        UART_GATING_W::new(self)
     }
     #[doc = "Bit 2 - Gating Clock"]
     #[inline(always)]
     pub fn uart2_gating(&mut self) -> UART_GATING_W<2> {
-        UART_GATING_W { w: self }
+        UART_GATING_W::new(self)
     }
     #[doc = "Bit 3 - Gating Clock"]
     #[inline(always)]
     pub fn uart3_gating(&mut self) -> UART_GATING_W<3> {
-        UART_GATING_W { w: self }
+        UART_GATING_W::new(self)
     }
     #[doc = "Bit 4 - Gating Clock"]
     #[inline(always)]
     pub fn uart4_gating(&mut self) -> UART_GATING_W<4> {
-        UART_GATING_W { w: self }
+        UART_GATING_W::new(self)
     }
     #[doc = "Bit 5 - Gating Clock"]
     #[inline(always)]
     pub fn uart5_gating(&mut self) -> UART_GATING_W<5> {
-        UART_GATING_W { w: self }
+        UART_GATING_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
