@@ -52,13 +52,9 @@ impl From<TASK_CHANNEL_ERROR_TYPE_A> for u8 {
     }
 }
 #[doc = "Fields `TASK_CHANNEL(0-3)_ERROR_TYPE` reader - Task Channel Error Type"]
-pub struct TASK_CHANNEL_ERROR_TYPE_R(crate::FieldReader<u8>);
+pub type TASK_CHANNEL_ERROR_TYPE_R = crate::FieldReader<u8, TASK_CHANNEL_ERROR_TYPE_A>;
 impl TASK_CHANNEL_ERROR_TYPE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        TASK_CHANNEL_ERROR_TYPE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<TASK_CHANNEL_ERROR_TYPE_A> {
         match self.bits {
@@ -71,36 +67,23 @@ impl TASK_CHANNEL_ERROR_TYPE_R {
     #[doc = "Checks if the value of the field is `ALGORITHM_NOT_SUPPORT`"]
     #[inline(always)]
     pub fn is_algorithm_not_support(&self) -> bool {
-        **self == TASK_CHANNEL_ERROR_TYPE_A::ALGORITHM_NOT_SUPPORT
+        *self == TASK_CHANNEL_ERROR_TYPE_A::ALGORITHM_NOT_SUPPORT
     }
     #[doc = "Checks if the value of the field is `DATA_LENGTH_ERROR`"]
     #[inline(always)]
     pub fn is_data_length_error(&self) -> bool {
-        **self == TASK_CHANNEL_ERROR_TYPE_A::DATA_LENGTH_ERROR
+        *self == TASK_CHANNEL_ERROR_TYPE_A::DATA_LENGTH_ERROR
     }
     #[doc = "Checks if the value of the field is `KEYSRAM_ACCESS_ERROR`"]
     #[inline(always)]
     pub fn is_keysram_access_error(&self) -> bool {
-        **self == TASK_CHANNEL_ERROR_TYPE_A::KEYSRAM_ACCESS_ERROR
+        *self == TASK_CHANNEL_ERROR_TYPE_A::KEYSRAM_ACCESS_ERROR
     }
 }
-impl core::ops::Deref for TASK_CHANNEL_ERROR_TYPE_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `TASK_CHANNEL(0-3)_ERROR_TYPE` const generic writer - Task Channel Error Type"]
-pub struct TASK_CHANNEL_ERROR_TYPE_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> TASK_CHANNEL_ERROR_TYPE_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TASK_CHANNEL_ERROR_TYPE_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
+#[doc = "Fields `TASK_CHANNEL(0-3)_ERROR_TYPE` writer - Task Channel Error Type"]
+pub type TASK_CHANNEL_ERROR_TYPE_W<'a, const O: u8> =
+    crate::FieldWriter<'a, u32, CE_ESR_SPEC, u8, TASK_CHANNEL_ERROR_TYPE_A, 4, O>;
+impl<'a, const O: u8> TASK_CHANNEL_ERROR_TYPE_W<'a, O> {
     #[doc = "Algorithm not support"]
     #[inline(always)]
     pub fn algorithm_not_support(self) -> &'a mut W {
@@ -116,17 +99,11 @@ impl<'a, const O: usize> TASK_CHANNEL_ERROR_TYPE_W<'a, O> {
     pub fn keysram_access_error(self) -> &'a mut W {
         self.variant(TASK_CHANNEL_ERROR_TYPE_A::KEYSRAM_ACCESS_ERROR)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << O)) | ((value as u32 & 0x0f) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "Task Channel Error Type"]
     #[inline(always)]
-    pub unsafe fn task_channel_error_type(&self, n: usize) -> TASK_CHANNEL_ERROR_TYPE_R {
+    pub unsafe fn task_channel_error_type(&self, n: u8) -> TASK_CHANNEL_ERROR_TYPE_R {
         TASK_CHANNEL_ERROR_TYPE_R::new(((self.bits >> (n * 4)) & 0x0f) as u8)
     }
     #[doc = "Bits 0:3 - Task Channel Error Type"]
@@ -153,30 +130,28 @@ impl R {
 impl W {
     #[doc = "Task Channel Error Type"]
     #[inline(always)]
-    pub unsafe fn task_channel_error_type<const O: usize>(
-        &mut self,
-    ) -> TASK_CHANNEL_ERROR_TYPE_W<O> {
-        TASK_CHANNEL_ERROR_TYPE_W { w: self }
+    pub unsafe fn task_channel_error_type<const O: u8>(&mut self) -> TASK_CHANNEL_ERROR_TYPE_W<O> {
+        TASK_CHANNEL_ERROR_TYPE_W::new(self)
     }
     #[doc = "Bits 0:3 - Task Channel Error Type"]
     #[inline(always)]
     pub fn task_channel0_error_type(&mut self) -> TASK_CHANNEL_ERROR_TYPE_W<0> {
-        TASK_CHANNEL_ERROR_TYPE_W { w: self }
+        TASK_CHANNEL_ERROR_TYPE_W::new(self)
     }
     #[doc = "Bits 4:7 - Task Channel Error Type"]
     #[inline(always)]
     pub fn task_channel1_error_type(&mut self) -> TASK_CHANNEL_ERROR_TYPE_W<4> {
-        TASK_CHANNEL_ERROR_TYPE_W { w: self }
+        TASK_CHANNEL_ERROR_TYPE_W::new(self)
     }
     #[doc = "Bits 8:11 - Task Channel Error Type"]
     #[inline(always)]
     pub fn task_channel2_error_type(&mut self) -> TASK_CHANNEL_ERROR_TYPE_W<8> {
-        TASK_CHANNEL_ERROR_TYPE_W { w: self }
+        TASK_CHANNEL_ERROR_TYPE_W::new(self)
     }
     #[doc = "Bits 12:15 - Task Channel Error Type"]
     #[inline(always)]
     pub fn task_channel3_error_type(&mut self) -> TASK_CHANNEL_ERROR_TYPE_W<12> {
-        TASK_CHANNEL_ERROR_TYPE_W { w: self }
+        TASK_CHANNEL_ERROR_TYPE_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
