@@ -35,42 +35,9 @@ impl From<crate::W<CE_TLR_SPEC>> for W {
     }
 }
 #[doc = "Field `TASK_LOAD` reader - Task Load\n\nWhen set, the CE can load the descriptor of task if the task FIFO is not full."]
-pub struct TASK_LOAD_R(crate::FieldReader<bool>);
-impl TASK_LOAD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TASK_LOAD_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TASK_LOAD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TASK_LOAD_R = crate::BitReader<bool>;
 #[doc = "Field `TASK_LOAD` writer - Task Load\n\nWhen set, the CE can load the descriptor of task if the task FIFO is not full."]
-pub struct TASK_LOAD_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TASK_LOAD_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
-}
+pub type TASK_LOAD_W<'a> = crate::BitWriter<'a, u32, CE_TLR_SPEC, bool, 0>;
 impl R {
     #[doc = "Bit 0 - Task Load\n\nWhen set, the CE can load the descriptor of task if the task FIFO is not full."]
     #[inline(always)]
@@ -82,7 +49,7 @@ impl W {
     #[doc = "Bit 0 - Task Load\n\nWhen set, the CE can load the descriptor of task if the task FIFO is not full."]
     #[inline(always)]
     pub fn task_load(&mut self) -> TASK_LOAD_W {
-        TASK_LOAD_W { w: self }
+        TASK_LOAD_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
