@@ -35,32 +35,9 @@ impl From<crate::W<CE_TPR_SPEC>> for W {
     }
 }
 #[doc = "Field `TP_NUM` reader - It indicates the throughput writing to this register at last time.\n\nWriting to this register will clear it to 0."]
-pub struct TP_NUM_R(crate::FieldReader<u32>);
-impl TP_NUM_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u32) -> Self {
-        TP_NUM_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TP_NUM_R {
-    type Target = crate::FieldReader<u32>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TP_NUM_R = crate::FieldReader<u32, u32>;
 #[doc = "Field `TP_NUM` writer - It indicates the throughput writing to this register at last time.\n\nWriting to this register will clear it to 0."]
-pub struct TP_NUM_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TP_NUM_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = value;
-        self.w
-    }
-}
+pub type TP_NUM_W<'a> = crate::FieldWriter<'a, u32, CE_TPR_SPEC, u32, u32, 32, 0>;
 impl R {
     #[doc = "Bits 0:31 - It indicates the throughput writing to this register at last time.\n\nWriting to this register will clear it to 0."]
     #[inline(always)]
@@ -72,7 +49,7 @@ impl W {
     #[doc = "Bits 0:31 - It indicates the throughput writing to this register at last time.\n\nWriting to this register will clear it to 0."]
     #[inline(always)]
     pub fn tp_num(&mut self) -> TP_NUM_W {
-        TP_NUM_W { w: self }
+        TP_NUM_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
