@@ -49,13 +49,9 @@ impl From<DMA_EN_A> for bool {
     }
 }
 #[doc = "Field `DMA_EN` reader - DMA Channel Enable"]
-pub struct DMA_EN_R(crate::FieldReader<bool>);
+pub type DMA_EN_R = crate::BitReader<DMA_EN_A>;
 impl DMA_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DMA_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DMA_EN_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl DMA_EN_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        **self == DMA_EN_A::DISABLED
+        *self == DMA_EN_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        **self == DMA_EN_A::ENABLED
-    }
-}
-impl core::ops::Deref for DMA_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DMA_EN_A::ENABLED
     }
 }
 #[doc = "Field `DMA_EN` writer - DMA Channel Enable"]
-pub struct DMA_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type DMA_EN_W<'a> = crate::BitWriter<'a, u32, DMAC_EN_REG_SPEC, DMA_EN_A, 0>;
 impl<'a> DMA_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DMA_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disabled(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> DMA_EN_W<'a> {
     pub fn enabled(self) -> &'a mut W {
         self.variant(DMA_EN_A::ENABLED)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 0 - DMA Channel Enable"]
@@ -129,7 +95,7 @@ impl W {
     #[doc = "Bit 0 - DMA Channel Enable"]
     #[inline(always)]
     pub fn dma_en(&mut self) -> DMA_EN_W {
-        DMA_EN_W { w: self }
+        DMA_EN_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
