@@ -49,13 +49,9 @@ impl From<DMA_HLAF_IRQ_PEND_A> for bool {
     }
 }
 #[doc = "Fields `DMA(8-15)_HLAF_IRQ_PEND` reader - The IRQ pending bit for the half package interrupt of DMA"]
-pub struct DMA_HLAF_IRQ_PEND_R(crate::FieldReader<bool>);
+pub type DMA_HLAF_IRQ_PEND_R = crate::BitReader<DMA_HLAF_IRQ_PEND_A>;
 impl DMA_HLAF_IRQ_PEND_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DMA_HLAF_IRQ_PEND_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DMA_HLAF_IRQ_PEND_A {
         match self.bits {
@@ -66,31 +62,18 @@ impl DMA_HLAF_IRQ_PEND_R {
     #[doc = "Checks if the value of the field is `NO_EFFECT`"]
     #[inline(always)]
     pub fn is_no_effect(&self) -> bool {
-        **self == DMA_HLAF_IRQ_PEND_A::NO_EFFECT
+        *self == DMA_HLAF_IRQ_PEND_A::NO_EFFECT
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == DMA_HLAF_IRQ_PEND_A::PENDING
+        *self == DMA_HLAF_IRQ_PEND_A::PENDING
     }
 }
-impl core::ops::Deref for DMA_HLAF_IRQ_PEND_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `DMA(8-15)_HLAF_IRQ_PEND` const generic writer - The IRQ pending bit for the half package interrupt of DMA"]
-pub struct DMA_HLAF_IRQ_PEND_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> DMA_HLAF_IRQ_PEND_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DMA_HLAF_IRQ_PEND_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `DMA(8-15)_HLAF_IRQ_PEND` writer - The IRQ pending bit for the half package interrupt of DMA"]
+pub type DMA_HLAF_IRQ_PEND_W<'a, const O: u8> =
+    crate::BitWriter<'a, u32, DMAC_IRQ_PEND_REG1_SPEC, DMA_HLAF_IRQ_PEND_A, O>;
+impl<'a, const O: u8> DMA_HLAF_IRQ_PEND_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_effect(self) -> &'a mut W {
@@ -101,22 +84,6 @@ impl<'a, const O: usize> DMA_HLAF_IRQ_PEND_W<'a, O> {
     pub fn pending(self) -> &'a mut W {
         self.variant(DMA_HLAF_IRQ_PEND_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 #[doc = "The IRQ pending bit for the package end interrupt of DMA\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +100,9 @@ impl From<DMA_PKG_IRQ_PEND_A> for bool {
     }
 }
 #[doc = "Fields `DMA(8-15)_PKG_IRQ_PEND` reader - The IRQ pending bit for the package end interrupt of DMA"]
-pub struct DMA_PKG_IRQ_PEND_R(crate::FieldReader<bool>);
+pub type DMA_PKG_IRQ_PEND_R = crate::BitReader<DMA_PKG_IRQ_PEND_A>;
 impl DMA_PKG_IRQ_PEND_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DMA_PKG_IRQ_PEND_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DMA_PKG_IRQ_PEND_A {
         match self.bits {
@@ -150,31 +113,18 @@ impl DMA_PKG_IRQ_PEND_R {
     #[doc = "Checks if the value of the field is `NO_EFFECT`"]
     #[inline(always)]
     pub fn is_no_effect(&self) -> bool {
-        **self == DMA_PKG_IRQ_PEND_A::NO_EFFECT
+        *self == DMA_PKG_IRQ_PEND_A::NO_EFFECT
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == DMA_PKG_IRQ_PEND_A::PENDING
+        *self == DMA_PKG_IRQ_PEND_A::PENDING
     }
 }
-impl core::ops::Deref for DMA_PKG_IRQ_PEND_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `DMA(8-15)_PKG_IRQ_PEND` const generic writer - The IRQ pending bit for the package end interrupt of DMA"]
-pub struct DMA_PKG_IRQ_PEND_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> DMA_PKG_IRQ_PEND_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DMA_PKG_IRQ_PEND_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `DMA(8-15)_PKG_IRQ_PEND` writer - The IRQ pending bit for the package end interrupt of DMA"]
+pub type DMA_PKG_IRQ_PEND_W<'a, const O: u8> =
+    crate::BitWriter<'a, u32, DMAC_IRQ_PEND_REG1_SPEC, DMA_PKG_IRQ_PEND_A, O>;
+impl<'a, const O: u8> DMA_PKG_IRQ_PEND_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_effect(self) -> &'a mut W {
@@ -185,22 +135,6 @@ impl<'a, const O: usize> DMA_PKG_IRQ_PEND_W<'a, O> {
     pub fn pending(self) -> &'a mut W {
         self.variant(DMA_PKG_IRQ_PEND_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 #[doc = "The IRQ pending bit for the queue end interrupt of DMA\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -217,13 +151,9 @@ impl From<DMA_QUEUE_IRQ_PEND_A> for bool {
     }
 }
 #[doc = "Fields `DMA(8-15)_QUEUE_IRQ_PEND` reader - The IRQ pending bit for the queue end interrupt of DMA"]
-pub struct DMA_QUEUE_IRQ_PEND_R(crate::FieldReader<bool>);
+pub type DMA_QUEUE_IRQ_PEND_R = crate::BitReader<DMA_QUEUE_IRQ_PEND_A>;
 impl DMA_QUEUE_IRQ_PEND_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DMA_QUEUE_IRQ_PEND_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DMA_QUEUE_IRQ_PEND_A {
         match self.bits {
@@ -234,31 +164,18 @@ impl DMA_QUEUE_IRQ_PEND_R {
     #[doc = "Checks if the value of the field is `NO_EFFECT`"]
     #[inline(always)]
     pub fn is_no_effect(&self) -> bool {
-        **self == DMA_QUEUE_IRQ_PEND_A::NO_EFFECT
+        *self == DMA_QUEUE_IRQ_PEND_A::NO_EFFECT
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == DMA_QUEUE_IRQ_PEND_A::PENDING
+        *self == DMA_QUEUE_IRQ_PEND_A::PENDING
     }
 }
-impl core::ops::Deref for DMA_QUEUE_IRQ_PEND_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `DMA(8-15)_QUEUE_IRQ_PEND` const generic writer - The IRQ pending bit for the queue end interrupt of DMA"]
-pub struct DMA_QUEUE_IRQ_PEND_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> DMA_QUEUE_IRQ_PEND_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DMA_QUEUE_IRQ_PEND_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `DMA(8-15)_QUEUE_IRQ_PEND` writer - The IRQ pending bit for the queue end interrupt of DMA"]
+pub type DMA_QUEUE_IRQ_PEND_W<'a, const O: u8> =
+    crate::BitWriter<'a, u32, DMAC_IRQ_PEND_REG1_SPEC, DMA_QUEUE_IRQ_PEND_A, O>;
+impl<'a, const O: u8> DMA_QUEUE_IRQ_PEND_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_effect(self) -> &'a mut W {
@@ -269,27 +186,11 @@ impl<'a, const O: usize> DMA_QUEUE_IRQ_PEND_W<'a, O> {
     pub fn pending(self) -> &'a mut W {
         self.variant(DMA_QUEUE_IRQ_PEND_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
-    pub unsafe fn dma_hlaf_irq_pend(&self, n: usize) -> DMA_HLAF_IRQ_PEND_R {
+    pub unsafe fn dma_hlaf_irq_pend(&self, n: u8) -> DMA_HLAF_IRQ_PEND_R {
         DMA_HLAF_IRQ_PEND_R::new(((self.bits >> ((n - 8) * 4)) & 1) != 0)
     }
     #[doc = "Bit 0 - The IRQ pending bit for the half package interrupt of DMA"]
@@ -334,7 +235,7 @@ impl R {
     }
     #[doc = "The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
-    pub unsafe fn dma_pkg_irq_pend(&self, n: usize) -> DMA_PKG_IRQ_PEND_R {
+    pub unsafe fn dma_pkg_irq_pend(&self, n: u8) -> DMA_PKG_IRQ_PEND_R {
         DMA_PKG_IRQ_PEND_R::new(((self.bits >> ((n - 8) * 4 + 1)) & 1) != 0)
     }
     #[doc = "Bit 1 - The IRQ pending bit for the package end interrupt of DMA"]
@@ -379,7 +280,7 @@ impl R {
     }
     #[doc = "The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
-    pub unsafe fn dma_queue_irq_pend(&self, n: usize) -> DMA_QUEUE_IRQ_PEND_R {
+    pub unsafe fn dma_queue_irq_pend(&self, n: u8) -> DMA_QUEUE_IRQ_PEND_R {
         DMA_QUEUE_IRQ_PEND_R::new(((self.bits >> ((n - 8) * 4 + 2)) & 1) != 0)
     }
     #[doc = "Bit 2 - The IRQ pending bit for the queue end interrupt of DMA"]
@@ -426,138 +327,138 @@ impl R {
 impl W {
     #[doc = "The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
-    pub unsafe fn dma_hlaf_irq_pend<const O: usize>(&mut self) -> DMA_HLAF_IRQ_PEND_W<O> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+    pub unsafe fn dma_hlaf_irq_pend<const O: u8>(&mut self) -> DMA_HLAF_IRQ_PEND_W<O> {
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 0 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma8_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<0> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 4 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma9_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<4> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 8 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma10_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<8> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 12 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma11_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<12> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 16 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma12_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<16> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 20 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma13_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<20> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 24 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma14_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<24> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 28 - The IRQ pending bit for the half package interrupt of DMA"]
     #[inline(always)]
     pub fn dma15_hlaf_irq_pend(&mut self) -> DMA_HLAF_IRQ_PEND_W<28> {
-        DMA_HLAF_IRQ_PEND_W { w: self }
+        DMA_HLAF_IRQ_PEND_W::new(self)
     }
     #[doc = "The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
-    pub unsafe fn dma_pkg_irq_pend<const O: usize>(&mut self) -> DMA_PKG_IRQ_PEND_W<O> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+    pub unsafe fn dma_pkg_irq_pend<const O: u8>(&mut self) -> DMA_PKG_IRQ_PEND_W<O> {
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 1 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma8_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<1> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 5 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma9_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<5> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 9 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma10_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<9> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 13 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma11_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<13> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 17 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma12_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<17> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 21 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma13_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<21> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 25 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma14_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<25> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 29 - The IRQ pending bit for the package end interrupt of DMA"]
     #[inline(always)]
     pub fn dma15_pkg_irq_pend(&mut self) -> DMA_PKG_IRQ_PEND_W<29> {
-        DMA_PKG_IRQ_PEND_W { w: self }
+        DMA_PKG_IRQ_PEND_W::new(self)
     }
     #[doc = "The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
-    pub unsafe fn dma_queue_irq_pend<const O: usize>(&mut self) -> DMA_QUEUE_IRQ_PEND_W<O> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+    pub unsafe fn dma_queue_irq_pend<const O: u8>(&mut self) -> DMA_QUEUE_IRQ_PEND_W<O> {
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 2 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma8_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<2> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 6 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma9_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<6> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 10 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma10_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<10> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 14 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma11_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<14> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 18 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma12_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<18> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 22 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma13_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<22> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 26 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma14_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<26> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Bit 30 - The IRQ pending bit for the queue end interrupt of DMA"]
     #[inline(always)]
     pub fn dma15_queue_irq_pend(&mut self) -> DMA_QUEUE_IRQ_PEND_W<30> {
-        DMA_QUEUE_IRQ_PEND_W { w: self }
+        DMA_QUEUE_IRQ_PEND_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
