@@ -49,13 +49,9 @@ impl From<RGMII_LINK_STA_P_A> for bool {
     }
 }
 #[doc = "Field `RGMII_LINK_STA_P` reader - RMII Link Status Changed Interrupt Pending"]
-pub struct RGMII_LINK_STA_P_R(crate::FieldReader<bool>);
+pub type RGMII_LINK_STA_P_R = crate::BitReader<RGMII_LINK_STA_P_A>;
 impl RGMII_LINK_STA_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RGMII_LINK_STA_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RGMII_LINK_STA_P_A {
         match self.bits {
@@ -66,31 +62,18 @@ impl RGMII_LINK_STA_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == RGMII_LINK_STA_P_A::NO_PENDING
+        *self == RGMII_LINK_STA_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == RGMII_LINK_STA_P_A::PENDING
-    }
-}
-impl core::ops::Deref for RGMII_LINK_STA_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RGMII_LINK_STA_P_A::PENDING
     }
 }
 #[doc = "Field `RGMII_LINK_STA_P` writer - RMII Link Status Changed Interrupt Pending"]
-pub struct RGMII_LINK_STA_P_W<'a> {
-    w: &'a mut W,
-}
+pub type RGMII_LINK_STA_P_W<'a> =
+    crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, RGMII_LINK_STA_P_A, 16>;
 impl<'a> RGMII_LINK_STA_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RGMII_LINK_STA_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -101,22 +84,6 @@ impl<'a> RGMII_LINK_STA_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(RGMII_LINK_STA_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
-        self.w
-    }
 }
 #[doc = "RX DMA Filled First Data Buffer of the Receive Frame Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +100,9 @@ impl From<RX_EARLY_P_A> for bool {
     }
 }
 #[doc = "Field `RX_EARLY_P` reader - RX DMA Filled First Data Buffer of the Receive Frame Interrupt Pending"]
-pub struct RX_EARLY_P_R(crate::FieldReader<bool>);
+pub type RX_EARLY_P_R = crate::BitReader<RX_EARLY_P_A>;
 impl RX_EARLY_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_EARLY_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_EARLY_P_A {
         match self.bits {
@@ -150,31 +113,17 @@ impl RX_EARLY_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == RX_EARLY_P_A::NO_PENDING
+        *self == RX_EARLY_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == RX_EARLY_P_A::PENDING
-    }
-}
-impl core::ops::Deref for RX_EARLY_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_EARLY_P_A::PENDING
     }
 }
 #[doc = "Field `RX_EARLY_P` writer - RX DMA Filled First Data Buffer of the Receive Frame Interrupt Pending"]
-pub struct RX_EARLY_P_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_EARLY_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, RX_EARLY_P_A, 13>;
 impl<'a> RX_EARLY_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_EARLY_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -185,22 +134,6 @@ impl<'a> RX_EARLY_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(RX_EARLY_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
-        self.w
-    }
 }
 #[doc = "RX FIFO Overflow Error Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -217,13 +150,9 @@ impl From<RX_OVERFLOW_P_A> for bool {
     }
 }
 #[doc = "Field `RX_OVERFLOW_P` reader - RX FIFO Overflow Error Interrupt Pending"]
-pub struct RX_OVERFLOW_P_R(crate::FieldReader<bool>);
+pub type RX_OVERFLOW_P_R = crate::BitReader<RX_OVERFLOW_P_A>;
 impl RX_OVERFLOW_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_OVERFLOW_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_OVERFLOW_P_A {
         match self.bits {
@@ -234,31 +163,17 @@ impl RX_OVERFLOW_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == RX_OVERFLOW_P_A::NO_PENDING
+        *self == RX_OVERFLOW_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == RX_OVERFLOW_P_A::PENDING
-    }
-}
-impl core::ops::Deref for RX_OVERFLOW_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_OVERFLOW_P_A::PENDING
     }
 }
 #[doc = "Field `RX_OVERFLOW_P` writer - RX FIFO Overflow Error Interrupt Pending"]
-pub struct RX_OVERFLOW_P_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_OVERFLOW_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, RX_OVERFLOW_P_A, 12>;
 impl<'a> RX_OVERFLOW_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_OVERFLOW_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -269,22 +184,6 @@ impl<'a> RX_OVERFLOW_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(RX_OVERFLOW_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
-        self.w
-    }
 }
 #[doc = "RX Timeout Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -301,13 +200,9 @@ impl From<RX_TIMEOUT_P_A> for bool {
     }
 }
 #[doc = "Field `RX_TIMEOUT_P` reader - RX Timeout Interrupt Pending"]
-pub struct RX_TIMEOUT_P_R(crate::FieldReader<bool>);
+pub type RX_TIMEOUT_P_R = crate::BitReader<RX_TIMEOUT_P_A>;
 impl RX_TIMEOUT_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_TIMEOUT_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_TIMEOUT_P_A {
         match self.bits {
@@ -318,31 +213,17 @@ impl RX_TIMEOUT_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == RX_TIMEOUT_P_A::NO_PENDING
+        *self == RX_TIMEOUT_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == RX_TIMEOUT_P_A::PENDING
-    }
-}
-impl core::ops::Deref for RX_TIMEOUT_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_TIMEOUT_P_A::PENDING
     }
 }
 #[doc = "Field `RX_TIMEOUT_P` writer - RX Timeout Interrupt Pending"]
-pub struct RX_TIMEOUT_P_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_TIMEOUT_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, RX_TIMEOUT_P_A, 11>;
 impl<'a> RX_TIMEOUT_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_TIMEOUT_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -353,60 +234,11 @@ impl<'a> RX_TIMEOUT_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(RX_TIMEOUT_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
-        self.w
-    }
 }
 #[doc = "Field `RX_DMA_STOPPED_P` reader - When this bit asserted, the RX DMA FSM is stopped."]
-pub struct RX_DMA_STOPPED_P_R(crate::FieldReader<bool>);
-impl RX_DMA_STOPPED_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_DMA_STOPPED_P_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RX_DMA_STOPPED_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RX_DMA_STOPPED_P_R = crate::BitReader<bool>;
 #[doc = "Field `RX_DMA_STOPPED_P` writer - When this bit asserted, the RX DMA FSM is stopped."]
-pub struct RX_DMA_STOPPED_P_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RX_DMA_STOPPED_P_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
-        self.w
-    }
-}
+pub type RX_DMA_STOPPED_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, bool, 10>;
 #[doc = "RX Buffer UA Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum RX_BUF_UA_P_A {
@@ -422,13 +254,9 @@ impl From<RX_BUF_UA_P_A> for bool {
     }
 }
 #[doc = "Field `RX_BUF_UA_P` reader - RX Buffer UA Interrupt Pending"]
-pub struct RX_BUF_UA_P_R(crate::FieldReader<bool>);
+pub type RX_BUF_UA_P_R = crate::BitReader<RX_BUF_UA_P_A>;
 impl RX_BUF_UA_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_BUF_UA_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_BUF_UA_P_A {
         match self.bits {
@@ -439,31 +267,17 @@ impl RX_BUF_UA_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == RX_BUF_UA_P_A::NO_PENDING
+        *self == RX_BUF_UA_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == RX_BUF_UA_P_A::PENDING
-    }
-}
-impl core::ops::Deref for RX_BUF_UA_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_BUF_UA_P_A::PENDING
     }
 }
 #[doc = "Field `RX_BUF_UA_P` writer - RX Buffer UA Interrupt Pending"]
-pub struct RX_BUF_UA_P_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_BUF_UA_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, RX_BUF_UA_P_A, 9>;
 impl<'a> RX_BUF_UA_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_BUF_UA_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -474,22 +288,6 @@ impl<'a> RX_BUF_UA_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(RX_BUF_UA_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
-        self.w
-    }
 }
 #[doc = "Frame RX Completed Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -506,13 +304,9 @@ impl From<RX_P_A> for bool {
     }
 }
 #[doc = "Field `RX_P` reader - Frame RX Completed Interrupt Pending"]
-pub struct RX_P_R(crate::FieldReader<bool>);
+pub type RX_P_R = crate::BitReader<RX_P_A>;
 impl RX_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_P_A {
         match self.bits {
@@ -523,31 +317,17 @@ impl RX_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == RX_P_A::NO_PENDING
+        *self == RX_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == RX_P_A::PENDING
-    }
-}
-impl core::ops::Deref for RX_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_P_A::PENDING
     }
 }
 #[doc = "Field `RX_P` writer - Frame RX Completed Interrupt Pending"]
-pub struct RX_P_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, RX_P_A, 8>;
 impl<'a> RX_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -558,22 +338,6 @@ impl<'a> RX_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(RX_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
-        self.w
-    }
 }
 #[doc = "Total interrupt pending which the frame is transmitted to FIFO\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -590,13 +354,9 @@ impl From<TX_EARLY_P_A> for bool {
     }
 }
 #[doc = "Field `TX_EARLY_P` reader - Total interrupt pending which the frame is transmitted to FIFO"]
-pub struct TX_EARLY_P_R(crate::FieldReader<bool>);
+pub type TX_EARLY_P_R = crate::BitReader<TX_EARLY_P_A>;
 impl TX_EARLY_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_EARLY_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_EARLY_P_A {
         match self.bits {
@@ -607,31 +367,17 @@ impl TX_EARLY_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == TX_EARLY_P_A::NO_PENDING
+        *self == TX_EARLY_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == TX_EARLY_P_A::PENDING
-    }
-}
-impl core::ops::Deref for TX_EARLY_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_EARLY_P_A::PENDING
     }
 }
 #[doc = "Field `TX_EARLY_P` writer - Total interrupt pending which the frame is transmitted to FIFO"]
-pub struct TX_EARLY_P_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_EARLY_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, TX_EARLY_P_A, 5>;
 impl<'a> TX_EARLY_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_EARLY_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -642,22 +388,6 @@ impl<'a> TX_EARLY_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(TX_EARLY_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
-        self.w
-    }
 }
 #[doc = "TX FIFO Underflow Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -674,13 +404,9 @@ impl From<TX_UNDERFLOW_P_A> for bool {
     }
 }
 #[doc = "Field `TX_UNDERFLOW_P` reader - TX FIFO Underflow Interrupt Pending"]
-pub struct TX_UNDERFLOW_P_R(crate::FieldReader<bool>);
+pub type TX_UNDERFLOW_P_R = crate::BitReader<TX_UNDERFLOW_P_A>;
 impl TX_UNDERFLOW_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_UNDERFLOW_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_UNDERFLOW_P_A {
         match self.bits {
@@ -691,31 +417,17 @@ impl TX_UNDERFLOW_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == TX_UNDERFLOW_P_A::NO_PENDING
+        *self == TX_UNDERFLOW_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == TX_UNDERFLOW_P_A::PENDING
-    }
-}
-impl core::ops::Deref for TX_UNDERFLOW_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_UNDERFLOW_P_A::PENDING
     }
 }
 #[doc = "Field `TX_UNDERFLOW_P` writer - TX FIFO Underflow Interrupt Pending"]
-pub struct TX_UNDERFLOW_P_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_UNDERFLOW_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, TX_UNDERFLOW_P_A, 4>;
 impl<'a> TX_UNDERFLOW_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_UNDERFLOW_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -726,22 +438,6 @@ impl<'a> TX_UNDERFLOW_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(TX_UNDERFLOW_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
-        self.w
-    }
 }
 #[doc = "Transmitter Timeout Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -758,13 +454,9 @@ impl From<TX_TIMEOUT_P_A> for bool {
     }
 }
 #[doc = "Field `TX_TIMEOUT_P` reader - Transmitter Timeout Interrupt Pending"]
-pub struct TX_TIMEOUT_P_R(crate::FieldReader<bool>);
+pub type TX_TIMEOUT_P_R = crate::BitReader<TX_TIMEOUT_P_A>;
 impl TX_TIMEOUT_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_TIMEOUT_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_TIMEOUT_P_A {
         match self.bits {
@@ -775,31 +467,17 @@ impl TX_TIMEOUT_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == TX_TIMEOUT_P_A::NO_PENDING
+        *self == TX_TIMEOUT_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == TX_TIMEOUT_P_A::PENDING
-    }
-}
-impl core::ops::Deref for TX_TIMEOUT_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_TIMEOUT_P_A::PENDING
     }
 }
 #[doc = "Field `TX_TIMEOUT_P` writer - Transmitter Timeout Interrupt Pending"]
-pub struct TX_TIMEOUT_P_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_TIMEOUT_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, TX_TIMEOUT_P_A, 3>;
 impl<'a> TX_TIMEOUT_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_TIMEOUT_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -810,22 +488,6 @@ impl<'a> TX_TIMEOUT_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(TX_TIMEOUT_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
-        self.w
-    }
 }
 #[doc = "TX Buffer UA Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -842,13 +504,9 @@ impl From<TX_BUF_UA_P_A> for bool {
     }
 }
 #[doc = "Field `TX_BUF_UA_P` reader - TX Buffer UA Interrupt Pending"]
-pub struct TX_BUF_UA_P_R(crate::FieldReader<bool>);
+pub type TX_BUF_UA_P_R = crate::BitReader<TX_BUF_UA_P_A>;
 impl TX_BUF_UA_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_BUF_UA_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_BUF_UA_P_A {
         match self.bits {
@@ -859,31 +517,17 @@ impl TX_BUF_UA_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == TX_BUF_UA_P_A::NO_PENDING
+        *self == TX_BUF_UA_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == TX_BUF_UA_P_A::PENDING
-    }
-}
-impl core::ops::Deref for TX_BUF_UA_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_BUF_UA_P_A::PENDING
     }
 }
 #[doc = "Field `TX_BUF_UA_P` writer - TX Buffer UA Interrupt Pending"]
-pub struct TX_BUF_UA_P_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_BUF_UA_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, TX_BUF_UA_P_A, 2>;
 impl<'a> TX_BUF_UA_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_BUF_UA_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -894,22 +538,6 @@ impl<'a> TX_BUF_UA_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(TX_BUF_UA_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
-        self.w
-    }
 }
 #[doc = "Transmission DMA Stopped Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -926,13 +554,9 @@ impl From<TX_DMA_STOPPED_P_A> for bool {
     }
 }
 #[doc = "Field `TX_DMA_STOPPED_P` reader - Transmission DMA Stopped Interrupt Pending"]
-pub struct TX_DMA_STOPPED_P_R(crate::FieldReader<bool>);
+pub type TX_DMA_STOPPED_P_R = crate::BitReader<TX_DMA_STOPPED_P_A>;
 impl TX_DMA_STOPPED_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_DMA_STOPPED_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_DMA_STOPPED_P_A {
         match self.bits {
@@ -943,31 +567,18 @@ impl TX_DMA_STOPPED_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == TX_DMA_STOPPED_P_A::NO_PENDING
+        *self == TX_DMA_STOPPED_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == TX_DMA_STOPPED_P_A::PENDING
-    }
-}
-impl core::ops::Deref for TX_DMA_STOPPED_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_DMA_STOPPED_P_A::PENDING
     }
 }
 #[doc = "Field `TX_DMA_STOPPED_P` writer - Transmission DMA Stopped Interrupt Pending"]
-pub struct TX_DMA_STOPPED_P_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_DMA_STOPPED_P_W<'a> =
+    crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, TX_DMA_STOPPED_P_A, 1>;
 impl<'a> TX_DMA_STOPPED_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_DMA_STOPPED_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -978,22 +589,6 @@ impl<'a> TX_DMA_STOPPED_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(TX_DMA_STOPPED_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
-        self.w
-    }
 }
 #[doc = "Frame Transmission Interrupt Pending\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -1010,13 +605,9 @@ impl From<TX_P_A> for bool {
     }
 }
 #[doc = "Field `TX_P` reader - Frame Transmission Interrupt Pending"]
-pub struct TX_P_R(crate::FieldReader<bool>);
+pub type TX_P_R = crate::BitReader<TX_P_A>;
 impl TX_P_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_P_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_P_A {
         match self.bits {
@@ -1027,31 +618,17 @@ impl TX_P_R {
     #[doc = "Checks if the value of the field is `NO_PENDING`"]
     #[inline(always)]
     pub fn is_no_pending(&self) -> bool {
-        **self == TX_P_A::NO_PENDING
+        *self == TX_P_A::NO_PENDING
     }
     #[doc = "Checks if the value of the field is `PENDING`"]
     #[inline(always)]
     pub fn is_pending(&self) -> bool {
-        **self == TX_P_A::PENDING
-    }
-}
-impl core::ops::Deref for TX_P_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_P_A::PENDING
     }
 }
 #[doc = "Field `TX_P` writer - Frame Transmission Interrupt Pending"]
-pub struct TX_P_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_P_W<'a> = crate::BitWriter1C<'a, u32, EMAC_INT_STA_SPEC, TX_P_A, 0>;
 impl<'a> TX_P_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_P_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_pending(self) -> &'a mut W {
@@ -1062,22 +639,6 @@ impl<'a> TX_P_W<'a> {
     pub fn pending(self) -> &'a mut W {
         self.variant(TX_P_A::PENDING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 16 - RMII Link Status Changed Interrupt Pending"]
@@ -1150,67 +711,67 @@ impl W {
     #[doc = "Bit 16 - RMII Link Status Changed Interrupt Pending"]
     #[inline(always)]
     pub fn rgmii_link_sta_p(&mut self) -> RGMII_LINK_STA_P_W {
-        RGMII_LINK_STA_P_W { w: self }
+        RGMII_LINK_STA_P_W::new(self)
     }
     #[doc = "Bit 13 - RX DMA Filled First Data Buffer of the Receive Frame Interrupt Pending"]
     #[inline(always)]
     pub fn rx_early_p(&mut self) -> RX_EARLY_P_W {
-        RX_EARLY_P_W { w: self }
+        RX_EARLY_P_W::new(self)
     }
     #[doc = "Bit 12 - RX FIFO Overflow Error Interrupt Pending"]
     #[inline(always)]
     pub fn rx_overflow_p(&mut self) -> RX_OVERFLOW_P_W {
-        RX_OVERFLOW_P_W { w: self }
+        RX_OVERFLOW_P_W::new(self)
     }
     #[doc = "Bit 11 - RX Timeout Interrupt Pending"]
     #[inline(always)]
     pub fn rx_timeout_p(&mut self) -> RX_TIMEOUT_P_W {
-        RX_TIMEOUT_P_W { w: self }
+        RX_TIMEOUT_P_W::new(self)
     }
     #[doc = "Bit 10 - When this bit asserted, the RX DMA FSM is stopped."]
     #[inline(always)]
     pub fn rx_dma_stopped_p(&mut self) -> RX_DMA_STOPPED_P_W {
-        RX_DMA_STOPPED_P_W { w: self }
+        RX_DMA_STOPPED_P_W::new(self)
     }
     #[doc = "Bit 9 - RX Buffer UA Interrupt Pending"]
     #[inline(always)]
     pub fn rx_buf_ua_p(&mut self) -> RX_BUF_UA_P_W {
-        RX_BUF_UA_P_W { w: self }
+        RX_BUF_UA_P_W::new(self)
     }
     #[doc = "Bit 8 - Frame RX Completed Interrupt Pending"]
     #[inline(always)]
     pub fn rx_p(&mut self) -> RX_P_W {
-        RX_P_W { w: self }
+        RX_P_W::new(self)
     }
     #[doc = "Bit 5 - Total interrupt pending which the frame is transmitted to FIFO"]
     #[inline(always)]
     pub fn tx_early_p(&mut self) -> TX_EARLY_P_W {
-        TX_EARLY_P_W { w: self }
+        TX_EARLY_P_W::new(self)
     }
     #[doc = "Bit 4 - TX FIFO Underflow Interrupt Pending"]
     #[inline(always)]
     pub fn tx_underflow_p(&mut self) -> TX_UNDERFLOW_P_W {
-        TX_UNDERFLOW_P_W { w: self }
+        TX_UNDERFLOW_P_W::new(self)
     }
     #[doc = "Bit 3 - Transmitter Timeout Interrupt Pending"]
     #[inline(always)]
     pub fn tx_timeout_p(&mut self) -> TX_TIMEOUT_P_W {
-        TX_TIMEOUT_P_W { w: self }
+        TX_TIMEOUT_P_W::new(self)
     }
     #[doc = "Bit 2 - TX Buffer UA Interrupt Pending"]
     #[inline(always)]
     pub fn tx_buf_ua_p(&mut self) -> TX_BUF_UA_P_W {
-        TX_BUF_UA_P_W { w: self }
+        TX_BUF_UA_P_W::new(self)
     }
     #[doc = "Bit 1 - Transmission DMA Stopped Interrupt Pending"]
     #[inline(always)]
     pub fn tx_dma_stopped_p(&mut self) -> TX_DMA_STOPPED_P_W {
-        TX_DMA_STOPPED_P_W { w: self }
+        TX_DMA_STOPPED_P_W::new(self)
     }
     #[doc = "Bit 0 - Frame Transmission Interrupt Pending"]
     #[inline(always)]
     pub fn tx_p(&mut self) -> TX_P_W {
-        TX_P_W { w: self }
+        TX_P_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
