@@ -35,32 +35,9 @@ impl From<crate::W<EMAC_MII_DATA_SPEC>> for W {
     }
 }
 #[doc = "Field `MII_DATA` reader - "]
-pub struct MII_DATA_R(crate::FieldReader<u16>);
-impl MII_DATA_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        MII_DATA_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for MII_DATA_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type MII_DATA_R = crate::FieldReader<u16, u16>;
 #[doc = "Field `MII_DATA` writer - "]
-pub struct MII_DATA_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> MII_DATA_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0xffff) | (value as u32 & 0xffff);
-        self.w
-    }
-}
+pub type MII_DATA_W<'a> = crate::FieldWriter<'a, u32, EMAC_MII_DATA_SPEC, u16, u16, 16, 0>;
 impl R {
     #[doc = "Bits 0:15"]
     #[inline(always)]
@@ -72,7 +49,7 @@ impl W {
     #[doc = "Bits 0:15"]
     #[inline(always)]
     pub fn mii_data(&mut self) -> MII_DATA_W {
-        MII_DATA_W { w: self }
+        MII_DATA_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
