@@ -49,13 +49,9 @@ impl From<RX_EN_A> for bool {
     }
 }
 #[doc = "Field `RX_EN` reader - Enable Receiver"]
-pub struct RX_EN_R(crate::FieldReader<bool>);
+pub type RX_EN_R = crate::BitReader<RX_EN_A>;
 impl RX_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_EN_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl RX_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == RX_EN_A::DISABLE
+        *self == RX_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == RX_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for RX_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_EN_A::ENABLE
     }
 }
 #[doc = "Field `RX_EN` writer - Enable Receiver"]
-pub struct RX_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_CTL0_SPEC, RX_EN_A, 31>;
 impl<'a> RX_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> RX_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(RX_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "Frame Receive Length Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<RX_FRM_LEN_CTL_A> for bool {
     }
 }
 #[doc = "Field `RX_FRM_LEN_CTL` reader - Frame Receive Length Control"]
-pub struct RX_FRM_LEN_CTL_R(crate::FieldReader<bool>);
+pub type RX_FRM_LEN_CTL_R = crate::BitReader<RX_FRM_LEN_CTL_A>;
 impl RX_FRM_LEN_CTL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_FRM_LEN_CTL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_FRM_LEN_CTL_A {
         match self.bits {
@@ -150,31 +112,17 @@ impl RX_FRM_LEN_CTL_R {
     #[doc = "Checks if the value of the field is `B2048`"]
     #[inline(always)]
     pub fn is_b2048(&self) -> bool {
-        **self == RX_FRM_LEN_CTL_A::B2048
+        *self == RX_FRM_LEN_CTL_A::B2048
     }
     #[doc = "Checks if the value of the field is `B16384`"]
     #[inline(always)]
     pub fn is_b16384(&self) -> bool {
-        **self == RX_FRM_LEN_CTL_A::B16384
-    }
-}
-impl core::ops::Deref for RX_FRM_LEN_CTL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_FRM_LEN_CTL_A::B16384
     }
 }
 #[doc = "Field `RX_FRM_LEN_CTL` writer - Frame Receive Length Control"]
-pub struct RX_FRM_LEN_CTL_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_FRM_LEN_CTL_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_CTL0_SPEC, RX_FRM_LEN_CTL_A, 30>;
 impl<'a> RX_FRM_LEN_CTL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_FRM_LEN_CTL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn b2048(self) -> &'a mut W {
@@ -185,22 +133,6 @@ impl<'a> RX_FRM_LEN_CTL_W<'a> {
     pub fn b16384(self) -> &'a mut W {
         self.variant(RX_FRM_LEN_CTL_A::B16384)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
-        self.w
-    }
 }
 #[doc = "Jumbo Frame Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -217,13 +149,9 @@ impl From<JUMBO_FRM_EN_A> for bool {
     }
 }
 #[doc = "Field `JUMBO_FRM_EN` reader - Jumbo Frame Enable"]
-pub struct JUMBO_FRM_EN_R(crate::FieldReader<bool>);
+pub type JUMBO_FRM_EN_R = crate::BitReader<JUMBO_FRM_EN_A>;
 impl JUMBO_FRM_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        JUMBO_FRM_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> JUMBO_FRM_EN_A {
         match self.bits {
@@ -234,31 +162,17 @@ impl JUMBO_FRM_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == JUMBO_FRM_EN_A::DISABLE
+        *self == JUMBO_FRM_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == JUMBO_FRM_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for JUMBO_FRM_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == JUMBO_FRM_EN_A::ENABLE
     }
 }
 #[doc = "Field `JUMBO_FRM_EN` writer - Jumbo Frame Enable"]
-pub struct JUMBO_FRM_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type JUMBO_FRM_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_CTL0_SPEC, JUMBO_FRM_EN_A, 29>;
 impl<'a> JUMBO_FRM_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: JUMBO_FRM_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -269,60 +183,11 @@ impl<'a> JUMBO_FRM_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(JUMBO_FRM_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 29)) | ((value as u32 & 1) << 29);
-        self.w
-    }
 }
 #[doc = "Field `STRIP_FCS` reader - "]
-pub struct STRIP_FCS_R(crate::FieldReader<bool>);
-impl STRIP_FCS_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        STRIP_FCS_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for STRIP_FCS_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type STRIP_FCS_R = crate::BitReader<bool>;
 #[doc = "Field `STRIP_FCS` writer - "]
-pub struct STRIP_FCS_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> STRIP_FCS_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
-        self.w
-    }
-}
+pub type STRIP_FCS_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_CTL0_SPEC, bool, 28>;
 #[doc = "Check CRC Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CHECK_CRC_A {
@@ -338,13 +203,9 @@ impl From<CHECK_CRC_A> for bool {
     }
 }
 #[doc = "Field `CHECK_CRC` reader - Check CRC Enable"]
-pub struct CHECK_CRC_R(crate::FieldReader<bool>);
+pub type CHECK_CRC_R = crate::BitReader<CHECK_CRC_A>;
 impl CHECK_CRC_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        CHECK_CRC_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CHECK_CRC_A {
         match self.bits {
@@ -355,31 +216,17 @@ impl CHECK_CRC_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == CHECK_CRC_A::DISABLE
+        *self == CHECK_CRC_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `CHECK`"]
     #[inline(always)]
     pub fn is_check(&self) -> bool {
-        **self == CHECK_CRC_A::CHECK
-    }
-}
-impl core::ops::Deref for CHECK_CRC_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CHECK_CRC_A::CHECK
     }
 }
 #[doc = "Field `CHECK_CRC` writer - Check CRC Enable"]
-pub struct CHECK_CRC_W<'a> {
-    w: &'a mut W,
-}
+pub type CHECK_CRC_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_CTL0_SPEC, CHECK_CRC_A, 27>;
 impl<'a> CHECK_CRC_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CHECK_CRC_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -390,22 +237,6 @@ impl<'a> CHECK_CRC_W<'a> {
     pub fn check(self) -> &'a mut W {
         self.variant(CHECK_CRC_A::CHECK)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -422,13 +253,9 @@ impl From<RX_PAUSE_FRM_MD_A> for bool {
     }
 }
 #[doc = "Field `RX_PAUSE_FRM_MD` reader - "]
-pub struct RX_PAUSE_FRM_MD_R(crate::FieldReader<bool>);
+pub type RX_PAUSE_FRM_MD_R = crate::BitReader<RX_PAUSE_FRM_MD_A>;
 impl RX_PAUSE_FRM_MD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_PAUSE_FRM_MD_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_PAUSE_FRM_MD_A {
         match self.bits {
@@ -439,31 +266,18 @@ impl RX_PAUSE_FRM_MD_R {
     #[doc = "Checks if the value of the field is `ONLY_MULTICAST`"]
     #[inline(always)]
     pub fn is_only_multicast(&self) -> bool {
-        **self == RX_PAUSE_FRM_MD_A::ONLY_MULTICAST
+        *self == RX_PAUSE_FRM_MD_A::ONLY_MULTICAST
     }
     #[doc = "Checks if the value of the field is `ALSO_UNICAST_MAC0`"]
     #[inline(always)]
     pub fn is_also_unicast_mac0(&self) -> bool {
-        **self == RX_PAUSE_FRM_MD_A::ALSO_UNICAST_MAC0
-    }
-}
-impl core::ops::Deref for RX_PAUSE_FRM_MD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_PAUSE_FRM_MD_A::ALSO_UNICAST_MAC0
     }
 }
 #[doc = "Field `RX_PAUSE_FRM_MD` writer - "]
-pub struct RX_PAUSE_FRM_MD_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_PAUSE_FRM_MD_W<'a> =
+    crate::BitWriter<'a, u32, EMAC_RX_CTL0_SPEC, RX_PAUSE_FRM_MD_A, 17>;
 impl<'a> RX_PAUSE_FRM_MD_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_PAUSE_FRM_MD_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn only_multicast(self) -> &'a mut W {
@@ -474,60 +288,11 @@ impl<'a> RX_PAUSE_FRM_MD_W<'a> {
     pub fn also_unicast_mac0(self) -> &'a mut W {
         self.variant(RX_PAUSE_FRM_MD_A::ALSO_UNICAST_MAC0)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
-        self.w
-    }
 }
 #[doc = "Field `RX_FLOW_CTL_EN` reader - "]
-pub struct RX_FLOW_CTL_EN_R(crate::FieldReader<bool>);
-impl RX_FLOW_CTL_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_FLOW_CTL_EN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RX_FLOW_CTL_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RX_FLOW_CTL_EN_R = crate::BitReader<bool>;
 #[doc = "Field `RX_FLOW_CTL_EN` writer - "]
-pub struct RX_FLOW_CTL_EN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RX_FLOW_CTL_EN_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
-        self.w
-    }
-}
+pub type RX_FLOW_CTL_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_CTL0_SPEC, bool, 16>;
 impl R {
     #[doc = "Bit 31 - Enable Receiver"]
     #[inline(always)]
@@ -569,37 +334,37 @@ impl W {
     #[doc = "Bit 31 - Enable Receiver"]
     #[inline(always)]
     pub fn rx_en(&mut self) -> RX_EN_W {
-        RX_EN_W { w: self }
+        RX_EN_W::new(self)
     }
     #[doc = "Bit 30 - Frame Receive Length Control"]
     #[inline(always)]
     pub fn rx_frm_len_ctl(&mut self) -> RX_FRM_LEN_CTL_W {
-        RX_FRM_LEN_CTL_W { w: self }
+        RX_FRM_LEN_CTL_W::new(self)
     }
     #[doc = "Bit 29 - Jumbo Frame Enable"]
     #[inline(always)]
     pub fn jumbo_frm_en(&mut self) -> JUMBO_FRM_EN_W {
-        JUMBO_FRM_EN_W { w: self }
+        JUMBO_FRM_EN_W::new(self)
     }
     #[doc = "Bit 28"]
     #[inline(always)]
     pub fn strip_fcs(&mut self) -> STRIP_FCS_W {
-        STRIP_FCS_W { w: self }
+        STRIP_FCS_W::new(self)
     }
     #[doc = "Bit 27 - Check CRC Enable"]
     #[inline(always)]
     pub fn check_crc(&mut self) -> CHECK_CRC_W {
-        CHECK_CRC_W { w: self }
+        CHECK_CRC_W::new(self)
     }
     #[doc = "Bit 17"]
     #[inline(always)]
     pub fn rx_pause_frm_md(&mut self) -> RX_PAUSE_FRM_MD_W {
-        RX_PAUSE_FRM_MD_W { w: self }
+        RX_PAUSE_FRM_MD_W::new(self)
     }
     #[doc = "Bit 16"]
     #[inline(always)]
     pub fn rx_flow_ctl_en(&mut self) -> RX_FLOW_CTL_EN_W {
-        RX_FLOW_CTL_EN_W { w: self }
+        RX_FLOW_CTL_EN_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
