@@ -49,13 +49,9 @@ impl From<DIS_ADDR_FILTER_A> for bool {
     }
 }
 #[doc = "Field `DIS_ADDR_FILTER` reader - Disable Address Filter"]
-pub struct DIS_ADDR_FILTER_R(crate::FieldReader<bool>);
+pub type DIS_ADDR_FILTER_R = crate::BitReader<DIS_ADDR_FILTER_A>;
 impl DIS_ADDR_FILTER_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DIS_ADDR_FILTER_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DIS_ADDR_FILTER_A {
         match self.bits {
@@ -66,31 +62,18 @@ impl DIS_ADDR_FILTER_R {
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == DIS_ADDR_FILTER_A::ENABLE
+        *self == DIS_ADDR_FILTER_A::ENABLE
     }
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == DIS_ADDR_FILTER_A::DISABLE
-    }
-}
-impl core::ops::Deref for DIS_ADDR_FILTER_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DIS_ADDR_FILTER_A::DISABLE
     }
 }
 #[doc = "Field `DIS_ADDR_FILTER` writer - Disable Address Filter"]
-pub struct DIS_ADDR_FILTER_W<'a> {
-    w: &'a mut W,
-}
+pub type DIS_ADDR_FILTER_W<'a> =
+    crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, DIS_ADDR_FILTER_A, 31>;
 impl<'a> DIS_ADDR_FILTER_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DIS_ADDR_FILTER_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn enable(self) -> &'a mut W {
@@ -101,22 +84,6 @@ impl<'a> DIS_ADDR_FILTER_W<'a> {
     pub fn disable(self) -> &'a mut W {
         self.variant(DIS_ADDR_FILTER_A::DISABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "Disable Receive Broadcast Frames\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +100,9 @@ impl From<DIS_BROADCAST_A> for bool {
     }
 }
 #[doc = "Field `DIS_BROADCAST` reader - Disable Receive Broadcast Frames"]
-pub struct DIS_BROADCAST_R(crate::FieldReader<bool>);
+pub type DIS_BROADCAST_R = crate::BitReader<DIS_BROADCAST_A>;
 impl DIS_BROADCAST_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DIS_BROADCAST_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DIS_BROADCAST_A {
         match self.bits {
@@ -150,31 +113,17 @@ impl DIS_BROADCAST_R {
     #[doc = "Checks if the value of the field is `RECEIVE`"]
     #[inline(always)]
     pub fn is_receive(&self) -> bool {
-        **self == DIS_BROADCAST_A::RECEIVE
+        *self == DIS_BROADCAST_A::RECEIVE
     }
     #[doc = "Checks if the value of the field is `DROP`"]
     #[inline(always)]
     pub fn is_drop(&self) -> bool {
-        **self == DIS_BROADCAST_A::DROP
-    }
-}
-impl core::ops::Deref for DIS_BROADCAST_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DIS_BROADCAST_A::DROP
     }
 }
 #[doc = "Field `DIS_BROADCAST` writer - Disable Receive Broadcast Frames"]
-pub struct DIS_BROADCAST_W<'a> {
-    w: &'a mut W,
-}
+pub type DIS_BROADCAST_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, DIS_BROADCAST_A, 17>;
 impl<'a> DIS_BROADCAST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DIS_BROADCAST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn receive(self) -> &'a mut W {
@@ -185,22 +134,6 @@ impl<'a> DIS_BROADCAST_W<'a> {
     pub fn drop(self) -> &'a mut W {
         self.variant(DIS_BROADCAST_A::DROP)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
-        self.w
-    }
 }
 #[doc = "Receive All Multicast Frames Filter\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -217,13 +150,9 @@ impl From<RX_ALL_MULTICAST_A> for bool {
     }
 }
 #[doc = "Field `RX_ALL_MULTICAST` reader - Receive All Multicast Frames Filter"]
-pub struct RX_ALL_MULTICAST_R(crate::FieldReader<bool>);
+pub type RX_ALL_MULTICAST_R = crate::BitReader<RX_ALL_MULTICAST_A>;
 impl RX_ALL_MULTICAST_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_ALL_MULTICAST_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_ALL_MULTICAST_A {
         match self.bits {
@@ -234,31 +163,18 @@ impl RX_ALL_MULTICAST_R {
     #[doc = "Checks if the value of the field is `FILTER`"]
     #[inline(always)]
     pub fn is_filter(&self) -> bool {
-        **self == RX_ALL_MULTICAST_A::FILTER
+        *self == RX_ALL_MULTICAST_A::FILTER
     }
     #[doc = "Checks if the value of the field is `RECEIVE_ALL`"]
     #[inline(always)]
     pub fn is_receive_all(&self) -> bool {
-        **self == RX_ALL_MULTICAST_A::RECEIVE_ALL
-    }
-}
-impl core::ops::Deref for RX_ALL_MULTICAST_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_ALL_MULTICAST_A::RECEIVE_ALL
     }
 }
 #[doc = "Field `RX_ALL_MULTICAST` writer - Receive All Multicast Frames Filter"]
-pub struct RX_ALL_MULTICAST_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_ALL_MULTICAST_W<'a> =
+    crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, RX_ALL_MULTICAST_A, 16>;
 impl<'a> RX_ALL_MULTICAST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_ALL_MULTICAST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn filter(self) -> &'a mut W {
@@ -269,22 +185,6 @@ impl<'a> RX_ALL_MULTICAST_W<'a> {
     pub fn receive_all(self) -> &'a mut W {
         self.variant(RX_ALL_MULTICAST_A::RECEIVE_ALL)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
-        self.w
-    }
 }
 #[doc = "Receive Control Frames Filter\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -304,13 +204,9 @@ impl From<CTL_FRM_FILTER_A> for u8 {
     }
 }
 #[doc = "Field `CTL_FRM_FILTER` reader - Receive Control Frames Filter"]
-pub struct CTL_FRM_FILTER_R(crate::FieldReader<u8>);
+pub type CTL_FRM_FILTER_R = crate::FieldReader<u8, CTL_FRM_FILTER_A>;
 impl CTL_FRM_FILTER_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        CTL_FRM_FILTER_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<CTL_FRM_FILTER_A> {
         match self.bits {
@@ -323,36 +219,23 @@ impl CTL_FRM_FILTER_R {
     #[doc = "Checks if the value of the field is `DROP_ALL`"]
     #[inline(always)]
     pub fn is_drop_all(&self) -> bool {
-        **self == CTL_FRM_FILTER_A::DROP_ALL
+        *self == CTL_FRM_FILTER_A::DROP_ALL
     }
     #[doc = "Checks if the value of the field is `RECEIVE_ALL`"]
     #[inline(always)]
     pub fn is_receive_all(&self) -> bool {
-        **self == CTL_FRM_FILTER_A::RECEIVE_ALL
+        *self == CTL_FRM_FILTER_A::RECEIVE_ALL
     }
     #[doc = "Checks if the value of the field is `RECEIVE_ALL_WHEN_FILTER`"]
     #[inline(always)]
     pub fn is_receive_all_when_filter(&self) -> bool {
-        **self == CTL_FRM_FILTER_A::RECEIVE_ALL_WHEN_FILTER
-    }
-}
-impl core::ops::Deref for CTL_FRM_FILTER_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CTL_FRM_FILTER_A::RECEIVE_ALL_WHEN_FILTER
     }
 }
 #[doc = "Field `CTL_FRM_FILTER` writer - Receive Control Frames Filter"]
-pub struct CTL_FRM_FILTER_W<'a> {
-    w: &'a mut W,
-}
+pub type CTL_FRM_FILTER_W<'a> =
+    crate::FieldWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, u8, CTL_FRM_FILTER_A, 2, 12>;
 impl<'a> CTL_FRM_FILTER_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CTL_FRM_FILTER_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn drop_all(self) -> &'a mut W {
@@ -368,12 +251,6 @@ impl<'a> CTL_FRM_FILTER_W<'a> {
     pub fn receive_all_when_filter(self) -> &'a mut W {
         self.variant(CTL_FRM_FILTER_A::RECEIVE_ALL_WHEN_FILTER)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 12)) | ((value as u32 & 3) << 12);
-        self.w
-    }
 }
 #[doc = "Filter Multicast Frames Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -390,13 +267,9 @@ impl From<HASH_MULTICAST_A> for bool {
     }
 }
 #[doc = "Field `HASH_MULTICAST` reader - Filter Multicast Frames Set"]
-pub struct HASH_MULTICAST_R(crate::FieldReader<bool>);
+pub type HASH_MULTICAST_R = crate::BitReader<HASH_MULTICAST_A>;
 impl HASH_MULTICAST_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        HASH_MULTICAST_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> HASH_MULTICAST_A {
         match self.bits {
@@ -407,31 +280,18 @@ impl HASH_MULTICAST_R {
     #[doc = "Checks if the value of the field is `DA_FIELD`"]
     #[inline(always)]
     pub fn is_da_field(&self) -> bool {
-        **self == HASH_MULTICAST_A::DA_FIELD
+        *self == HASH_MULTICAST_A::DA_FIELD
     }
     #[doc = "Checks if the value of the field is `HASH_TABLE`"]
     #[inline(always)]
     pub fn is_hash_table(&self) -> bool {
-        **self == HASH_MULTICAST_A::HASH_TABLE
-    }
-}
-impl core::ops::Deref for HASH_MULTICAST_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == HASH_MULTICAST_A::HASH_TABLE
     }
 }
 #[doc = "Field `HASH_MULTICAST` writer - Filter Multicast Frames Set"]
-pub struct HASH_MULTICAST_W<'a> {
-    w: &'a mut W,
-}
+pub type HASH_MULTICAST_W<'a> =
+    crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, HASH_MULTICAST_A, 9>;
 impl<'a> HASH_MULTICAST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: HASH_MULTICAST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn da_field(self) -> &'a mut W {
@@ -442,22 +302,6 @@ impl<'a> HASH_MULTICAST_W<'a> {
     pub fn hash_table(self) -> &'a mut W {
         self.variant(HASH_MULTICAST_A::HASH_TABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
-        self.w
-    }
 }
 #[doc = "Filter Unicast Frames Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -474,13 +318,9 @@ impl From<HASH_UNICAST_A> for bool {
     }
 }
 #[doc = "Field `HASH_UNICAST` reader - Filter Unicast Frames Set"]
-pub struct HASH_UNICAST_R(crate::FieldReader<bool>);
+pub type HASH_UNICAST_R = crate::BitReader<HASH_UNICAST_A>;
 impl HASH_UNICAST_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        HASH_UNICAST_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> HASH_UNICAST_A {
         match self.bits {
@@ -491,31 +331,17 @@ impl HASH_UNICAST_R {
     #[doc = "Checks if the value of the field is `DA_FIELD`"]
     #[inline(always)]
     pub fn is_da_field(&self) -> bool {
-        **self == HASH_UNICAST_A::DA_FIELD
+        *self == HASH_UNICAST_A::DA_FIELD
     }
     #[doc = "Checks if the value of the field is `HASH_TABLE`"]
     #[inline(always)]
     pub fn is_hash_table(&self) -> bool {
-        **self == HASH_UNICAST_A::HASH_TABLE
-    }
-}
-impl core::ops::Deref for HASH_UNICAST_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == HASH_UNICAST_A::HASH_TABLE
     }
 }
 #[doc = "Field `HASH_UNICAST` writer - Filter Unicast Frames Set"]
-pub struct HASH_UNICAST_W<'a> {
-    w: &'a mut W,
-}
+pub type HASH_UNICAST_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, HASH_UNICAST_A, 8>;
 impl<'a> HASH_UNICAST_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: HASH_UNICAST_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn da_field(self) -> &'a mut W {
@@ -526,22 +352,6 @@ impl<'a> HASH_UNICAST_W<'a> {
     pub fn hash_table(self) -> &'a mut W {
         self.variant(HASH_UNICAST_A::HASH_TABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
-        self.w
-    }
 }
 #[doc = "Receive SA Filter Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -558,13 +368,9 @@ impl From<SA_FILTER_EN_A> for bool {
     }
 }
 #[doc = "Field `SA_FILTER_EN` reader - Receive SA Filter Enable"]
-pub struct SA_FILTER_EN_R(crate::FieldReader<bool>);
+pub type SA_FILTER_EN_R = crate::BitReader<SA_FILTER_EN_A>;
 impl SA_FILTER_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SA_FILTER_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SA_FILTER_EN_A {
         match self.bits {
@@ -575,31 +381,17 @@ impl SA_FILTER_EN_R {
     #[doc = "Checks if the value of the field is `RECEIVE_UPDATE`"]
     #[inline(always)]
     pub fn is_receive_update(&self) -> bool {
-        **self == SA_FILTER_EN_A::RECEIVE_UPDATE
+        *self == SA_FILTER_EN_A::RECEIVE_UPDATE
     }
     #[doc = "Checks if the value of the field is `UPDATE_DROP_UNMATCHED`"]
     #[inline(always)]
     pub fn is_update_drop_unmatched(&self) -> bool {
-        **self == SA_FILTER_EN_A::UPDATE_DROP_UNMATCHED
-    }
-}
-impl core::ops::Deref for SA_FILTER_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SA_FILTER_EN_A::UPDATE_DROP_UNMATCHED
     }
 }
 #[doc = "Field `SA_FILTER_EN` writer - Receive SA Filter Enable"]
-pub struct SA_FILTER_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type SA_FILTER_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, SA_FILTER_EN_A, 6>;
 impl<'a> SA_FILTER_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SA_FILTER_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn receive_update(self) -> &'a mut W {
@@ -610,22 +402,6 @@ impl<'a> SA_FILTER_EN_W<'a> {
     pub fn update_drop_unmatched(self) -> &'a mut W {
         self.variant(SA_FILTER_EN_A::UPDATE_DROP_UNMATCHED)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
-        self.w
-    }
 }
 #[doc = "Receive SA Invert Filter Set\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -642,13 +418,9 @@ impl From<SA_INV_FILTER_A> for bool {
     }
 }
 #[doc = "Field `SA_INV_FILTER` reader - Receive SA Invert Filter Set"]
-pub struct SA_INV_FILTER_R(crate::FieldReader<bool>);
+pub type SA_INV_FILTER_R = crate::BitReader<SA_INV_FILTER_A>;
 impl SA_INV_FILTER_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SA_INV_FILTER_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SA_INV_FILTER_A {
         match self.bits {
@@ -659,31 +431,17 @@ impl SA_INV_FILTER_R {
     #[doc = "Checks if the value of the field is `MATCHED`"]
     #[inline(always)]
     pub fn is_matched(&self) -> bool {
-        **self == SA_INV_FILTER_A::MATCHED
+        *self == SA_INV_FILTER_A::MATCHED
     }
     #[doc = "Checks if the value of the field is `UNMATCHED`"]
     #[inline(always)]
     pub fn is_unmatched(&self) -> bool {
-        **self == SA_INV_FILTER_A::UNMATCHED
-    }
-}
-impl core::ops::Deref for SA_INV_FILTER_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SA_INV_FILTER_A::UNMATCHED
     }
 }
 #[doc = "Field `SA_INV_FILTER` writer - Receive SA Invert Filter Set"]
-pub struct SA_INV_FILTER_W<'a> {
-    w: &'a mut W,
-}
+pub type SA_INV_FILTER_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, SA_INV_FILTER_A, 5>;
 impl<'a> SA_INV_FILTER_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SA_INV_FILTER_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn matched(self) -> &'a mut W {
@@ -694,22 +452,6 @@ impl<'a> SA_INV_FILTER_W<'a> {
     pub fn unmatched(self) -> &'a mut W {
         self.variant(SA_INV_FILTER_A::UNMATCHED)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -726,13 +468,9 @@ impl From<DA_INV_FILTER_A> for bool {
     }
 }
 #[doc = "Field `DA_INV_FILTER` reader - "]
-pub struct DA_INV_FILTER_R(crate::FieldReader<bool>);
+pub type DA_INV_FILTER_R = crate::BitReader<DA_INV_FILTER_A>;
 impl DA_INV_FILTER_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DA_INV_FILTER_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DA_INV_FILTER_A {
         match self.bits {
@@ -743,31 +481,17 @@ impl DA_INV_FILTER_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == DA_INV_FILTER_A::NORMAL
+        *self == DA_INV_FILTER_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `INVERSE_CMP_DA`"]
     #[inline(always)]
     pub fn is_inverse_cmp_da(&self) -> bool {
-        **self == DA_INV_FILTER_A::INVERSE_CMP_DA
-    }
-}
-impl core::ops::Deref for DA_INV_FILTER_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DA_INV_FILTER_A::INVERSE_CMP_DA
     }
 }
 #[doc = "Field `DA_INV_FILTER` writer - "]
-pub struct DA_INV_FILTER_W<'a> {
-    w: &'a mut W,
-}
+pub type DA_INV_FILTER_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, DA_INV_FILTER_A, 4>;
 impl<'a> DA_INV_FILTER_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DA_INV_FILTER_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -778,22 +502,6 @@ impl<'a> DA_INV_FILTER_W<'a> {
     pub fn inverse_cmp_da(self) -> &'a mut W {
         self.variant(DA_INV_FILTER_A::INVERSE_CMP_DA)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -810,13 +518,9 @@ impl From<FLT_MD_A> for bool {
     }
 }
 #[doc = "Field `FLT_MD` reader - "]
-pub struct FLT_MD_R(crate::FieldReader<bool>);
+pub type FLT_MD_R = crate::BitReader<FLT_MD_A>;
 impl FLT_MD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FLT_MD_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FLT_MD_A {
         match self.bits {
@@ -827,31 +531,17 @@ impl FLT_MD_R {
     #[doc = "Checks if the value of the field is `PASSED_WHEN_MATCHED`"]
     #[inline(always)]
     pub fn is_passed_when_matched(&self) -> bool {
-        **self == FLT_MD_A::PASSED_WHEN_MATCHED
+        *self == FLT_MD_A::PASSED_WHEN_MATCHED
     }
     #[doc = "Checks if the value of the field is `RECEIVE_WHEN_PASSED`"]
     #[inline(always)]
     pub fn is_receive_when_passed(&self) -> bool {
-        **self == FLT_MD_A::RECEIVE_WHEN_PASSED
-    }
-}
-impl core::ops::Deref for FLT_MD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FLT_MD_A::RECEIVE_WHEN_PASSED
     }
 }
 #[doc = "Field `FLT_MD` writer - "]
-pub struct FLT_MD_W<'a> {
-    w: &'a mut W,
-}
+pub type FLT_MD_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, FLT_MD_A, 1>;
 impl<'a> FLT_MD_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FLT_MD_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn passed_when_matched(self) -> &'a mut W {
@@ -862,22 +552,6 @@ impl<'a> FLT_MD_W<'a> {
     pub fn receive_when_passed(self) -> &'a mut W {
         self.variant(FLT_MD_A::RECEIVE_WHEN_PASSED)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
-        self.w
-    }
 }
 #[doc = "Receive All Frame\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -894,13 +568,9 @@ impl From<RX_ALL_A> for bool {
     }
 }
 #[doc = "Field `RX_ALL` reader - Receive All Frame"]
-pub struct RX_ALL_R(crate::FieldReader<bool>);
+pub type RX_ALL_R = crate::BitReader<RX_ALL_A>;
 impl RX_ALL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RX_ALL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RX_ALL_A {
         match self.bits {
@@ -911,31 +581,17 @@ impl RX_ALL_R {
     #[doc = "Checks if the value of the field is `RECEIVE_WHEN_PASSED`"]
     #[inline(always)]
     pub fn is_receive_when_passed(&self) -> bool {
-        **self == RX_ALL_A::RECEIVE_WHEN_PASSED
+        *self == RX_ALL_A::RECEIVE_WHEN_PASSED
     }
     #[doc = "Checks if the value of the field is `RECEIVE_ALL_UPDATE`"]
     #[inline(always)]
     pub fn is_receive_all_update(&self) -> bool {
-        **self == RX_ALL_A::RECEIVE_ALL_UPDATE
-    }
-}
-impl core::ops::Deref for RX_ALL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RX_ALL_A::RECEIVE_ALL_UPDATE
     }
 }
 #[doc = "Field `RX_ALL` writer - Receive All Frame"]
-pub struct RX_ALL_W<'a> {
-    w: &'a mut W,
-}
+pub type RX_ALL_W<'a> = crate::BitWriter<'a, u32, EMAC_RX_FRM_FLT_SPEC, RX_ALL_A, 0>;
 impl<'a> RX_ALL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RX_ALL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn receive_when_passed(self) -> &'a mut W {
@@ -946,22 +602,6 @@ impl<'a> RX_ALL_W<'a> {
     pub fn receive_all_update(self) -> &'a mut W {
         self.variant(RX_ALL_A::RECEIVE_ALL_UPDATE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 31 - Disable Address Filter"]
@@ -1024,57 +664,57 @@ impl W {
     #[doc = "Bit 31 - Disable Address Filter"]
     #[inline(always)]
     pub fn dis_addr_filter(&mut self) -> DIS_ADDR_FILTER_W {
-        DIS_ADDR_FILTER_W { w: self }
+        DIS_ADDR_FILTER_W::new(self)
     }
     #[doc = "Bit 17 - Disable Receive Broadcast Frames"]
     #[inline(always)]
     pub fn dis_broadcast(&mut self) -> DIS_BROADCAST_W {
-        DIS_BROADCAST_W { w: self }
+        DIS_BROADCAST_W::new(self)
     }
     #[doc = "Bit 16 - Receive All Multicast Frames Filter"]
     #[inline(always)]
     pub fn rx_all_multicast(&mut self) -> RX_ALL_MULTICAST_W {
-        RX_ALL_MULTICAST_W { w: self }
+        RX_ALL_MULTICAST_W::new(self)
     }
     #[doc = "Bits 12:13 - Receive Control Frames Filter"]
     #[inline(always)]
     pub fn ctl_frm_filter(&mut self) -> CTL_FRM_FILTER_W {
-        CTL_FRM_FILTER_W { w: self }
+        CTL_FRM_FILTER_W::new(self)
     }
     #[doc = "Bit 9 - Filter Multicast Frames Set"]
     #[inline(always)]
     pub fn hash_multicast(&mut self) -> HASH_MULTICAST_W {
-        HASH_MULTICAST_W { w: self }
+        HASH_MULTICAST_W::new(self)
     }
     #[doc = "Bit 8 - Filter Unicast Frames Set"]
     #[inline(always)]
     pub fn hash_unicast(&mut self) -> HASH_UNICAST_W {
-        HASH_UNICAST_W { w: self }
+        HASH_UNICAST_W::new(self)
     }
     #[doc = "Bit 6 - Receive SA Filter Enable"]
     #[inline(always)]
     pub fn sa_filter_en(&mut self) -> SA_FILTER_EN_W {
-        SA_FILTER_EN_W { w: self }
+        SA_FILTER_EN_W::new(self)
     }
     #[doc = "Bit 5 - Receive SA Invert Filter Set"]
     #[inline(always)]
     pub fn sa_inv_filter(&mut self) -> SA_INV_FILTER_W {
-        SA_INV_FILTER_W { w: self }
+        SA_INV_FILTER_W::new(self)
     }
     #[doc = "Bit 4"]
     #[inline(always)]
     pub fn da_inv_filter(&mut self) -> DA_INV_FILTER_W {
-        DA_INV_FILTER_W { w: self }
+        DA_INV_FILTER_W::new(self)
     }
     #[doc = "Bit 1"]
     #[inline(always)]
     pub fn flt_md(&mut self) -> FLT_MD_W {
-        FLT_MD_W { w: self }
+        FLT_MD_W::new(self)
     }
     #[doc = "Bit 0 - Receive All Frame"]
     #[inline(always)]
     pub fn rx_all(&mut self) -> RX_ALL_W {
-        RX_ALL_W { w: self }
+        RX_ALL_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
