@@ -49,13 +49,9 @@ impl From<TX_EN_A> for bool {
     }
 }
 #[doc = "Field `TX_EN` reader - Enable Transmitter"]
-pub struct TX_EN_R(crate::FieldReader<bool>);
+pub type TX_EN_R = crate::BitReader<TX_EN_A>;
 impl TX_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_EN_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl TX_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == TX_EN_A::DISABLE
+        *self == TX_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == TX_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for TX_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_EN_A::ENABLE
     }
 }
 #[doc = "Field `TX_EN` writer - Enable Transmitter"]
-pub struct TX_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_CTL0_SPEC, TX_EN_A, 31>;
 impl<'a> TX_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> TX_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(TX_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "Frame Transmit Length Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<TX_FRM_LEN_CTL_A> for bool {
     }
 }
 #[doc = "Field `TX_FRM_LEN_CTL` reader - Frame Transmit Length Control"]
-pub struct TX_FRM_LEN_CTL_R(crate::FieldReader<bool>);
+pub type TX_FRM_LEN_CTL_R = crate::BitReader<TX_FRM_LEN_CTL_A>;
 impl TX_FRM_LEN_CTL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_FRM_LEN_CTL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_FRM_LEN_CTL_A {
         match self.bits {
@@ -150,31 +112,17 @@ impl TX_FRM_LEN_CTL_R {
     #[doc = "Checks if the value of the field is `B2048`"]
     #[inline(always)]
     pub fn is_b2048(&self) -> bool {
-        **self == TX_FRM_LEN_CTL_A::B2048
+        *self == TX_FRM_LEN_CTL_A::B2048
     }
     #[doc = "Checks if the value of the field is `B16384`"]
     #[inline(always)]
     pub fn is_b16384(&self) -> bool {
-        **self == TX_FRM_LEN_CTL_A::B16384
-    }
-}
-impl core::ops::Deref for TX_FRM_LEN_CTL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_FRM_LEN_CTL_A::B16384
     }
 }
 #[doc = "Field `TX_FRM_LEN_CTL` writer - Frame Transmit Length Control"]
-pub struct TX_FRM_LEN_CTL_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_FRM_LEN_CTL_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_CTL0_SPEC, TX_FRM_LEN_CTL_A, 30>;
 impl<'a> TX_FRM_LEN_CTL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_FRM_LEN_CTL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn b2048(self) -> &'a mut W {
@@ -185,22 +133,6 @@ impl<'a> TX_FRM_LEN_CTL_W<'a> {
     pub fn b16384(self) -> &'a mut W {
         self.variant(TX_FRM_LEN_CTL_A::B16384)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 31 - Enable Transmitter"]
@@ -218,12 +150,12 @@ impl W {
     #[doc = "Bit 31 - Enable Transmitter"]
     #[inline(always)]
     pub fn tx_en(&mut self) -> TX_EN_W {
-        TX_EN_W { w: self }
+        TX_EN_W::new(self)
     }
     #[doc = "Bit 30 - Frame Transmit Length Control"]
     #[inline(always)]
     pub fn tx_frm_len_ctl(&mut self) -> TX_FRM_LEN_CTL_W {
-        TX_FRM_LEN_CTL_W { w: self }
+        TX_FRM_LEN_CTL_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
