@@ -49,13 +49,9 @@ impl From<TX_DMA_START_A> for bool {
     }
 }
 #[doc = "Field `TX_DMA_START` reader - Transmit DMA FSM Start"]
-pub struct TX_DMA_START_R(crate::FieldReader<bool>);
+pub type TX_DMA_START_R = crate::BitReader<TX_DMA_START_A>;
 impl TX_DMA_START_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_DMA_START_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_DMA_START_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl TX_DMA_START_R {
     #[doc = "Checks if the value of the field is `NO_VALID`"]
     #[inline(always)]
     pub fn is_no_valid(&self) -> bool {
-        **self == TX_DMA_START_A::NO_VALID
+        *self == TX_DMA_START_A::NO_VALID
     }
     #[doc = "Checks if the value of the field is `START`"]
     #[inline(always)]
     pub fn is_start(&self) -> bool {
-        **self == TX_DMA_START_A::START
-    }
-}
-impl core::ops::Deref for TX_DMA_START_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_DMA_START_A::START
     }
 }
 #[doc = "Field `TX_DMA_START` writer - Transmit DMA FSM Start"]
-pub struct TX_DMA_START_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_DMA_START_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_CTL1_SPEC, TX_DMA_START_A, 31>;
 impl<'a> TX_DMA_START_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_DMA_START_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_valid(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> TX_DMA_START_W<'a> {
     pub fn start(self) -> &'a mut W {
         self.variant(TX_DMA_START_A::START)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
 }
 #[doc = "Transmit DMA Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<TX_DMA_EN_A> for bool {
     }
 }
 #[doc = "Field `TX_DMA_EN` reader - Transmit DMA Enable"]
-pub struct TX_DMA_EN_R(crate::FieldReader<bool>);
+pub type TX_DMA_EN_R = crate::BitReader<TX_DMA_EN_A>;
 impl TX_DMA_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_DMA_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_DMA_EN_A {
         match self.bits {
@@ -150,31 +112,17 @@ impl TX_DMA_EN_R {
     #[doc = "Checks if the value of the field is `STOP`"]
     #[inline(always)]
     pub fn is_stop(&self) -> bool {
-        **self == TX_DMA_EN_A::STOP
+        *self == TX_DMA_EN_A::STOP
     }
     #[doc = "Checks if the value of the field is `START`"]
     #[inline(always)]
     pub fn is_start(&self) -> bool {
-        **self == TX_DMA_EN_A::START
-    }
-}
-impl core::ops::Deref for TX_DMA_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_DMA_EN_A::START
     }
 }
 #[doc = "Field `TX_DMA_EN` writer - Transmit DMA Enable"]
-pub struct TX_DMA_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_DMA_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_CTL1_SPEC, TX_DMA_EN_A, 30>;
 impl<'a> TX_DMA_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_DMA_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn stop(self) -> &'a mut W {
@@ -185,22 +133,6 @@ impl<'a> TX_DMA_EN_W<'a> {
     pub fn start(self) -> &'a mut W {
         self.variant(TX_DMA_EN_A::START)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 30)) | ((value as u32 & 1) << 30);
-        self.w
-    }
 }
 #[doc = "Threshold value of TX DMA FIFO\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -222,13 +154,9 @@ impl From<TX_TH_A> for u8 {
     }
 }
 #[doc = "Field `TX_TH` reader - Threshold value of TX DMA FIFO"]
-pub struct TX_TH_R(crate::FieldReader<u8>);
+pub type TX_TH_R = crate::FieldReader<u8, TX_TH_A>;
 impl TX_TH_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        TX_TH_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<TX_TH_A> {
         match self.bits {
@@ -242,41 +170,27 @@ impl TX_TH_R {
     #[doc = "Checks if the value of the field is `T64`"]
     #[inline(always)]
     pub fn is_t64(&self) -> bool {
-        **self == TX_TH_A::T64
+        *self == TX_TH_A::T64
     }
     #[doc = "Checks if the value of the field is `T128`"]
     #[inline(always)]
     pub fn is_t128(&self) -> bool {
-        **self == TX_TH_A::T128
+        *self == TX_TH_A::T128
     }
     #[doc = "Checks if the value of the field is `T192`"]
     #[inline(always)]
     pub fn is_t192(&self) -> bool {
-        **self == TX_TH_A::T192
+        *self == TX_TH_A::T192
     }
     #[doc = "Checks if the value of the field is `T256`"]
     #[inline(always)]
     pub fn is_t256(&self) -> bool {
-        **self == TX_TH_A::T256
-    }
-}
-impl core::ops::Deref for TX_TH_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_TH_A::T256
     }
 }
 #[doc = "Field `TX_TH` writer - Threshold value of TX DMA FIFO"]
-pub struct TX_TH_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_TH_W<'a> = crate::FieldWriter<'a, u32, EMAC_TX_CTL1_SPEC, u8, TX_TH_A, 3, 8>;
 impl<'a> TX_TH_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_TH_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn t64(self) -> &'a mut W {
@@ -297,12 +211,6 @@ impl<'a> TX_TH_W<'a> {
     pub fn t256(self) -> &'a mut W {
         self.variant(TX_TH_A::T256)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << 8)) | ((value as u32 & 7) << 8);
-        self.w
-    }
 }
 #[doc = "Transmission Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -319,13 +227,9 @@ impl From<TX_MD_A> for bool {
     }
 }
 #[doc = "Field `TX_MD` reader - Transmission Mode"]
-pub struct TX_MD_R(crate::FieldReader<bool>);
+pub type TX_MD_R = crate::BitReader<TX_MD_A>;
 impl TX_MD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_MD_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_MD_A {
         match self.bits {
@@ -336,31 +240,17 @@ impl TX_MD_R {
     #[doc = "Checks if the value of the field is `GREATER_THAN_TH`"]
     #[inline(always)]
     pub fn is_greater_than_th(&self) -> bool {
-        **self == TX_MD_A::GREATER_THAN_TH
+        *self == TX_MD_A::GREATER_THAN_TH
     }
     #[doc = "Checks if the value of the field is `LOCATE_FULL_FRAME`"]
     #[inline(always)]
     pub fn is_locate_full_frame(&self) -> bool {
-        **self == TX_MD_A::LOCATE_FULL_FRAME
-    }
-}
-impl core::ops::Deref for TX_MD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_MD_A::LOCATE_FULL_FRAME
     }
 }
 #[doc = "Field `TX_MD` writer - Transmission Mode"]
-pub struct TX_MD_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_MD_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_CTL1_SPEC, TX_MD_A, 1>;
 impl<'a> TX_MD_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_MD_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn greater_than_th(self) -> &'a mut W {
@@ -371,22 +261,6 @@ impl<'a> TX_MD_W<'a> {
     pub fn locate_full_frame(self) -> &'a mut W {
         self.variant(TX_MD_A::LOCATE_FULL_FRAME)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
-        self.w
-    }
 }
 #[doc = "Flush the data in the TX FIFO\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -403,13 +277,9 @@ impl From<FLUSH_TX_FIFO_A> for bool {
     }
 }
 #[doc = "Field `FLUSH_TX_FIFO` reader - Flush the data in the TX FIFO"]
-pub struct FLUSH_TX_FIFO_R(crate::FieldReader<bool>);
+pub type FLUSH_TX_FIFO_R = crate::BitReader<FLUSH_TX_FIFO_A>;
 impl FLUSH_TX_FIFO_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FLUSH_TX_FIFO_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FLUSH_TX_FIFO_A {
         match self.bits {
@@ -420,31 +290,17 @@ impl FLUSH_TX_FIFO_R {
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == FLUSH_TX_FIFO_A::ENABLE
+        *self == FLUSH_TX_FIFO_A::ENABLE
     }
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == FLUSH_TX_FIFO_A::DISABLE
-    }
-}
-impl core::ops::Deref for FLUSH_TX_FIFO_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FLUSH_TX_FIFO_A::DISABLE
     }
 }
 #[doc = "Field `FLUSH_TX_FIFO` writer - Flush the data in the TX FIFO"]
-pub struct FLUSH_TX_FIFO_W<'a> {
-    w: &'a mut W,
-}
+pub type FLUSH_TX_FIFO_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_CTL1_SPEC, FLUSH_TX_FIFO_A, 0>;
 impl<'a> FLUSH_TX_FIFO_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FLUSH_TX_FIFO_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn enable(self) -> &'a mut W {
@@ -455,22 +311,6 @@ impl<'a> FLUSH_TX_FIFO_W<'a> {
     pub fn disable(self) -> &'a mut W {
         self.variant(FLUSH_TX_FIFO_A::DISABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 31 - Transmit DMA FSM Start"]
@@ -503,27 +343,27 @@ impl W {
     #[doc = "Bit 31 - Transmit DMA FSM Start"]
     #[inline(always)]
     pub fn tx_dma_start(&mut self) -> TX_DMA_START_W {
-        TX_DMA_START_W { w: self }
+        TX_DMA_START_W::new(self)
     }
     #[doc = "Bit 30 - Transmit DMA Enable"]
     #[inline(always)]
     pub fn tx_dma_en(&mut self) -> TX_DMA_EN_W {
-        TX_DMA_EN_W { w: self }
+        TX_DMA_EN_W::new(self)
     }
     #[doc = "Bits 8:10 - Threshold value of TX DMA FIFO"]
     #[inline(always)]
     pub fn tx_th(&mut self) -> TX_TH_W {
-        TX_TH_W { w: self }
+        TX_TH_W::new(self)
     }
     #[doc = "Bit 1 - Transmission Mode"]
     #[inline(always)]
     pub fn tx_md(&mut self) -> TX_MD_W {
-        TX_MD_W { w: self }
+        TX_MD_W::new(self)
     }
     #[doc = "Bit 0 - Flush the data in the TX FIFO"]
     #[inline(always)]
     pub fn flush_tx_fifo(&mut self) -> FLUSH_TX_FIFO_W {
-        FLUSH_TX_FIFO_W { w: self }
+        FLUSH_TX_FIFO_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
