@@ -35,96 +35,18 @@ impl From<crate::W<EMAC_TX_FLOW_CTL_SPEC>> for W {
     }
 }
 #[doc = "Field `TX_FLOW_CTL_STA` reader - "]
-pub struct TX_FLOW_CTL_STA_R(crate::FieldReader<bool>);
-impl TX_FLOW_CTL_STA_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_FLOW_CTL_STA_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TX_FLOW_CTL_STA_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TX_FLOW_CTL_STA_R = crate::BitReader<bool>;
 #[doc = "Field `TX_FLOW_CTL_STA` writer - "]
-pub struct TX_FLOW_CTL_STA_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TX_FLOW_CTL_STA_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
-}
+pub type TX_FLOW_CTL_STA_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_FLOW_CTL_SPEC, bool, 31>;
 #[doc = "Field `TX_PAUSE_FRM_SLOT` reader - "]
-pub struct TX_PAUSE_FRM_SLOT_R(crate::FieldReader<u8>);
-impl TX_PAUSE_FRM_SLOT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        TX_PAUSE_FRM_SLOT_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TX_PAUSE_FRM_SLOT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TX_PAUSE_FRM_SLOT_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `TX_PAUSE_FRM_SLOT` writer - "]
-pub struct TX_PAUSE_FRM_SLOT_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TX_PAUSE_FRM_SLOT_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 20)) | ((value as u32 & 3) << 20);
-        self.w
-    }
-}
+pub type TX_PAUSE_FRM_SLOT_W<'a> =
+    crate::FieldWriter<'a, u32, EMAC_TX_FLOW_CTL_SPEC, u8, u8, 2, 20>;
 #[doc = "Field `PAUSE_TIME` reader - "]
-pub struct PAUSE_TIME_R(crate::FieldReader<u16>);
-impl PAUSE_TIME_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        PAUSE_TIME_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for PAUSE_TIME_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PAUSE_TIME_R = crate::FieldReader<u16, u16>;
 #[doc = "Field `PAUSE_TIME` writer - "]
-pub struct PAUSE_TIME_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PAUSE_TIME_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0xffff << 4)) | ((value as u32 & 0xffff) << 4);
-        self.w
-    }
-}
+pub type PAUSE_TIME_W<'a> = crate::FieldWriter<'a, u32, EMAC_TX_FLOW_CTL_SPEC, u16, u16, 16, 4>;
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ZQP_FRM_EN_A {
@@ -140,13 +62,9 @@ impl From<ZQP_FRM_EN_A> for bool {
     }
 }
 #[doc = "Field `ZQP_FRM_EN` reader - "]
-pub struct ZQP_FRM_EN_R(crate::FieldReader<bool>);
+pub type ZQP_FRM_EN_R = crate::BitReader<ZQP_FRM_EN_A>;
 impl ZQP_FRM_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        ZQP_FRM_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ZQP_FRM_EN_A {
         match self.bits {
@@ -157,31 +75,17 @@ impl ZQP_FRM_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == ZQP_FRM_EN_A::DISABLE
+        *self == ZQP_FRM_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == ZQP_FRM_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for ZQP_FRM_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == ZQP_FRM_EN_A::ENABLE
     }
 }
 #[doc = "Field `ZQP_FRM_EN` writer - "]
-pub struct ZQP_FRM_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type ZQP_FRM_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_TX_FLOW_CTL_SPEC, ZQP_FRM_EN_A, 1>;
 impl<'a> ZQP_FRM_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ZQP_FRM_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -192,22 +96,6 @@ impl<'a> ZQP_FRM_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(ZQP_FRM_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
-        self.w
-    }
 }
 #[doc = "TX Flow Control Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -224,13 +112,9 @@ impl From<TX_FLOW_CTL_EN_A> for bool {
     }
 }
 #[doc = "Field `TX_FLOW_CTL_EN` reader - TX Flow Control Enable"]
-pub struct TX_FLOW_CTL_EN_R(crate::FieldReader<bool>);
+pub type TX_FLOW_CTL_EN_R = crate::BitReader<TX_FLOW_CTL_EN_A>;
 impl TX_FLOW_CTL_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TX_FLOW_CTL_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TX_FLOW_CTL_EN_A {
         match self.bits {
@@ -241,31 +125,18 @@ impl TX_FLOW_CTL_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == TX_FLOW_CTL_EN_A::DISABLE
+        *self == TX_FLOW_CTL_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == TX_FLOW_CTL_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for TX_FLOW_CTL_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TX_FLOW_CTL_EN_A::ENABLE
     }
 }
 #[doc = "Field `TX_FLOW_CTL_EN` writer - TX Flow Control Enable"]
-pub struct TX_FLOW_CTL_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type TX_FLOW_CTL_EN_W<'a> =
+    crate::BitWriter<'a, u32, EMAC_TX_FLOW_CTL_SPEC, TX_FLOW_CTL_EN_A, 0>;
 impl<'a> TX_FLOW_CTL_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TX_FLOW_CTL_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -276,22 +147,6 @@ impl<'a> TX_FLOW_CTL_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(TX_FLOW_CTL_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 31"]
@@ -324,27 +179,27 @@ impl W {
     #[doc = "Bit 31"]
     #[inline(always)]
     pub fn tx_flow_ctl_sta(&mut self) -> TX_FLOW_CTL_STA_W {
-        TX_FLOW_CTL_STA_W { w: self }
+        TX_FLOW_CTL_STA_W::new(self)
     }
     #[doc = "Bits 20:21"]
     #[inline(always)]
     pub fn tx_pause_frm_slot(&mut self) -> TX_PAUSE_FRM_SLOT_W {
-        TX_PAUSE_FRM_SLOT_W { w: self }
+        TX_PAUSE_FRM_SLOT_W::new(self)
     }
     #[doc = "Bits 4:19"]
     #[inline(always)]
     pub fn pause_time(&mut self) -> PAUSE_TIME_W {
-        PAUSE_TIME_W { w: self }
+        PAUSE_TIME_W::new(self)
     }
     #[doc = "Bit 1"]
     #[inline(always)]
     pub fn zqp_frm_en(&mut self) -> ZQP_FRM_EN_W {
-        ZQP_FRM_EN_W { w: self }
+        ZQP_FRM_EN_W::new(self)
     }
     #[doc = "Bit 0 - TX Flow Control Enable"]
     #[inline(always)]
     pub fn tx_flow_ctl_en(&mut self) -> TX_FLOW_CTL_EN_W {
-        TX_FLOW_CTL_EN_W { w: self }
+        TX_FLOW_CTL_EN_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
