@@ -49,13 +49,9 @@ impl From<ADC_CH_CMP_EN_A> for bool {
     }
 }
 #[doc = "Fields `ADC_CH(0-1)_CMP_EN` reader - Channel Compare Enable"]
-pub struct ADC_CH_CMP_EN_R(crate::FieldReader<bool>);
+pub type ADC_CH_CMP_EN_R = crate::BitReader<ADC_CH_CMP_EN_A>;
 impl ADC_CH_CMP_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        ADC_CH_CMP_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ADC_CH_CMP_EN_A {
         match self.bits {
@@ -66,31 +62,18 @@ impl ADC_CH_CMP_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == ADC_CH_CMP_EN_A::DISABLE
+        *self == ADC_CH_CMP_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == ADC_CH_CMP_EN_A::ENABLE
+        *self == ADC_CH_CMP_EN_A::ENABLE
     }
 }
-impl core::ops::Deref for ADC_CH_CMP_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `ADC_CH(0-1)_CMP_EN` const generic writer - Channel Compare Enable"]
-pub struct ADC_CH_CMP_EN_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> ADC_CH_CMP_EN_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ADC_CH_CMP_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `ADC_CH(0-1)_CMP_EN` writer - Channel Compare Enable"]
+pub type ADC_CH_CMP_EN_W<'a, const O: u8> =
+    crate::BitWriter<'a, u32, GP_CS_EN_SPEC, ADC_CH_CMP_EN_A, O>;
+impl<'a, const O: u8> ADC_CH_CMP_EN_W<'a, O> {
     #[doc = "Disable"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -101,22 +84,6 @@ impl<'a, const O: usize> ADC_CH_CMP_EN_W<'a, O> {
     pub fn enable(self) -> &'a mut W {
         self.variant(ADC_CH_CMP_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 #[doc = "Analog Input Channel Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +100,9 @@ impl From<ADC_CH_SELECT_A> for bool {
     }
 }
 #[doc = "Fields `ADC_CH(0-1)_SELECT` reader - Analog Input Channel Select"]
-pub struct ADC_CH_SELECT_R(crate::FieldReader<bool>);
+pub type ADC_CH_SELECT_R = crate::BitReader<ADC_CH_SELECT_A>;
 impl ADC_CH_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        ADC_CH_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ADC_CH_SELECT_A {
         match self.bits {
@@ -150,31 +113,18 @@ impl ADC_CH_SELECT_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == ADC_CH_SELECT_A::DISABLE
+        *self == ADC_CH_SELECT_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == ADC_CH_SELECT_A::ENABLE
+        *self == ADC_CH_SELECT_A::ENABLE
     }
 }
-impl core::ops::Deref for ADC_CH_SELECT_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `ADC_CH(0-1)_SELECT` const generic writer - Analog Input Channel Select"]
-pub struct ADC_CH_SELECT_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> ADC_CH_SELECT_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ADC_CH_SELECT_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
+#[doc = "Fields `ADC_CH(0-1)_SELECT` writer - Analog Input Channel Select"]
+pub type ADC_CH_SELECT_W<'a, const O: u8> =
+    crate::BitWriter<'a, u32, GP_CS_EN_SPEC, ADC_CH_SELECT_A, O>;
+impl<'a, const O: u8> ADC_CH_SELECT_W<'a, O> {
     #[doc = "Disable"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -185,27 +135,11 @@ impl<'a, const O: usize> ADC_CH_SELECT_W<'a, O> {
     pub fn enable(self) -> &'a mut W {
         self.variant(ADC_CH_SELECT_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << O)) | ((value as u32 & 1) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "Channel Compare Enable"]
     #[inline(always)]
-    pub unsafe fn adc_ch_cmp_en(&self, n: usize) -> ADC_CH_CMP_EN_R {
+    pub unsafe fn adc_ch_cmp_en(&self, n: u8) -> ADC_CH_CMP_EN_R {
         ADC_CH_CMP_EN_R::new(((self.bits >> (n + 16)) & 1) != 0)
     }
     #[doc = "Bit 16 - Channel Compare Enable"]
@@ -220,7 +154,7 @@ impl R {
     }
     #[doc = "Analog Input Channel Select"]
     #[inline(always)]
-    pub unsafe fn adc_ch_select(&self, n: usize) -> ADC_CH_SELECT_R {
+    pub unsafe fn adc_ch_select(&self, n: u8) -> ADC_CH_SELECT_R {
         ADC_CH_SELECT_R::new(((self.bits >> n) & 1) != 0)
     }
     #[doc = "Bit 0 - Analog Input Channel Select"]
@@ -237,33 +171,33 @@ impl R {
 impl W {
     #[doc = "Channel Compare Enable"]
     #[inline(always)]
-    pub unsafe fn adc_ch_cmp_en<const O: usize>(&mut self) -> ADC_CH_CMP_EN_W<O> {
-        ADC_CH_CMP_EN_W { w: self }
+    pub unsafe fn adc_ch_cmp_en<const O: u8>(&mut self) -> ADC_CH_CMP_EN_W<O> {
+        ADC_CH_CMP_EN_W::new(self)
     }
     #[doc = "Bit 16 - Channel Compare Enable"]
     #[inline(always)]
     pub fn adc_ch0_cmp_en(&mut self) -> ADC_CH_CMP_EN_W<16> {
-        ADC_CH_CMP_EN_W { w: self }
+        ADC_CH_CMP_EN_W::new(self)
     }
     #[doc = "Bit 17 - Channel Compare Enable"]
     #[inline(always)]
     pub fn adc_ch1_cmp_en(&mut self) -> ADC_CH_CMP_EN_W<17> {
-        ADC_CH_CMP_EN_W { w: self }
+        ADC_CH_CMP_EN_W::new(self)
     }
     #[doc = "Analog Input Channel Select"]
     #[inline(always)]
-    pub unsafe fn adc_ch_select<const O: usize>(&mut self) -> ADC_CH_SELECT_W<O> {
-        ADC_CH_SELECT_W { w: self }
+    pub unsafe fn adc_ch_select<const O: u8>(&mut self) -> ADC_CH_SELECT_W<O> {
+        ADC_CH_SELECT_W::new(self)
     }
     #[doc = "Bit 0 - Analog Input Channel Select"]
     #[inline(always)]
     pub fn adc_ch0_select(&mut self) -> ADC_CH_SELECT_W<0> {
-        ADC_CH_SELECT_W { w: self }
+        ADC_CH_SELECT_W::new(self)
     }
     #[doc = "Bit 1 - Analog Input Channel Select"]
     #[inline(always)]
     pub fn adc_ch1_select(&mut self) -> ADC_CH_SELECT_W<1> {
-        ADC_CH_SELECT_W { w: self }
+        ADC_CH_SELECT_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
