@@ -52,13 +52,9 @@ impl From<PC_PULL_A> for u8 {
     }
 }
 #[doc = "Fields `PC(0-12)_PULL` reader - PC Pull_up/down Select"]
-pub struct PC_PULL_R(crate::FieldReader<u8>);
+pub type PC_PULL_R = crate::FieldReader<u8, PC_PULL_A>;
 impl PC_PULL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PC_PULL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PC_PULL_A {
         match self.bits {
@@ -71,36 +67,23 @@ impl PC_PULL_R {
     #[doc = "Checks if the value of the field is `PULL_DISABLE`"]
     #[inline(always)]
     pub fn is_pull_disable(&self) -> bool {
-        **self == PC_PULL_A::PULL_DISABLE
+        *self == PC_PULL_A::PULL_DISABLE
     }
     #[doc = "Checks if the value of the field is `PULL_UP`"]
     #[inline(always)]
     pub fn is_pull_up(&self) -> bool {
-        **self == PC_PULL_A::PULL_UP
+        *self == PC_PULL_A::PULL_UP
     }
     #[doc = "Checks if the value of the field is `PULL_DOWN`"]
     #[inline(always)]
     pub fn is_pull_down(&self) -> bool {
-        **self == PC_PULL_A::PULL_DOWN
+        *self == PC_PULL_A::PULL_DOWN
     }
 }
-impl core::ops::Deref for PC_PULL_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `PC(0-12)_PULL` const generic writer - PC Pull_up/down Select"]
-pub struct PC_PULL_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> PC_PULL_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PC_PULL_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
+#[doc = "Fields `PC(0-12)_PULL` writer - PC Pull_up/down Select"]
+pub type PC_PULL_W<'a, const O: u8> =
+    crate::FieldWriter<'a, u32, PB_PULL0_SPEC, u8, PC_PULL_A, 2, O>;
+impl<'a, const O: u8> PC_PULL_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn pull_disable(self) -> &'a mut W {
@@ -116,17 +99,11 @@ impl<'a, const O: usize> PC_PULL_W<'a, O> {
     pub fn pull_down(self) -> &'a mut W {
         self.variant(PC_PULL_A::PULL_DOWN)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << O)) | ((value as u32 & 3) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "PC Pull_up/down Select"]
     #[inline(always)]
-    pub unsafe fn pc_pull(&self, n: usize) -> PC_PULL_R {
+    pub unsafe fn pc_pull(&self, n: u8) -> PC_PULL_R {
         PC_PULL_R::new(((self.bits >> (n * 2)) & 3) as u8)
     }
     #[doc = "Bits 0:1 - PC Pull_up/down Select"]
@@ -198,73 +175,73 @@ impl R {
 impl W {
     #[doc = "PC Pull_up/down Select"]
     #[inline(always)]
-    pub unsafe fn pc_pull<const O: usize>(&mut self) -> PC_PULL_W<O> {
-        PC_PULL_W { w: self }
+    pub unsafe fn pc_pull<const O: u8>(&mut self) -> PC_PULL_W<O> {
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 0:1 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc0_pull(&mut self) -> PC_PULL_W<0> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 2:3 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc1_pull(&mut self) -> PC_PULL_W<2> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 4:5 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc2_pull(&mut self) -> PC_PULL_W<4> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 6:7 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc3_pull(&mut self) -> PC_PULL_W<6> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 8:9 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc4_pull(&mut self) -> PC_PULL_W<8> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 10:11 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc5_pull(&mut self) -> PC_PULL_W<10> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 12:13 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc6_pull(&mut self) -> PC_PULL_W<12> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 14:15 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc7_pull(&mut self) -> PC_PULL_W<14> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 16:17 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc8_pull(&mut self) -> PC_PULL_W<16> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 18:19 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc9_pull(&mut self) -> PC_PULL_W<18> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 20:21 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc10_pull(&mut self) -> PC_PULL_W<20> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 22:23 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc11_pull(&mut self) -> PC_PULL_W<22> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Bits 24:25 - PC Pull_up/down Select"]
     #[inline(always)]
     pub fn pc12_pull(&mut self) -> PC_PULL_W<24> {
-        PC_PULL_W { w: self }
+        PC_PULL_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
