@@ -35,32 +35,9 @@ impl From<crate::W<PC_EINT_DEB_SPEC>> for W {
     }
 }
 #[doc = "Field `DEB_CLK_PRE_SCALE` reader - Debounce Clock Pre_scale n"]
-pub struct DEB_CLK_PRE_SCALE_R(crate::FieldReader<u8>);
-impl DEB_CLK_PRE_SCALE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        DEB_CLK_PRE_SCALE_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DEB_CLK_PRE_SCALE_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DEB_CLK_PRE_SCALE_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `DEB_CLK_PRE_SCALE` writer - Debounce Clock Pre_scale n"]
-pub struct DEB_CLK_PRE_SCALE_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DEB_CLK_PRE_SCALE_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << 4)) | ((value as u32 & 7) << 4);
-        self.w
-    }
-}
+pub type DEB_CLK_PRE_SCALE_W<'a> = crate::FieldWriter<'a, u32, PC_EINT_DEB_SPEC, u8, u8, 3, 4>;
 #[doc = "PIO Interrupt Clock Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum PIO_INT_CLK_SELECT_A {
@@ -76,13 +53,9 @@ impl From<PIO_INT_CLK_SELECT_A> for bool {
     }
 }
 #[doc = "Field `PIO_INT_CLK_SELECT` reader - PIO Interrupt Clock Select"]
-pub struct PIO_INT_CLK_SELECT_R(crate::FieldReader<bool>);
+pub type PIO_INT_CLK_SELECT_R = crate::BitReader<PIO_INT_CLK_SELECT_A>;
 impl PIO_INT_CLK_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PIO_INT_CLK_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PIO_INT_CLK_SELECT_A {
         match self.bits {
@@ -93,31 +66,18 @@ impl PIO_INT_CLK_SELECT_R {
     #[doc = "Checks if the value of the field is `LOSC_32KHZ`"]
     #[inline(always)]
     pub fn is_losc_32khz(&self) -> bool {
-        **self == PIO_INT_CLK_SELECT_A::LOSC_32KHZ
+        *self == PIO_INT_CLK_SELECT_A::LOSC_32KHZ
     }
     #[doc = "Checks if the value of the field is `HOSC_24MHZ`"]
     #[inline(always)]
     pub fn is_hosc_24mhz(&self) -> bool {
-        **self == PIO_INT_CLK_SELECT_A::HOSC_24MHZ
-    }
-}
-impl core::ops::Deref for PIO_INT_CLK_SELECT_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PIO_INT_CLK_SELECT_A::HOSC_24MHZ
     }
 }
 #[doc = "Field `PIO_INT_CLK_SELECT` writer - PIO Interrupt Clock Select"]
-pub struct PIO_INT_CLK_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PIO_INT_CLK_SELECT_W<'a> =
+    crate::BitWriter<'a, u32, PC_EINT_DEB_SPEC, PIO_INT_CLK_SELECT_A, 0>;
 impl<'a> PIO_INT_CLK_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PIO_INT_CLK_SELECT_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn losc_32khz(self) -> &'a mut W {
@@ -128,22 +88,6 @@ impl<'a> PIO_INT_CLK_SELECT_W<'a> {
     pub fn hosc_24mhz(self) -> &'a mut W {
         self.variant(PIO_INT_CLK_SELECT_A::HOSC_24MHZ)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bits 4:6 - Debounce Clock Pre_scale n"]
@@ -161,12 +105,12 @@ impl W {
     #[doc = "Bits 4:6 - Debounce Clock Pre_scale n"]
     #[inline(always)]
     pub fn deb_clk_pre_scale(&mut self) -> DEB_CLK_PRE_SCALE_W {
-        DEB_CLK_PRE_SCALE_W { w: self }
+        DEB_CLK_PRE_SCALE_W::new(self)
     }
     #[doc = "Bit 0 - PIO Interrupt Clock Select"]
     #[inline(always)]
     pub fn pio_int_clk_select(&mut self) -> PIO_INT_CLK_SELECT_W {
-        PIO_INT_CLK_SELECT_W { w: self }
+        PIO_INT_CLK_SELECT_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
