@@ -62,13 +62,9 @@ impl From<PD7_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD7_SELECT` reader - PD7 Select"]
-pub struct PD7_SELECT_R(crate::FieldReader<u8>);
+pub type PD7_SELECT_R = crate::FieldReader<u8, PD7_SELECT_A>;
 impl PD7_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD7_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD7_SELECT_A> {
         match self.bits {
@@ -86,61 +82,47 @@ impl PD7_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD7_SELECT_A::INPUT
+        *self == PD7_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D11`"]
     #[inline(always)]
     pub fn is_lcd0_d11(&self) -> bool {
-        **self == PD7_SELECT_A::LCD0_D11
+        *self == PD7_SELECT_A::LCD0_D11
     }
     #[doc = "Checks if the value of the field is `DSI_D2N`"]
     #[inline(always)]
     pub fn is_dsi_d2n(&self) -> bool {
-        **self == PD7_SELECT_A::DSI_D2N
+        *self == PD7_SELECT_A::DSI_D2N
     }
     #[doc = "Checks if the value of the field is `PD_EINT7`"]
     #[inline(always)]
     pub fn is_pd_eint7(&self) -> bool {
-        **self == PD7_SELECT_A::PD_EINT7
+        *self == PD7_SELECT_A::PD_EINT7
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD7_SELECT_A::OUTPUT
+        *self == PD7_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_CKN`"]
     #[inline(always)]
     pub fn is_lvds0_ckn(&self) -> bool {
-        **self == PD7_SELECT_A::LVDS0_CKN
+        *self == PD7_SELECT_A::LVDS0_CKN
     }
     #[doc = "Checks if the value of the field is `UART4_TX`"]
     #[inline(always)]
     pub fn is_uart4_tx(&self) -> bool {
-        **self == PD7_SELECT_A::UART4_TX
+        *self == PD7_SELECT_A::UART4_TX
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD7_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD7_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD7_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD7_SELECT` writer - PD7 Select"]
-pub struct PD7_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD7_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD7_SELECT_A, 4, 28>;
 impl<'a> PD7_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD7_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -181,12 +163,6 @@ impl<'a> PD7_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD7_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 28)) | ((value as u32 & 0x0f) << 28);
-        self.w
-    }
 }
 #[doc = "PD6 Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -216,13 +192,9 @@ impl From<PD6_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD6_SELECT` reader - PD6 Select"]
-pub struct PD6_SELECT_R(crate::FieldReader<u8>);
+pub type PD6_SELECT_R = crate::FieldReader<u8, PD6_SELECT_A>;
 impl PD6_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD6_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD6_SELECT_A> {
         match self.bits {
@@ -240,61 +212,47 @@ impl PD6_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD6_SELECT_A::INPUT
+        *self == PD6_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D10`"]
     #[inline(always)]
     pub fn is_lcd0_d10(&self) -> bool {
-        **self == PD6_SELECT_A::LCD0_D10
+        *self == PD6_SELECT_A::LCD0_D10
     }
     #[doc = "Checks if the value of the field is `DSI_D2P`"]
     #[inline(always)]
     pub fn is_dsi_d2p(&self) -> bool {
-        **self == PD6_SELECT_A::DSI_D2P
+        *self == PD6_SELECT_A::DSI_D2P
     }
     #[doc = "Checks if the value of the field is `PD_EINT6`"]
     #[inline(always)]
     pub fn is_pd_eint6(&self) -> bool {
-        **self == PD6_SELECT_A::PD_EINT6
+        *self == PD6_SELECT_A::PD_EINT6
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD6_SELECT_A::OUTPUT
+        *self == PD6_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_CKP`"]
     #[inline(always)]
     pub fn is_lvds0_ckp(&self) -> bool {
-        **self == PD6_SELECT_A::LVDS0_CKP
+        *self == PD6_SELECT_A::LVDS0_CKP
     }
     #[doc = "Checks if the value of the field is `UART5_RX`"]
     #[inline(always)]
     pub fn is_uart5_rx(&self) -> bool {
-        **self == PD6_SELECT_A::UART5_RX
+        *self == PD6_SELECT_A::UART5_RX
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD6_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD6_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD6_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD6_SELECT` writer - PD6 Select"]
-pub struct PD6_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD6_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD6_SELECT_A, 4, 24>;
 impl<'a> PD6_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD6_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -335,12 +293,6 @@ impl<'a> PD6_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD6_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 24)) | ((value as u32 & 0x0f) << 24);
-        self.w
-    }
 }
 #[doc = "PD5 Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -370,13 +322,9 @@ impl From<PD5_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD5_SELECT` reader - PD5 Select"]
-pub struct PD5_SELECT_R(crate::FieldReader<u8>);
+pub type PD5_SELECT_R = crate::FieldReader<u8, PD5_SELECT_A>;
 impl PD5_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD5_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD5_SELECT_A> {
         match self.bits {
@@ -394,61 +342,47 @@ impl PD5_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD5_SELECT_A::INPUT
+        *self == PD5_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D7`"]
     #[inline(always)]
     pub fn is_lcd0_d7(&self) -> bool {
-        **self == PD5_SELECT_A::LCD0_D7
+        *self == PD5_SELECT_A::LCD0_D7
     }
     #[doc = "Checks if the value of the field is `DSI_CKN`"]
     #[inline(always)]
     pub fn is_dsi_ckn(&self) -> bool {
-        **self == PD5_SELECT_A::DSI_CKN
+        *self == PD5_SELECT_A::DSI_CKN
     }
     #[doc = "Checks if the value of the field is `PD_EINT5`"]
     #[inline(always)]
     pub fn is_pd_eint5(&self) -> bool {
-        **self == PD5_SELECT_A::PD_EINT5
+        *self == PD5_SELECT_A::PD_EINT5
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD5_SELECT_A::OUTPUT
+        *self == PD5_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_V2N`"]
     #[inline(always)]
     pub fn is_lvds0_v2n(&self) -> bool {
-        **self == PD5_SELECT_A::LVDS0_V2N
+        *self == PD5_SELECT_A::LVDS0_V2N
     }
     #[doc = "Checks if the value of the field is `UART5_TX`"]
     #[inline(always)]
     pub fn is_uart5_tx(&self) -> bool {
-        **self == PD5_SELECT_A::UART5_TX
+        *self == PD5_SELECT_A::UART5_TX
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD5_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD5_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD5_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD5_SELECT` writer - PD5 Select"]
-pub struct PD5_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD5_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD5_SELECT_A, 4, 20>;
 impl<'a> PD5_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD5_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -489,12 +423,6 @@ impl<'a> PD5_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD5_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 20)) | ((value as u32 & 0x0f) << 20);
-        self.w
-    }
 }
 #[doc = "PD4 Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -524,13 +452,9 @@ impl From<PD4_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD4_SELECT` reader - PD4 Select"]
-pub struct PD4_SELECT_R(crate::FieldReader<u8>);
+pub type PD4_SELECT_R = crate::FieldReader<u8, PD4_SELECT_A>;
 impl PD4_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD4_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD4_SELECT_A> {
         match self.bits {
@@ -548,61 +472,47 @@ impl PD4_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD4_SELECT_A::INPUT
+        *self == PD4_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D6`"]
     #[inline(always)]
     pub fn is_lcd0_d6(&self) -> bool {
-        **self == PD4_SELECT_A::LCD0_D6
+        *self == PD4_SELECT_A::LCD0_D6
     }
     #[doc = "Checks if the value of the field is `DSI_CKP`"]
     #[inline(always)]
     pub fn is_dsi_ckp(&self) -> bool {
-        **self == PD4_SELECT_A::DSI_CKP
+        *self == PD4_SELECT_A::DSI_CKP
     }
     #[doc = "Checks if the value of the field is `PD_EINT4`"]
     #[inline(always)]
     pub fn is_pd_eint4(&self) -> bool {
-        **self == PD4_SELECT_A::PD_EINT4
+        *self == PD4_SELECT_A::PD_EINT4
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD4_SELECT_A::OUTPUT
+        *self == PD4_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_V2P`"]
     #[inline(always)]
     pub fn is_lvds0_v2p(&self) -> bool {
-        **self == PD4_SELECT_A::LVDS0_V2P
+        *self == PD4_SELECT_A::LVDS0_V2P
     }
     #[doc = "Checks if the value of the field is `UART2_CTS`"]
     #[inline(always)]
     pub fn is_uart2_cts(&self) -> bool {
-        **self == PD4_SELECT_A::UART2_CTS
+        *self == PD4_SELECT_A::UART2_CTS
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD4_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD4_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD4_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD4_SELECT` writer - PD4 Select"]
-pub struct PD4_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD4_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD4_SELECT_A, 4, 16>;
 impl<'a> PD4_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD4_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -643,12 +553,6 @@ impl<'a> PD4_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD4_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 16)) | ((value as u32 & 0x0f) << 16);
-        self.w
-    }
 }
 #[doc = "PD3 Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -678,13 +582,9 @@ impl From<PD3_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD3_SELECT` reader - PD3 Select"]
-pub struct PD3_SELECT_R(crate::FieldReader<u8>);
+pub type PD3_SELECT_R = crate::FieldReader<u8, PD3_SELECT_A>;
 impl PD3_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD3_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD3_SELECT_A> {
         match self.bits {
@@ -702,61 +602,47 @@ impl PD3_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD3_SELECT_A::INPUT
+        *self == PD3_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D5`"]
     #[inline(always)]
     pub fn is_lcd0_d5(&self) -> bool {
-        **self == PD3_SELECT_A::LCD0_D5
+        *self == PD3_SELECT_A::LCD0_D5
     }
     #[doc = "Checks if the value of the field is `DSI_D1N`"]
     #[inline(always)]
     pub fn is_dsi_d1n(&self) -> bool {
-        **self == PD3_SELECT_A::DSI_D1N
+        *self == PD3_SELECT_A::DSI_D1N
     }
     #[doc = "Checks if the value of the field is `PD_EINT3`"]
     #[inline(always)]
     pub fn is_pd_eint3(&self) -> bool {
-        **self == PD3_SELECT_A::PD_EINT3
+        *self == PD3_SELECT_A::PD_EINT3
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD3_SELECT_A::OUTPUT
+        *self == PD3_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_V1N`"]
     #[inline(always)]
     pub fn is_lvds0_v1n(&self) -> bool {
-        **self == PD3_SELECT_A::LVDS0_V1N
+        *self == PD3_SELECT_A::LVDS0_V1N
     }
     #[doc = "Checks if the value of the field is `UART2_RTS`"]
     #[inline(always)]
     pub fn is_uart2_rts(&self) -> bool {
-        **self == PD3_SELECT_A::UART2_RTS
+        *self == PD3_SELECT_A::UART2_RTS
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD3_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD3_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD3_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD3_SELECT` writer - PD3 Select"]
-pub struct PD3_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD3_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD3_SELECT_A, 4, 12>;
 impl<'a> PD3_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD3_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -797,12 +683,6 @@ impl<'a> PD3_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD3_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 12)) | ((value as u32 & 0x0f) << 12);
-        self.w
-    }
 }
 #[doc = "PD2 Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -832,13 +712,9 @@ impl From<PD2_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD2_SELECT` reader - PD2 Select"]
-pub struct PD2_SELECT_R(crate::FieldReader<u8>);
+pub type PD2_SELECT_R = crate::FieldReader<u8, PD2_SELECT_A>;
 impl PD2_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD2_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD2_SELECT_A> {
         match self.bits {
@@ -856,61 +732,47 @@ impl PD2_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD2_SELECT_A::INPUT
+        *self == PD2_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D4`"]
     #[inline(always)]
     pub fn is_lcd0_d4(&self) -> bool {
-        **self == PD2_SELECT_A::LCD0_D4
+        *self == PD2_SELECT_A::LCD0_D4
     }
     #[doc = "Checks if the value of the field is `DSI_D1P`"]
     #[inline(always)]
     pub fn is_dsi_d1p(&self) -> bool {
-        **self == PD2_SELECT_A::DSI_D1P
+        *self == PD2_SELECT_A::DSI_D1P
     }
     #[doc = "Checks if the value of the field is `PD_EINT2`"]
     #[inline(always)]
     pub fn is_pd_eint2(&self) -> bool {
-        **self == PD2_SELECT_A::PD_EINT2
+        *self == PD2_SELECT_A::PD_EINT2
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD2_SELECT_A::OUTPUT
+        *self == PD2_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_V1P`"]
     #[inline(always)]
     pub fn is_lvds0_v1p(&self) -> bool {
-        **self == PD2_SELECT_A::LVDS0_V1P
+        *self == PD2_SELECT_A::LVDS0_V1P
     }
     #[doc = "Checks if the value of the field is `UART2_RX`"]
     #[inline(always)]
     pub fn is_uart2_rx(&self) -> bool {
-        **self == PD2_SELECT_A::UART2_RX
+        *self == PD2_SELECT_A::UART2_RX
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD2_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD2_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD2_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD2_SELECT` writer - PD2 Select"]
-pub struct PD2_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD2_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD2_SELECT_A, 4, 8>;
 impl<'a> PD2_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD2_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -951,12 +813,6 @@ impl<'a> PD2_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD2_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 8)) | ((value as u32 & 0x0f) << 8);
-        self.w
-    }
 }
 #[doc = "PD1 Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -986,13 +842,9 @@ impl From<PD1_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD1_SELECT` reader - PD1 Select"]
-pub struct PD1_SELECT_R(crate::FieldReader<u8>);
+pub type PD1_SELECT_R = crate::FieldReader<u8, PD1_SELECT_A>;
 impl PD1_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD1_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD1_SELECT_A> {
         match self.bits {
@@ -1010,61 +862,47 @@ impl PD1_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD1_SELECT_A::INPUT
+        *self == PD1_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D3`"]
     #[inline(always)]
     pub fn is_lcd0_d3(&self) -> bool {
-        **self == PD1_SELECT_A::LCD0_D3
+        *self == PD1_SELECT_A::LCD0_D3
     }
     #[doc = "Checks if the value of the field is `DSI_D0N`"]
     #[inline(always)]
     pub fn is_dsi_d0n(&self) -> bool {
-        **self == PD1_SELECT_A::DSI_D0N
+        *self == PD1_SELECT_A::DSI_D0N
     }
     #[doc = "Checks if the value of the field is `PD_EINT1`"]
     #[inline(always)]
     pub fn is_pd_eint1(&self) -> bool {
-        **self == PD1_SELECT_A::PD_EINT1
+        *self == PD1_SELECT_A::PD_EINT1
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD1_SELECT_A::OUTPUT
+        *self == PD1_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_V0N`"]
     #[inline(always)]
     pub fn is_lvds0_v0n(&self) -> bool {
-        **self == PD1_SELECT_A::LVDS0_V0N
+        *self == PD1_SELECT_A::LVDS0_V0N
     }
     #[doc = "Checks if the value of the field is `UART2_TX`"]
     #[inline(always)]
     pub fn is_uart2_tx(&self) -> bool {
-        **self == PD1_SELECT_A::UART2_TX
+        *self == PD1_SELECT_A::UART2_TX
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD1_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD1_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD1_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD1_SELECT` writer - PD1 Select"]
-pub struct PD1_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD1_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD1_SELECT_A, 4, 4>;
 impl<'a> PD1_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD1_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -1105,12 +943,6 @@ impl<'a> PD1_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD1_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 4)) | ((value as u32 & 0x0f) << 4);
-        self.w
-    }
 }
 #[doc = "PD0 Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -1140,13 +972,9 @@ impl From<PD0_SELECT_A> for u8 {
     }
 }
 #[doc = "Field `PD0_SELECT` reader - PD0 Select"]
-pub struct PD0_SELECT_R(crate::FieldReader<u8>);
+pub type PD0_SELECT_R = crate::FieldReader<u8, PD0_SELECT_A>;
 impl PD0_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD0_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<PD0_SELECT_A> {
         match self.bits {
@@ -1164,61 +992,47 @@ impl PD0_SELECT_R {
     #[doc = "Checks if the value of the field is `INPUT`"]
     #[inline(always)]
     pub fn is_input(&self) -> bool {
-        **self == PD0_SELECT_A::INPUT
+        *self == PD0_SELECT_A::INPUT
     }
     #[doc = "Checks if the value of the field is `LCD0_D2`"]
     #[inline(always)]
     pub fn is_lcd0_d2(&self) -> bool {
-        **self == PD0_SELECT_A::LCD0_D2
+        *self == PD0_SELECT_A::LCD0_D2
     }
     #[doc = "Checks if the value of the field is `DSI_D0P`"]
     #[inline(always)]
     pub fn is_dsi_d0p(&self) -> bool {
-        **self == PD0_SELECT_A::DSI_D0P
+        *self == PD0_SELECT_A::DSI_D0P
     }
     #[doc = "Checks if the value of the field is `PD_EINT0`"]
     #[inline(always)]
     pub fn is_pd_eint0(&self) -> bool {
-        **self == PD0_SELECT_A::PD_EINT0
+        *self == PD0_SELECT_A::PD_EINT0
     }
     #[doc = "Checks if the value of the field is `OUTPUT`"]
     #[inline(always)]
     pub fn is_output(&self) -> bool {
-        **self == PD0_SELECT_A::OUTPUT
+        *self == PD0_SELECT_A::OUTPUT
     }
     #[doc = "Checks if the value of the field is `LVDS0_V0P`"]
     #[inline(always)]
     pub fn is_lvds0_v0p(&self) -> bool {
-        **self == PD0_SELECT_A::LVDS0_V0P
+        *self == PD0_SELECT_A::LVDS0_V0P
     }
     #[doc = "Checks if the value of the field is `TWI0_SCK`"]
     #[inline(always)]
     pub fn is_twi0_sck(&self) -> bool {
-        **self == PD0_SELECT_A::TWI0_SCK
+        *self == PD0_SELECT_A::TWI0_SCK
     }
     #[doc = "Checks if the value of the field is `IO_DISABLE`"]
     #[inline(always)]
     pub fn is_io_disable(&self) -> bool {
-        **self == PD0_SELECT_A::IO_DISABLE
-    }
-}
-impl core::ops::Deref for PD0_SELECT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PD0_SELECT_A::IO_DISABLE
     }
 }
 #[doc = "Field `PD0_SELECT` writer - PD0 Select"]
-pub struct PD0_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PD0_SELECT_W<'a> = crate::FieldWriter<'a, u32, PD_CFG0_SPEC, u8, PD0_SELECT_A, 4, 0>;
 impl<'a> PD0_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD0_SELECT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn input(self) -> &'a mut W {
@@ -1259,12 +1073,6 @@ impl<'a> PD0_SELECT_W<'a> {
     pub fn io_disable(self) -> &'a mut W {
         self.variant(PD0_SELECT_A::IO_DISABLE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x0f) | (value as u32 & 0x0f);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bits 28:31 - PD7 Select"]
@@ -1312,42 +1120,42 @@ impl W {
     #[doc = "Bits 28:31 - PD7 Select"]
     #[inline(always)]
     pub fn pd7_select(&mut self) -> PD7_SELECT_W {
-        PD7_SELECT_W { w: self }
+        PD7_SELECT_W::new(self)
     }
     #[doc = "Bits 24:27 - PD6 Select"]
     #[inline(always)]
     pub fn pd6_select(&mut self) -> PD6_SELECT_W {
-        PD6_SELECT_W { w: self }
+        PD6_SELECT_W::new(self)
     }
     #[doc = "Bits 20:23 - PD5 Select"]
     #[inline(always)]
     pub fn pd5_select(&mut self) -> PD5_SELECT_W {
-        PD5_SELECT_W { w: self }
+        PD5_SELECT_W::new(self)
     }
     #[doc = "Bits 16:19 - PD4 Select"]
     #[inline(always)]
     pub fn pd4_select(&mut self) -> PD4_SELECT_W {
-        PD4_SELECT_W { w: self }
+        PD4_SELECT_W::new(self)
     }
     #[doc = "Bits 12:15 - PD3 Select"]
     #[inline(always)]
     pub fn pd3_select(&mut self) -> PD3_SELECT_W {
-        PD3_SELECT_W { w: self }
+        PD3_SELECT_W::new(self)
     }
     #[doc = "Bits 8:11 - PD2 Select"]
     #[inline(always)]
     pub fn pd2_select(&mut self) -> PD2_SELECT_W {
-        PD2_SELECT_W { w: self }
+        PD2_SELECT_W::new(self)
     }
     #[doc = "Bits 4:7 - PD1 Select"]
     #[inline(always)]
     pub fn pd1_select(&mut self) -> PD1_SELECT_W {
-        PD1_SELECT_W { w: self }
+        PD1_SELECT_W::new(self)
     }
     #[doc = "Bits 0:3 - PD0 Select"]
     #[inline(always)]
     pub fn pd0_select(&mut self) -> PD0_SELECT_W {
-        PD0_SELECT_W { w: self }
+        PD0_SELECT_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
