@@ -35,32 +35,9 @@ impl From<crate::W<PD_DAT_SPEC>> for W {
     }
 }
 #[doc = "Field `pd_dat` reader - "]
-pub struct PD_DAT_R(crate::FieldReader<u32>);
-impl PD_DAT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u32) -> Self {
-        PD_DAT_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for PD_DAT_R {
-    type Target = crate::FieldReader<u32>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PD_DAT_R = crate::FieldReader<u32, u32>;
 #[doc = "Field `pd_dat` writer - "]
-pub struct PD_DAT_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PD_DAT_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u32) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x007f_ffff) | (value as u32 & 0x007f_ffff);
-        self.w
-    }
-}
+pub type PD_DAT_W<'a> = crate::FieldWriter<'a, u32, PD_DAT_SPEC, u32, u32, 23, 0>;
 impl R {
     #[doc = "Bits 0:22"]
     #[inline(always)]
@@ -72,7 +49,7 @@ impl W {
     #[doc = "Bits 0:22"]
     #[inline(always)]
     pub fn pd_dat(&mut self) -> PD_DAT_W {
-        PD_DAT_W { w: self }
+        PD_DAT_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
