@@ -54,13 +54,9 @@ impl From<PD_DRV_A> for u8 {
     }
 }
 #[doc = "Fields `PD(0-7)_DRV` reader - PD Multi_Driving Select"]
-pub struct PD_DRV_R(crate::FieldReader<u8>);
+pub type PD_DRV_R = crate::FieldReader<u8, PD_DRV_A>;
 impl PD_DRV_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PD_DRV_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PD_DRV_A {
         match self.bits {
@@ -74,41 +70,28 @@ impl PD_DRV_R {
     #[doc = "Checks if the value of the field is `L0`"]
     #[inline(always)]
     pub fn is_l0(&self) -> bool {
-        **self == PD_DRV_A::L0
+        *self == PD_DRV_A::L0
     }
     #[doc = "Checks if the value of the field is `L1`"]
     #[inline(always)]
     pub fn is_l1(&self) -> bool {
-        **self == PD_DRV_A::L1
+        *self == PD_DRV_A::L1
     }
     #[doc = "Checks if the value of the field is `L2`"]
     #[inline(always)]
     pub fn is_l2(&self) -> bool {
-        **self == PD_DRV_A::L2
+        *self == PD_DRV_A::L2
     }
     #[doc = "Checks if the value of the field is `L3`"]
     #[inline(always)]
     pub fn is_l3(&self) -> bool {
-        **self == PD_DRV_A::L3
+        *self == PD_DRV_A::L3
     }
 }
-impl core::ops::Deref for PD_DRV_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `PD(0-7)_DRV` const generic writer - PD Multi_Driving Select"]
-pub struct PD_DRV_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> PD_DRV_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PD_DRV_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
+#[doc = "Fields `PD(0-7)_DRV` writer - PD Multi_Driving Select"]
+pub type PD_DRV_W<'a, const O: u8> =
+    crate::FieldWriterSafe<'a, u32, PD_DRV0_SPEC, u8, PD_DRV_A, 2, O>;
+impl<'a, const O: u8> PD_DRV_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn l0(self) -> &'a mut W {
@@ -129,17 +112,11 @@ impl<'a, const O: usize> PD_DRV_W<'a, O> {
     pub fn l3(self) -> &'a mut W {
         self.variant(PD_DRV_A::L3)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << O)) | ((value as u32 & 3) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "PD Multi_Driving Select"]
     #[inline(always)]
-    pub unsafe fn pd_drv(&self, n: usize) -> PD_DRV_R {
+    pub unsafe fn pd_drv(&self, n: u8) -> PD_DRV_R {
         PD_DRV_R::new(((self.bits >> (n * 4)) & 3) as u8)
     }
     #[doc = "Bits 0:1 - PD Multi_Driving Select"]
@@ -186,48 +163,48 @@ impl R {
 impl W {
     #[doc = "PD Multi_Driving Select"]
     #[inline(always)]
-    pub unsafe fn pd_drv<const O: usize>(&mut self) -> PD_DRV_W<O> {
-        PD_DRV_W { w: self }
+    pub unsafe fn pd_drv<const O: u8>(&mut self) -> PD_DRV_W<O> {
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 0:1 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd0_drv(&mut self) -> PD_DRV_W<0> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 4:5 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd1_drv(&mut self) -> PD_DRV_W<4> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 8:9 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd2_drv(&mut self) -> PD_DRV_W<8> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 12:13 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd3_drv(&mut self) -> PD_DRV_W<12> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 16:17 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd4_drv(&mut self) -> PD_DRV_W<16> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 20:21 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd5_drv(&mut self) -> PD_DRV_W<20> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 24:25 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd6_drv(&mut self) -> PD_DRV_W<24> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Bits 28:29 - PD Multi_Driving Select"]
     #[inline(always)]
     pub fn pd7_drv(&mut self) -> PD_DRV_W<28> {
-        PD_DRV_W { w: self }
+        PD_DRV_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
