@@ -54,13 +54,9 @@ impl From<PF_DRV_A> for u8 {
     }
 }
 #[doc = "Fields `PF(0-6)_DRV` reader - PF Multi_Driving Select"]
-pub struct PF_DRV_R(crate::FieldReader<u8>);
+pub type PF_DRV_R = crate::FieldReader<u8, PF_DRV_A>;
 impl PF_DRV_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PF_DRV_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PF_DRV_A {
         match self.bits {
@@ -74,41 +70,28 @@ impl PF_DRV_R {
     #[doc = "Checks if the value of the field is `L0`"]
     #[inline(always)]
     pub fn is_l0(&self) -> bool {
-        **self == PF_DRV_A::L0
+        *self == PF_DRV_A::L0
     }
     #[doc = "Checks if the value of the field is `L1`"]
     #[inline(always)]
     pub fn is_l1(&self) -> bool {
-        **self == PF_DRV_A::L1
+        *self == PF_DRV_A::L1
     }
     #[doc = "Checks if the value of the field is `L2`"]
     #[inline(always)]
     pub fn is_l2(&self) -> bool {
-        **self == PF_DRV_A::L2
+        *self == PF_DRV_A::L2
     }
     #[doc = "Checks if the value of the field is `L3`"]
     #[inline(always)]
     pub fn is_l3(&self) -> bool {
-        **self == PF_DRV_A::L3
+        *self == PF_DRV_A::L3
     }
 }
-impl core::ops::Deref for PF_DRV_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
-#[doc = "Fields `PF(0-6)_DRV` const generic writer - PF Multi_Driving Select"]
-pub struct PF_DRV_W<'a, const O: usize> {
-    w: &'a mut W,
-}
-impl<'a, const O: usize> PF_DRV_W<'a, O> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PF_DRV_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
+#[doc = "Fields `PF(0-6)_DRV` writer - PF Multi_Driving Select"]
+pub type PF_DRV_W<'a, const O: u8> =
+    crate::FieldWriterSafe<'a, u32, PF_DRV0_SPEC, u8, PF_DRV_A, 2, O>;
+impl<'a, const O: u8> PF_DRV_W<'a, O> {
     #[doc = "`0`"]
     #[inline(always)]
     pub fn l0(self) -> &'a mut W {
@@ -129,17 +112,11 @@ impl<'a, const O: usize> PF_DRV_W<'a, O> {
     pub fn l3(self) -> &'a mut W {
         self.variant(PF_DRV_A::L3)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << O)) | ((value as u32 & 3) << O);
-        self.w
-    }
 }
 impl R {
     #[doc = "PF Multi_Driving Select"]
     #[inline(always)]
-    pub unsafe fn pf_drv(&self, n: usize) -> PF_DRV_R {
+    pub unsafe fn pf_drv(&self, n: u8) -> PF_DRV_R {
         PF_DRV_R::new(((self.bits >> (n * 4)) & 3) as u8)
     }
     #[doc = "Bits 0:1 - PF Multi_Driving Select"]
@@ -181,43 +158,43 @@ impl R {
 impl W {
     #[doc = "PF Multi_Driving Select"]
     #[inline(always)]
-    pub unsafe fn pf_drv<const O: usize>(&mut self) -> PF_DRV_W<O> {
-        PF_DRV_W { w: self }
+    pub unsafe fn pf_drv<const O: u8>(&mut self) -> PF_DRV_W<O> {
+        PF_DRV_W::new(self)
     }
     #[doc = "Bits 0:1 - PF Multi_Driving Select"]
     #[inline(always)]
     pub fn pf0_drv(&mut self) -> PF_DRV_W<0> {
-        PF_DRV_W { w: self }
+        PF_DRV_W::new(self)
     }
     #[doc = "Bits 4:5 - PF Multi_Driving Select"]
     #[inline(always)]
     pub fn pf1_drv(&mut self) -> PF_DRV_W<4> {
-        PF_DRV_W { w: self }
+        PF_DRV_W::new(self)
     }
     #[doc = "Bits 8:9 - PF Multi_Driving Select"]
     #[inline(always)]
     pub fn pf2_drv(&mut self) -> PF_DRV_W<8> {
-        PF_DRV_W { w: self }
+        PF_DRV_W::new(self)
     }
     #[doc = "Bits 12:13 - PF Multi_Driving Select"]
     #[inline(always)]
     pub fn pf3_drv(&mut self) -> PF_DRV_W<12> {
-        PF_DRV_W { w: self }
+        PF_DRV_W::new(self)
     }
     #[doc = "Bits 16:17 - PF Multi_Driving Select"]
     #[inline(always)]
     pub fn pf4_drv(&mut self) -> PF_DRV_W<16> {
-        PF_DRV_W { w: self }
+        PF_DRV_W::new(self)
     }
     #[doc = "Bits 20:21 - PF Multi_Driving Select"]
     #[inline(always)]
     pub fn pf5_drv(&mut self) -> PF_DRV_W<20> {
-        PF_DRV_W { w: self }
+        PF_DRV_W::new(self)
     }
     #[doc = "Bits 24:25 - PF Multi_Driving Select"]
     #[inline(always)]
     pub fn pf6_drv(&mut self) -> PF_DRV_W<24> {
-        PF_DRV_W { w: self }
+        PF_DRV_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
