@@ -49,13 +49,9 @@ impl From<GLOBAL_INT_EN_A> for bool {
     }
 }
 #[doc = "Field `GLOBAL_INT_EN` reader - "]
-pub struct GLOBAL_INT_EN_R(crate::FieldReader<bool>);
+pub type GLOBAL_INT_EN_R = crate::BitReader<GLOBAL_INT_EN_A>;
 impl GLOBAL_INT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        GLOBAL_INT_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> GLOBAL_INT_EN_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl GLOBAL_INT_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == GLOBAL_INT_EN_A::DISABLE
+        *self == GLOBAL_INT_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == GLOBAL_INT_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for GLOBAL_INT_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == GLOBAL_INT_EN_A::ENABLE
     }
 }
 #[doc = "Field `GLOBAL_INT_EN` writer - "]
-pub struct GLOBAL_INT_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type GLOBAL_INT_EN_W<'a> = crate::BitWriter<'a, u32, LEDC_INT_CTRL_SPEC, GLOBAL_INT_EN_A, 5>;
 impl<'a> GLOBAL_INT_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: GLOBAL_INT_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> GLOBAL_INT_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(GLOBAL_INT_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 5)) | ((value as u32 & 1) << 5);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<FIFO_OVERFLOW_INT_EN_A> for bool {
     }
 }
 #[doc = "Field `FIFO_OVERFLOW_INT_EN` reader - "]
-pub struct FIFO_OVERFLOW_INT_EN_R(crate::FieldReader<bool>);
+pub type FIFO_OVERFLOW_INT_EN_R = crate::BitReader<FIFO_OVERFLOW_INT_EN_A>;
 impl FIFO_OVERFLOW_INT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FIFO_OVERFLOW_INT_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FIFO_OVERFLOW_INT_EN_A {
         match self.bits {
@@ -150,31 +112,18 @@ impl FIFO_OVERFLOW_INT_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == FIFO_OVERFLOW_INT_EN_A::DISABLE
+        *self == FIFO_OVERFLOW_INT_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == FIFO_OVERFLOW_INT_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for FIFO_OVERFLOW_INT_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FIFO_OVERFLOW_INT_EN_A::ENABLE
     }
 }
 #[doc = "Field `FIFO_OVERFLOW_INT_EN` writer - "]
-pub struct FIFO_OVERFLOW_INT_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type FIFO_OVERFLOW_INT_EN_W<'a> =
+    crate::BitWriter<'a, u32, LEDC_INT_CTRL_SPEC, FIFO_OVERFLOW_INT_EN_A, 4>;
 impl<'a> FIFO_OVERFLOW_INT_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FIFO_OVERFLOW_INT_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -185,22 +134,6 @@ impl<'a> FIFO_OVERFLOW_INT_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(FIFO_OVERFLOW_INT_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -217,13 +150,9 @@ impl From<WAITDATA_TIMEOUT_INT_EN_A> for bool {
     }
 }
 #[doc = "Field `WAITDATA_TIMEOUT_INT_EN` reader - "]
-pub struct WAITDATA_TIMEOUT_INT_EN_R(crate::FieldReader<bool>);
+pub type WAITDATA_TIMEOUT_INT_EN_R = crate::BitReader<WAITDATA_TIMEOUT_INT_EN_A>;
 impl WAITDATA_TIMEOUT_INT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        WAITDATA_TIMEOUT_INT_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> WAITDATA_TIMEOUT_INT_EN_A {
         match self.bits {
@@ -234,31 +163,18 @@ impl WAITDATA_TIMEOUT_INT_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == WAITDATA_TIMEOUT_INT_EN_A::DISABLE
+        *self == WAITDATA_TIMEOUT_INT_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == WAITDATA_TIMEOUT_INT_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for WAITDATA_TIMEOUT_INT_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == WAITDATA_TIMEOUT_INT_EN_A::ENABLE
     }
 }
 #[doc = "Field `WAITDATA_TIMEOUT_INT_EN` writer - "]
-pub struct WAITDATA_TIMEOUT_INT_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type WAITDATA_TIMEOUT_INT_EN_W<'a> =
+    crate::BitWriter<'a, u32, LEDC_INT_CTRL_SPEC, WAITDATA_TIMEOUT_INT_EN_A, 3>;
 impl<'a> WAITDATA_TIMEOUT_INT_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: WAITDATA_TIMEOUT_INT_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -269,22 +185,6 @@ impl<'a> WAITDATA_TIMEOUT_INT_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(WAITDATA_TIMEOUT_INT_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -301,13 +201,9 @@ impl From<FIFO_CPUREQ_INT_EN_A> for bool {
     }
 }
 #[doc = "Field `FIFO_CPUREQ_INT_EN` reader - "]
-pub struct FIFO_CPUREQ_INT_EN_R(crate::FieldReader<bool>);
+pub type FIFO_CPUREQ_INT_EN_R = crate::BitReader<FIFO_CPUREQ_INT_EN_A>;
 impl FIFO_CPUREQ_INT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FIFO_CPUREQ_INT_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FIFO_CPUREQ_INT_EN_A {
         match self.bits {
@@ -318,31 +214,18 @@ impl FIFO_CPUREQ_INT_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == FIFO_CPUREQ_INT_EN_A::DISABLE
+        *self == FIFO_CPUREQ_INT_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == FIFO_CPUREQ_INT_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for FIFO_CPUREQ_INT_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FIFO_CPUREQ_INT_EN_A::ENABLE
     }
 }
 #[doc = "Field `FIFO_CPUREQ_INT_EN` writer - "]
-pub struct FIFO_CPUREQ_INT_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type FIFO_CPUREQ_INT_EN_W<'a> =
+    crate::BitWriter<'a, u32, LEDC_INT_CTRL_SPEC, FIFO_CPUREQ_INT_EN_A, 1>;
 impl<'a> FIFO_CPUREQ_INT_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FIFO_CPUREQ_INT_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -353,22 +236,6 @@ impl<'a> FIFO_CPUREQ_INT_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(FIFO_CPUREQ_INT_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -385,13 +252,9 @@ impl From<LED_TRANS_FINISH_INT_EN_A> for bool {
     }
 }
 #[doc = "Field `LED_TRANS_FINISH_INT_EN` reader - "]
-pub struct LED_TRANS_FINISH_INT_EN_R(crate::FieldReader<bool>);
+pub type LED_TRANS_FINISH_INT_EN_R = crate::BitReader<LED_TRANS_FINISH_INT_EN_A>;
 impl LED_TRANS_FINISH_INT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        LED_TRANS_FINISH_INT_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LED_TRANS_FINISH_INT_EN_A {
         match self.bits {
@@ -402,31 +265,18 @@ impl LED_TRANS_FINISH_INT_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == LED_TRANS_FINISH_INT_EN_A::DISABLE
+        *self == LED_TRANS_FINISH_INT_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == LED_TRANS_FINISH_INT_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for LED_TRANS_FINISH_INT_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == LED_TRANS_FINISH_INT_EN_A::ENABLE
     }
 }
 #[doc = "Field `LED_TRANS_FINISH_INT_EN` writer - "]
-pub struct LED_TRANS_FINISH_INT_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type LED_TRANS_FINISH_INT_EN_W<'a> =
+    crate::BitWriter<'a, u32, LEDC_INT_CTRL_SPEC, LED_TRANS_FINISH_INT_EN_A, 0>;
 impl<'a> LED_TRANS_FINISH_INT_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LED_TRANS_FINISH_INT_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -437,22 +287,6 @@ impl<'a> LED_TRANS_FINISH_INT_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(LED_TRANS_FINISH_INT_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 5"]
@@ -485,27 +319,27 @@ impl W {
     #[doc = "Bit 5"]
     #[inline(always)]
     pub fn global_int_en(&mut self) -> GLOBAL_INT_EN_W {
-        GLOBAL_INT_EN_W { w: self }
+        GLOBAL_INT_EN_W::new(self)
     }
     #[doc = "Bit 4"]
     #[inline(always)]
     pub fn fifo_overflow_int_en(&mut self) -> FIFO_OVERFLOW_INT_EN_W {
-        FIFO_OVERFLOW_INT_EN_W { w: self }
+        FIFO_OVERFLOW_INT_EN_W::new(self)
     }
     #[doc = "Bit 3"]
     #[inline(always)]
     pub fn waitdata_timeout_int_en(&mut self) -> WAITDATA_TIMEOUT_INT_EN_W {
-        WAITDATA_TIMEOUT_INT_EN_W { w: self }
+        WAITDATA_TIMEOUT_INT_EN_W::new(self)
     }
     #[doc = "Bit 1"]
     #[inline(always)]
     pub fn fifo_cpureq_int_en(&mut self) -> FIFO_CPUREQ_INT_EN_W {
-        FIFO_CPUREQ_INT_EN_W { w: self }
+        FIFO_CPUREQ_INT_EN_W::new(self)
     }
     #[doc = "Bit 0"]
     #[inline(always)]
     pub fn led_trans_finish_int_en(&mut self) -> LED_TRANS_FINISH_INT_EN_W {
-        LED_TRANS_FINISH_INT_EN_W { w: self }
+        LED_TRANS_FINISH_INT_EN_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
