@@ -35,32 +35,9 @@ impl From<crate::W<MCLAIM_SPEC>> for W {
     }
 }
 #[doc = "Field `mclaim` reader - "]
-pub struct MCLAIM_R(crate::FieldReader<u16>);
-impl MCLAIM_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        MCLAIM_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for MCLAIM_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type MCLAIM_R = crate::FieldReader<u16, u16>;
 #[doc = "Field `mclaim` writer - "]
-pub struct MCLAIM_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> MCLAIM_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03ff) | (value as u32 & 0x03ff);
-        self.w
-    }
-}
+pub type MCLAIM_W<'a> = crate::FieldWriter<'a, u32, MCLAIM_SPEC, u16, u16, 10, 0>;
 impl R {
     #[doc = "Bits 0:9"]
     #[inline(always)]
@@ -72,7 +49,7 @@ impl W {
     #[doc = "Bits 0:9"]
     #[inline(always)]
     pub fn mclaim(&mut self) -> MCLAIM_W {
-        MCLAIM_W { w: self }
+        MCLAIM_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
