@@ -35,32 +35,9 @@ impl From<crate::W<RF1P_CFG_REG_SPEC>> for W {
     }
 }
 #[doc = "Field `RF1P_CFG` reader - RF1P Configuration"]
-pub struct RF1P_CFG_R(crate::FieldReader<u8>);
-impl RF1P_CFG_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        RF1P_CFG_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RF1P_CFG_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RF1P_CFG_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `RF1P_CFG` writer - RF1P Configuration"]
-pub struct RF1P_CFG_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RF1P_CFG_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
-        self.w
-    }
-}
+pub type RF1P_CFG_W<'a> = crate::FieldWriter<'a, u32, RF1P_CFG_REG_SPEC, u8, u8, 8, 0>;
 impl R {
     #[doc = "Bits 0:7 - RF1P Configuration"]
     #[inline(always)]
@@ -72,7 +49,7 @@ impl W {
     #[doc = "Bits 0:7 - RF1P Configuration"]
     #[inline(always)]
     pub fn rf1p_cfg(&mut self) -> RF1P_CFG_W {
-        RF1P_CFG_W { w: self }
+        RF1P_CFG_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
