@@ -35,32 +35,9 @@ impl From<crate::W<ROM_CFG_REG_SPEC>> for W {
     }
 }
 #[doc = "Field `ROM_CFG` reader - ROM Configuration"]
-pub struct ROM_CFG_R(crate::FieldReader<u8>);
-impl ROM_CFG_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        ROM_CFG_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for ROM_CFG_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ROM_CFG_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `ROM_CFG` writer - ROM Configuration"]
-pub struct ROM_CFG_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ROM_CFG_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
-        self.w
-    }
-}
+pub type ROM_CFG_W<'a> = crate::FieldWriter<'a, u32, ROM_CFG_REG_SPEC, u8, u8, 8, 0>;
 impl R {
     #[doc = "Bits 0:7 - ROM Configuration"]
     #[inline(always)]
@@ -72,7 +49,7 @@ impl W {
     #[doc = "Bits 0:7 - ROM Configuration"]
     #[inline(always)]
     pub fn rom_cfg(&mut self) -> ROM_CFG_W {
-        ROM_CFG_W { w: self }
+        ROM_CFG_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
