@@ -35,42 +35,9 @@ impl From<crate::W<SMHC_CMD_SPEC>> for W {
     }
 }
 #[doc = "Field `CMD_LOAD` reader - Start Command"]
-pub struct CMD_LOAD_R(crate::FieldReader<bool>);
-impl CMD_LOAD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        CMD_LOAD_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for CMD_LOAD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CMD_LOAD_R = crate::BitReader<bool>;
 #[doc = "Field `CMD_LOAD` writer - Start Command"]
-pub struct CMD_LOAD_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> CMD_LOAD_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
-}
+pub type CMD_LOAD_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, bool, 31>;
 #[doc = "Voltage Switch\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum VOL_SW_A {
@@ -86,13 +53,9 @@ impl From<VOL_SW_A> for bool {
     }
 }
 #[doc = "Field `VOL_SW` reader - Voltage Switch"]
-pub struct VOL_SW_R(crate::FieldReader<bool>);
+pub type VOL_SW_R = crate::BitReader<VOL_SW_A>;
 impl VOL_SW_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        VOL_SW_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> VOL_SW_A {
         match self.bits {
@@ -103,31 +66,17 @@ impl VOL_SW_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == VOL_SW_A::NORMAL
+        *self == VOL_SW_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `VOLTAGE_SWITCH`"]
     #[inline(always)]
     pub fn is_voltage_switch(&self) -> bool {
-        **self == VOL_SW_A::VOLTAGE_SWITCH
-    }
-}
-impl core::ops::Deref for VOL_SW_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == VOL_SW_A::VOLTAGE_SWITCH
     }
 }
 #[doc = "Field `VOL_SW` writer - Voltage Switch"]
-pub struct VOL_SW_W<'a> {
-    w: &'a mut W,
-}
+pub type VOL_SW_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, VOL_SW_A, 28>;
 impl<'a> VOL_SW_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: VOL_SW_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Normal command"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -138,97 +87,15 @@ impl<'a> VOL_SW_W<'a> {
     pub fn voltage_switch(self) -> &'a mut W {
         self.variant(VOL_SW_A::VOLTAGE_SWITCH)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 28)) | ((value as u32 & 1) << 28);
-        self.w
-    }
 }
 #[doc = "Field `BOOT_ABT` reader - Boot Abort"]
-pub struct BOOT_ABT_R(crate::FieldReader<bool>);
-impl BOOT_ABT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        BOOT_ABT_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for BOOT_ABT_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type BOOT_ABT_R = crate::BitReader<bool>;
 #[doc = "Field `BOOT_ABT` writer - Boot Abort"]
-pub struct BOOT_ABT_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> BOOT_ABT_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
-        self.w
-    }
-}
+pub type BOOT_ABT_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, bool, 27>;
 #[doc = "Field `EXP_BOOT_ACK` reader - Expect Boot Acknowledge"]
-pub struct EXP_BOOT_ACK_R(crate::FieldReader<bool>);
-impl EXP_BOOT_ACK_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        EXP_BOOT_ACK_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for EXP_BOOT_ACK_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type EXP_BOOT_ACK_R = crate::BitReader<bool>;
 #[doc = "Field `EXP_BOOT_ACK` writer - Expect Boot Acknowledge"]
-pub struct EXP_BOOT_ACK_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> EXP_BOOT_ACK_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 26)) | ((value as u32 & 1) << 26);
-        self.w
-    }
-}
+pub type EXP_BOOT_ACK_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, bool, 26>;
 #[doc = "Boot Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
@@ -247,13 +114,9 @@ impl From<BOOT_MOD_A> for u8 {
     }
 }
 #[doc = "Field `BOOT_MOD` reader - Boot Mode"]
-pub struct BOOT_MOD_R(crate::FieldReader<u8>);
+pub type BOOT_MOD_R = crate::FieldReader<u8, BOOT_MOD_A>;
 impl BOOT_MOD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        BOOT_MOD_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<BOOT_MOD_A> {
         match self.bits {
@@ -266,36 +129,22 @@ impl BOOT_MOD_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == BOOT_MOD_A::NORMAL
+        *self == BOOT_MOD_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `MANDATORY_BOOT`"]
     #[inline(always)]
     pub fn is_mandatory_boot(&self) -> bool {
-        **self == BOOT_MOD_A::MANDATORY_BOOT
+        *self == BOOT_MOD_A::MANDATORY_BOOT
     }
     #[doc = "Checks if the value of the field is `ALTERNATE_BOOT`"]
     #[inline(always)]
     pub fn is_alternate_boot(&self) -> bool {
-        **self == BOOT_MOD_A::ALTERNATE_BOOT
-    }
-}
-impl core::ops::Deref for BOOT_MOD_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == BOOT_MOD_A::ALTERNATE_BOOT
     }
 }
 #[doc = "Field `BOOT_MOD` writer - Boot Mode"]
-pub struct BOOT_MOD_W<'a> {
-    w: &'a mut W,
-}
+pub type BOOT_MOD_W<'a> = crate::FieldWriter<'a, u32, SMHC_CMD_SPEC, u8, BOOT_MOD_A, 2, 24>;
 impl<'a> BOOT_MOD_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: BOOT_MOD_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "Normal command"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -311,12 +160,6 @@ impl<'a> BOOT_MOD_W<'a> {
     pub fn alternate_boot(self) -> &'a mut W {
         self.variant(BOOT_MOD_A::ALTERNATE_BOOT)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 24)) | ((value as u32 & 3) << 24);
-        self.w
-    }
 }
 #[doc = "Change Clock\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -333,13 +176,9 @@ impl From<PRG_CLK_A> for bool {
     }
 }
 #[doc = "Field `PRG_CLK` reader - Change Clock"]
-pub struct PRG_CLK_R(crate::FieldReader<bool>);
+pub type PRG_CLK_R = crate::BitReader<PRG_CLK_A>;
 impl PRG_CLK_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PRG_CLK_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PRG_CLK_A {
         match self.bits {
@@ -350,31 +189,17 @@ impl PRG_CLK_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == PRG_CLK_A::NORMAL
+        *self == PRG_CLK_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `CHANGE`"]
     #[inline(always)]
     pub fn is_change(&self) -> bool {
-        **self == PRG_CLK_A::CHANGE
-    }
-}
-impl core::ops::Deref for PRG_CLK_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PRG_CLK_A::CHANGE
     }
 }
 #[doc = "Field `PRG_CLK` writer - Change Clock"]
-pub struct PRG_CLK_W<'a> {
-    w: &'a mut W,
-}
+pub type PRG_CLK_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, PRG_CLK_A, 21>;
 impl<'a> PRG_CLK_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PRG_CLK_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Normal command"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -385,22 +210,6 @@ impl<'a> PRG_CLK_W<'a> {
     pub fn change(self) -> &'a mut W {
         self.variant(PRG_CLK_A::CHANGE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
-        self.w
-    }
 }
 #[doc = "Send Initialization\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -417,13 +226,9 @@ impl From<SEND_INIT_SEQ_A> for bool {
     }
 }
 #[doc = "Field `SEND_INIT_SEQ` reader - Send Initialization"]
-pub struct SEND_INIT_SEQ_R(crate::FieldReader<bool>);
+pub type SEND_INIT_SEQ_R = crate::BitReader<SEND_INIT_SEQ_A>;
 impl SEND_INIT_SEQ_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SEND_INIT_SEQ_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SEND_INIT_SEQ_A {
         match self.bits {
@@ -434,31 +239,17 @@ impl SEND_INIT_SEQ_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == SEND_INIT_SEQ_A::NORMAL
+        *self == SEND_INIT_SEQ_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `INIT_CMD`"]
     #[inline(always)]
     pub fn is_init_cmd(&self) -> bool {
-        **self == SEND_INIT_SEQ_A::INIT_CMD
-    }
-}
-impl core::ops::Deref for SEND_INIT_SEQ_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SEND_INIT_SEQ_A::INIT_CMD
     }
 }
 #[doc = "Field `SEND_INIT_SEQ` writer - Send Initialization"]
-pub struct SEND_INIT_SEQ_W<'a> {
-    w: &'a mut W,
-}
+pub type SEND_INIT_SEQ_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, SEND_INIT_SEQ_A, 15>;
 impl<'a> SEND_INIT_SEQ_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SEND_INIT_SEQ_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Normal command sending"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -469,22 +260,6 @@ impl<'a> SEND_INIT_SEQ_W<'a> {
     pub fn init_cmd(self) -> &'a mut W {
         self.variant(SEND_INIT_SEQ_A::INIT_CMD)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
-        self.w
-    }
 }
 #[doc = "Stop Abort Command\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -501,13 +276,9 @@ impl From<STOP_ABT_CMD_A> for bool {
     }
 }
 #[doc = "Field `STOP_ABT_CMD` reader - Stop Abort Command"]
-pub struct STOP_ABT_CMD_R(crate::FieldReader<bool>);
+pub type STOP_ABT_CMD_R = crate::BitReader<STOP_ABT_CMD_A>;
 impl STOP_ABT_CMD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        STOP_ABT_CMD_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> STOP_ABT_CMD_A {
         match self.bits {
@@ -518,31 +289,17 @@ impl STOP_ABT_CMD_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == STOP_ABT_CMD_A::NORMAL
+        *self == STOP_ABT_CMD_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `STOP`"]
     #[inline(always)]
     pub fn is_stop(&self) -> bool {
-        **self == STOP_ABT_CMD_A::STOP
-    }
-}
-impl core::ops::Deref for STOP_ABT_CMD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == STOP_ABT_CMD_A::STOP
     }
 }
 #[doc = "Field `STOP_ABT_CMD` writer - Stop Abort Command"]
-pub struct STOP_ABT_CMD_W<'a> {
-    w: &'a mut W,
-}
+pub type STOP_ABT_CMD_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, STOP_ABT_CMD_A, 14>;
 impl<'a> STOP_ABT_CMD_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: STOP_ABT_CMD_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Normal command sending"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -553,22 +310,6 @@ impl<'a> STOP_ABT_CMD_W<'a> {
     pub fn stop(self) -> &'a mut W {
         self.variant(STOP_ABT_CMD_A::STOP)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 14)) | ((value as u32 & 1) << 14);
-        self.w
-    }
 }
 #[doc = "Wait for Data Transfer Over\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -585,13 +326,9 @@ impl From<WAIT_PRE_OVER_A> for bool {
     }
 }
 #[doc = "Field `WAIT_PRE_OVER` reader - Wait for Data Transfer Over"]
-pub struct WAIT_PRE_OVER_R(crate::FieldReader<bool>);
+pub type WAIT_PRE_OVER_R = crate::BitReader<WAIT_PRE_OVER_A>;
 impl WAIT_PRE_OVER_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        WAIT_PRE_OVER_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> WAIT_PRE_OVER_A {
         match self.bits {
@@ -602,31 +339,17 @@ impl WAIT_PRE_OVER_R {
     #[doc = "Checks if the value of the field is `AT_ONCE`"]
     #[inline(always)]
     pub fn is_at_once(&self) -> bool {
-        **self == WAIT_PRE_OVER_A::AT_ONCE
+        *self == WAIT_PRE_OVER_A::AT_ONCE
     }
     #[doc = "Checks if the value of the field is `WAIT`"]
     #[inline(always)]
     pub fn is_wait(&self) -> bool {
-        **self == WAIT_PRE_OVER_A::WAIT
-    }
-}
-impl core::ops::Deref for WAIT_PRE_OVER_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == WAIT_PRE_OVER_A::WAIT
     }
 }
 #[doc = "Field `WAIT_PRE_OVER` writer - Wait for Data Transfer Over"]
-pub struct WAIT_PRE_OVER_W<'a> {
-    w: &'a mut W,
-}
+pub type WAIT_PRE_OVER_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, WAIT_PRE_OVER_A, 13>;
 impl<'a> WAIT_PRE_OVER_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: WAIT_PRE_OVER_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Send command at once, does not care about data transferring"]
     #[inline(always)]
     pub fn at_once(self) -> &'a mut W {
@@ -637,22 +360,6 @@ impl<'a> WAIT_PRE_OVER_W<'a> {
     pub fn wait(self) -> &'a mut W {
         self.variant(WAIT_PRE_OVER_A::WAIT)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
-        self.w
-    }
 }
 #[doc = "Send Stop CMD Automatically (CMD12)\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -669,13 +376,9 @@ impl From<STOP_CMD_FLAG_A> for bool {
     }
 }
 #[doc = "Field `STOP_CMD_FLAG` reader - Send Stop CMD Automatically (CMD12)"]
-pub struct STOP_CMD_FLAG_R(crate::FieldReader<bool>);
+pub type STOP_CMD_FLAG_R = crate::BitReader<STOP_CMD_FLAG_A>;
 impl STOP_CMD_FLAG_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        STOP_CMD_FLAG_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> STOP_CMD_FLAG_A {
         match self.bits {
@@ -686,31 +389,17 @@ impl STOP_CMD_FLAG_R {
     #[doc = "Checks if the value of the field is `NO_STOP`"]
     #[inline(always)]
     pub fn is_no_stop(&self) -> bool {
-        **self == STOP_CMD_FLAG_A::NO_STOP
+        *self == STOP_CMD_FLAG_A::NO_STOP
     }
     #[doc = "Checks if the value of the field is `AUTO_STOP`"]
     #[inline(always)]
     pub fn is_auto_stop(&self) -> bool {
-        **self == STOP_CMD_FLAG_A::AUTO_STOP
-    }
-}
-impl core::ops::Deref for STOP_CMD_FLAG_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == STOP_CMD_FLAG_A::AUTO_STOP
     }
 }
 #[doc = "Field `STOP_CMD_FLAG` writer - Send Stop CMD Automatically (CMD12)"]
-pub struct STOP_CMD_FLAG_W<'a> {
-    w: &'a mut W,
-}
+pub type STOP_CMD_FLAG_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, STOP_CMD_FLAG_A, 12>;
 impl<'a> STOP_CMD_FLAG_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: STOP_CMD_FLAG_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Do not send stop command at the end of the data transfer"]
     #[inline(always)]
     pub fn no_stop(self) -> &'a mut W {
@@ -721,22 +410,6 @@ impl<'a> STOP_CMD_FLAG_W<'a> {
     pub fn auto_stop(self) -> &'a mut W {
         self.variant(STOP_CMD_FLAG_A::AUTO_STOP)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 12)) | ((value as u32 & 1) << 12);
-        self.w
-    }
 }
 #[doc = "Transfer Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -753,13 +426,9 @@ impl From<TRANS_MODE_A> for bool {
     }
 }
 #[doc = "Field `TRANS_MODE` reader - Transfer Mode"]
-pub struct TRANS_MODE_R(crate::FieldReader<bool>);
+pub type TRANS_MODE_R = crate::BitReader<TRANS_MODE_A>;
 impl TRANS_MODE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TRANS_MODE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TRANS_MODE_A {
         match self.bits {
@@ -770,31 +439,17 @@ impl TRANS_MODE_R {
     #[doc = "Checks if the value of the field is `BLOCK`"]
     #[inline(always)]
     pub fn is_block(&self) -> bool {
-        **self == TRANS_MODE_A::BLOCK
+        *self == TRANS_MODE_A::BLOCK
     }
     #[doc = "Checks if the value of the field is `STREAM`"]
     #[inline(always)]
     pub fn is_stream(&self) -> bool {
-        **self == TRANS_MODE_A::STREAM
-    }
-}
-impl core::ops::Deref for TRANS_MODE_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TRANS_MODE_A::STREAM
     }
 }
 #[doc = "Field `TRANS_MODE` writer - Transfer Mode"]
-pub struct TRANS_MODE_W<'a> {
-    w: &'a mut W,
-}
+pub type TRANS_MODE_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, TRANS_MODE_A, 11>;
 impl<'a> TRANS_MODE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TRANS_MODE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Block data transfer command"]
     #[inline(always)]
     pub fn block(self) -> &'a mut W {
@@ -805,22 +460,6 @@ impl<'a> TRANS_MODE_W<'a> {
     pub fn stream(self) -> &'a mut W {
         self.variant(TRANS_MODE_A::STREAM)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 11)) | ((value as u32 & 1) << 11);
-        self.w
-    }
 }
 #[doc = "Transfer Direction\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -837,13 +476,9 @@ impl From<TRANS_DIR_A> for bool {
     }
 }
 #[doc = "Field `TRANS_DIR` reader - Transfer Direction"]
-pub struct TRANS_DIR_R(crate::FieldReader<bool>);
+pub type TRANS_DIR_R = crate::BitReader<TRANS_DIR_A>;
 impl TRANS_DIR_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TRANS_DIR_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TRANS_DIR_A {
         match self.bits {
@@ -854,31 +489,17 @@ impl TRANS_DIR_R {
     #[doc = "Checks if the value of the field is `READ`"]
     #[inline(always)]
     pub fn is_read(&self) -> bool {
-        **self == TRANS_DIR_A::READ
+        *self == TRANS_DIR_A::READ
     }
     #[doc = "Checks if the value of the field is `WRITE`"]
     #[inline(always)]
     pub fn is_write(&self) -> bool {
-        **self == TRANS_DIR_A::WRITE
-    }
-}
-impl core::ops::Deref for TRANS_DIR_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TRANS_DIR_A::WRITE
     }
 }
 #[doc = "Field `TRANS_DIR` writer - Transfer Direction"]
-pub struct TRANS_DIR_W<'a> {
-    w: &'a mut W,
-}
+pub type TRANS_DIR_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, TRANS_DIR_A, 10>;
 impl<'a> TRANS_DIR_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TRANS_DIR_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Read operation"]
     #[inline(always)]
     pub fn read(self) -> &'a mut W {
@@ -889,22 +510,6 @@ impl<'a> TRANS_DIR_W<'a> {
     pub fn write(self) -> &'a mut W {
         self.variant(TRANS_DIR_A::WRITE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 10)) | ((value as u32 & 1) << 10);
-        self.w
-    }
 }
 #[doc = "Data Transfer\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -921,13 +526,9 @@ impl From<DATA_TRANS_A> for bool {
     }
 }
 #[doc = "Field `DATA_TRANS` reader - Data Transfer"]
-pub struct DATA_TRANS_R(crate::FieldReader<bool>);
+pub type DATA_TRANS_R = crate::BitReader<DATA_TRANS_A>;
 impl DATA_TRANS_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DATA_TRANS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DATA_TRANS_A {
         match self.bits {
@@ -938,31 +539,17 @@ impl DATA_TRANS_R {
     #[doc = "Checks if the value of the field is `WITHOUT`"]
     #[inline(always)]
     pub fn is_without(&self) -> bool {
-        **self == DATA_TRANS_A::WITHOUT
+        *self == DATA_TRANS_A::WITHOUT
     }
     #[doc = "Checks if the value of the field is `WITH`"]
     #[inline(always)]
     pub fn is_with(&self) -> bool {
-        **self == DATA_TRANS_A::WITH
-    }
-}
-impl core::ops::Deref for DATA_TRANS_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DATA_TRANS_A::WITH
     }
 }
 #[doc = "Field `DATA_TRANS` writer - Data Transfer"]
-pub struct DATA_TRANS_W<'a> {
-    w: &'a mut W,
-}
+pub type DATA_TRANS_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, DATA_TRANS_A, 9>;
 impl<'a> DATA_TRANS_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DATA_TRANS_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Without data transfer"]
     #[inline(always)]
     pub fn without(self) -> &'a mut W {
@@ -973,22 +560,6 @@ impl<'a> DATA_TRANS_W<'a> {
     pub fn with(self) -> &'a mut W {
         self.variant(DATA_TRANS_A::WITH)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 9)) | ((value as u32 & 1) << 9);
-        self.w
-    }
 }
 #[doc = "Check Response CRC\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -1005,13 +576,9 @@ impl From<CHK_RESP_CRC_A> for bool {
     }
 }
 #[doc = "Field `CHK_RESP_CRC` reader - Check Response CRC"]
-pub struct CHK_RESP_CRC_R(crate::FieldReader<bool>);
+pub type CHK_RESP_CRC_R = crate::BitReader<CHK_RESP_CRC_A>;
 impl CHK_RESP_CRC_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        CHK_RESP_CRC_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CHK_RESP_CRC_A {
         match self.bits {
@@ -1022,31 +589,17 @@ impl CHK_RESP_CRC_R {
     #[doc = "Checks if the value of the field is `NOT_CHECK`"]
     #[inline(always)]
     pub fn is_not_check(&self) -> bool {
-        **self == CHK_RESP_CRC_A::NOT_CHECK
+        *self == CHK_RESP_CRC_A::NOT_CHECK
     }
     #[doc = "Checks if the value of the field is `CHECK`"]
     #[inline(always)]
     pub fn is_check(&self) -> bool {
-        **self == CHK_RESP_CRC_A::CHECK
-    }
-}
-impl core::ops::Deref for CHK_RESP_CRC_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CHK_RESP_CRC_A::CHECK
     }
 }
 #[doc = "Field `CHK_RESP_CRC` writer - Check Response CRC"]
-pub struct CHK_RESP_CRC_W<'a> {
-    w: &'a mut W,
-}
+pub type CHK_RESP_CRC_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, CHK_RESP_CRC_A, 8>;
 impl<'a> CHK_RESP_CRC_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CHK_RESP_CRC_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Do not check response CRC"]
     #[inline(always)]
     pub fn not_check(self) -> &'a mut W {
@@ -1057,22 +610,6 @@ impl<'a> CHK_RESP_CRC_W<'a> {
     pub fn check(self) -> &'a mut W {
         self.variant(CHK_RESP_CRC_A::CHECK)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
-        self.w
-    }
 }
 #[doc = "Response Type\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -1089,13 +626,9 @@ impl From<LONG_RESP_A> for bool {
     }
 }
 #[doc = "Field `LONG_RESP` reader - Response Type"]
-pub struct LONG_RESP_R(crate::FieldReader<bool>);
+pub type LONG_RESP_R = crate::BitReader<LONG_RESP_A>;
 impl LONG_RESP_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        LONG_RESP_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LONG_RESP_A {
         match self.bits {
@@ -1106,31 +639,17 @@ impl LONG_RESP_R {
     #[doc = "Checks if the value of the field is `SHORT`"]
     #[inline(always)]
     pub fn is_short(&self) -> bool {
-        **self == LONG_RESP_A::SHORT
+        *self == LONG_RESP_A::SHORT
     }
     #[doc = "Checks if the value of the field is `LONG`"]
     #[inline(always)]
     pub fn is_long(&self) -> bool {
-        **self == LONG_RESP_A::LONG
-    }
-}
-impl core::ops::Deref for LONG_RESP_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == LONG_RESP_A::LONG
     }
 }
 #[doc = "Field `LONG_RESP` writer - Response Type"]
-pub struct LONG_RESP_W<'a> {
-    w: &'a mut W,
-}
+pub type LONG_RESP_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, LONG_RESP_A, 7>;
 impl<'a> LONG_RESP_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LONG_RESP_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Short Response (48 bits)"]
     #[inline(always)]
     pub fn short(self) -> &'a mut W {
@@ -1141,22 +660,6 @@ impl<'a> LONG_RESP_W<'a> {
     pub fn long(self) -> &'a mut W {
         self.variant(LONG_RESP_A::LONG)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 7)) | ((value as u32 & 1) << 7);
-        self.w
-    }
 }
 #[doc = "Response Receive\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -1173,13 +676,9 @@ impl From<RESP_RCV_A> for bool {
     }
 }
 #[doc = "Field `RESP_RCV` reader - Response Receive"]
-pub struct RESP_RCV_R(crate::FieldReader<bool>);
+pub type RESP_RCV_R = crate::BitReader<RESP_RCV_A>;
 impl RESP_RCV_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RESP_RCV_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RESP_RCV_A {
         match self.bits {
@@ -1190,31 +689,17 @@ impl RESP_RCV_R {
     #[doc = "Checks if the value of the field is `WITHOUT`"]
     #[inline(always)]
     pub fn is_without(&self) -> bool {
-        **self == RESP_RCV_A::WITHOUT
+        *self == RESP_RCV_A::WITHOUT
     }
     #[doc = "Checks if the value of the field is `WITH`"]
     #[inline(always)]
     pub fn is_with(&self) -> bool {
-        **self == RESP_RCV_A::WITH
-    }
-}
-impl core::ops::Deref for RESP_RCV_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RESP_RCV_A::WITH
     }
 }
 #[doc = "Field `RESP_RCV` writer - Response Receive"]
-pub struct RESP_RCV_W<'a> {
-    w: &'a mut W,
-}
+pub type RESP_RCV_W<'a> = crate::BitWriter<'a, u32, SMHC_CMD_SPEC, RESP_RCV_A, 6>;
 impl<'a> RESP_RCV_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RESP_RCV_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "Command without response"]
     #[inline(always)]
     pub fn without(self) -> &'a mut W {
@@ -1225,50 +710,11 @@ impl<'a> RESP_RCV_W<'a> {
     pub fn with(self) -> &'a mut W {
         self.variant(RESP_RCV_A::WITH)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 6)) | ((value as u32 & 1) << 6);
-        self.w
-    }
 }
 #[doc = "Field `CMD_IDX` reader - CMD Index"]
-pub struct CMD_IDX_R(crate::FieldReader<u8>);
-impl CMD_IDX_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        CMD_IDX_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for CMD_IDX_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type CMD_IDX_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `CMD_IDX` writer - CMD Index"]
-pub struct CMD_IDX_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> CMD_IDX_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x3f) | (value as u32 & 0x3f);
-        self.w
-    }
-}
+pub type CMD_IDX_W<'a> = crate::FieldWriter<'a, u32, SMHC_CMD_SPEC, u8, u8, 6, 0>;
 impl R {
     #[doc = "Bit 31 - Start Command"]
     #[inline(always)]
@@ -1360,87 +806,87 @@ impl W {
     #[doc = "Bit 31 - Start Command"]
     #[inline(always)]
     pub fn cmd_load(&mut self) -> CMD_LOAD_W {
-        CMD_LOAD_W { w: self }
+        CMD_LOAD_W::new(self)
     }
     #[doc = "Bit 28 - Voltage Switch"]
     #[inline(always)]
     pub fn vol_sw(&mut self) -> VOL_SW_W {
-        VOL_SW_W { w: self }
+        VOL_SW_W::new(self)
     }
     #[doc = "Bit 27 - Boot Abort"]
     #[inline(always)]
     pub fn boot_abt(&mut self) -> BOOT_ABT_W {
-        BOOT_ABT_W { w: self }
+        BOOT_ABT_W::new(self)
     }
     #[doc = "Bit 26 - Expect Boot Acknowledge"]
     #[inline(always)]
     pub fn exp_boot_ack(&mut self) -> EXP_BOOT_ACK_W {
-        EXP_BOOT_ACK_W { w: self }
+        EXP_BOOT_ACK_W::new(self)
     }
     #[doc = "Bits 24:25 - Boot Mode"]
     #[inline(always)]
     pub fn boot_mod(&mut self) -> BOOT_MOD_W {
-        BOOT_MOD_W { w: self }
+        BOOT_MOD_W::new(self)
     }
     #[doc = "Bit 21 - Change Clock"]
     #[inline(always)]
     pub fn prg_clk(&mut self) -> PRG_CLK_W {
-        PRG_CLK_W { w: self }
+        PRG_CLK_W::new(self)
     }
     #[doc = "Bit 15 - Send Initialization"]
     #[inline(always)]
     pub fn send_init_seq(&mut self) -> SEND_INIT_SEQ_W {
-        SEND_INIT_SEQ_W { w: self }
+        SEND_INIT_SEQ_W::new(self)
     }
     #[doc = "Bit 14 - Stop Abort Command"]
     #[inline(always)]
     pub fn stop_abt_cmd(&mut self) -> STOP_ABT_CMD_W {
-        STOP_ABT_CMD_W { w: self }
+        STOP_ABT_CMD_W::new(self)
     }
     #[doc = "Bit 13 - Wait for Data Transfer Over"]
     #[inline(always)]
     pub fn wait_pre_over(&mut self) -> WAIT_PRE_OVER_W {
-        WAIT_PRE_OVER_W { w: self }
+        WAIT_PRE_OVER_W::new(self)
     }
     #[doc = "Bit 12 - Send Stop CMD Automatically (CMD12)"]
     #[inline(always)]
     pub fn stop_cmd_flag(&mut self) -> STOP_CMD_FLAG_W {
-        STOP_CMD_FLAG_W { w: self }
+        STOP_CMD_FLAG_W::new(self)
     }
     #[doc = "Bit 11 - Transfer Mode"]
     #[inline(always)]
     pub fn trans_mode(&mut self) -> TRANS_MODE_W {
-        TRANS_MODE_W { w: self }
+        TRANS_MODE_W::new(self)
     }
     #[doc = "Bit 10 - Transfer Direction"]
     #[inline(always)]
     pub fn trans_dir(&mut self) -> TRANS_DIR_W {
-        TRANS_DIR_W { w: self }
+        TRANS_DIR_W::new(self)
     }
     #[doc = "Bit 9 - Data Transfer"]
     #[inline(always)]
     pub fn data_trans(&mut self) -> DATA_TRANS_W {
-        DATA_TRANS_W { w: self }
+        DATA_TRANS_W::new(self)
     }
     #[doc = "Bit 8 - Check Response CRC"]
     #[inline(always)]
     pub fn chk_resp_crc(&mut self) -> CHK_RESP_CRC_W {
-        CHK_RESP_CRC_W { w: self }
+        CHK_RESP_CRC_W::new(self)
     }
     #[doc = "Bit 7 - Response Type"]
     #[inline(always)]
     pub fn long_resp(&mut self) -> LONG_RESP_W {
-        LONG_RESP_W { w: self }
+        LONG_RESP_W::new(self)
     }
     #[doc = "Bit 6 - Response Receive"]
     #[inline(always)]
     pub fn resp_rcv(&mut self) -> RESP_RCV_W {
-        RESP_RCV_W { w: self }
+        RESP_RCV_W::new(self)
     }
     #[doc = "Bits 0:5 - CMD Index"]
     #[inline(always)]
     pub fn cmd_idx(&mut self) -> CMD_IDX_W {
-        CMD_IDX_W { w: self }
+        CMD_IDX_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
