@@ -35,42 +35,9 @@ impl From<crate::W<DBI_CTL_1_SPEC>> for W {
     }
 }
 #[doc = "Field `dbi_soft_trg` reader - DBI Soft Trigger"]
-pub struct DBI_SOFT_TRG_R(crate::FieldReader<bool>);
-impl DBI_SOFT_TRG_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DBI_SOFT_TRG_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DBI_SOFT_TRG_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DBI_SOFT_TRG_R = crate::BitReader<bool>;
 #[doc = "Field `dbi_soft_trg` writer - DBI Soft Trigger"]
-pub struct DBI_SOFT_TRG_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DBI_SOFT_TRG_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 31)) | ((value as u32 & 1) << 31);
-        self.w
-    }
-}
+pub type DBI_SOFT_TRG_W<'a> = crate::BitWriter<'a, u32, DBI_CTL_1_SPEC, bool, 31>;
 #[doc = "DBI Enable Mode Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 #[repr(u8)]
@@ -91,13 +58,9 @@ impl From<DBI_EN_MODE_SEL_A> for u8 {
     }
 }
 #[doc = "Field `dbi_en_mode_sel` reader - DBI Enable Mode Select"]
-pub struct DBI_EN_MODE_SEL_R(crate::FieldReader<u8>);
+pub type DBI_EN_MODE_SEL_R = crate::FieldReader<u8, DBI_EN_MODE_SEL_A>;
 impl DBI_EN_MODE_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        DBI_EN_MODE_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DBI_EN_MODE_SEL_A {
         match self.bits {
@@ -111,41 +74,28 @@ impl DBI_EN_MODE_SEL_R {
     #[doc = "Checks if the value of the field is `DBI`"]
     #[inline(always)]
     pub fn is_dbi(&self) -> bool {
-        **self == DBI_EN_MODE_SEL_A::DBI
+        *self == DBI_EN_MODE_SEL_A::DBI
     }
     #[doc = "Checks if the value of the field is `SOFTWARE`"]
     #[inline(always)]
     pub fn is_software(&self) -> bool {
-        **self == DBI_EN_MODE_SEL_A::SOFTWARE
+        *self == DBI_EN_MODE_SEL_A::SOFTWARE
     }
     #[doc = "Checks if the value of the field is `TIMER`"]
     #[inline(always)]
     pub fn is_timer(&self) -> bool {
-        **self == DBI_EN_MODE_SEL_A::TIMER
+        *self == DBI_EN_MODE_SEL_A::TIMER
     }
     #[doc = "Checks if the value of the field is `TE`"]
     #[inline(always)]
     pub fn is_te(&self) -> bool {
-        **self == DBI_EN_MODE_SEL_A::TE
-    }
-}
-impl core::ops::Deref for DBI_EN_MODE_SEL_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DBI_EN_MODE_SEL_A::TE
     }
 }
 #[doc = "Field `dbi_en_mode_sel` writer - DBI Enable Mode Select"]
-pub struct DBI_EN_MODE_SEL_W<'a> {
-    w: &'a mut W,
-}
+pub type DBI_EN_MODE_SEL_W<'a> =
+    crate::FieldWriterSafe<'a, u32, DBI_CTL_1_SPEC, u8, DBI_EN_MODE_SEL_A, 2, 29>;
 impl<'a> DBI_EN_MODE_SEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DBI_EN_MODE_SEL_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn dbi(self) -> &'a mut W {
@@ -166,12 +116,6 @@ impl<'a> DBI_EN_MODE_SEL_W<'a> {
     pub fn te(self) -> &'a mut W {
         self.variant(DBI_EN_MODE_SEL_A::TE)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 29)) | ((value as u32 & 3) << 29);
-        self.w
-    }
 }
 #[doc = "2 Data Lane RGB666 Format\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -191,13 +135,9 @@ impl From<RGB666_FMT_A> for u8 {
     }
 }
 #[doc = "Field `RGB666_FMT` reader - 2 Data Lane RGB666 Format"]
-pub struct RGB666_FMT_R(crate::FieldReader<u8>);
+pub type RGB666_FMT_R = crate::FieldReader<u8, RGB666_FMT_A>;
 impl RGB666_FMT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        RGB666_FMT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<RGB666_FMT_A> {
         match self.bits {
@@ -210,36 +150,22 @@ impl RGB666_FMT_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == RGB666_FMT_A::NORMAL
+        *self == RGB666_FMT_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `SPECIAL_ILITEK`"]
     #[inline(always)]
     pub fn is_special_ilitek(&self) -> bool {
-        **self == RGB666_FMT_A::SPECIAL_ILITEK
+        *self == RGB666_FMT_A::SPECIAL_ILITEK
     }
     #[doc = "Checks if the value of the field is `SPECIAL_NEW_VISION`"]
     #[inline(always)]
     pub fn is_special_new_vision(&self) -> bool {
-        **self == RGB666_FMT_A::SPECIAL_NEW_VISION
-    }
-}
-impl core::ops::Deref for RGB666_FMT_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RGB666_FMT_A::SPECIAL_NEW_VISION
     }
 }
 #[doc = "Field `RGB666_FMT` writer - 2 Data Lane RGB666 Format"]
-pub struct RGB666_FMT_W<'a> {
-    w: &'a mut W,
-}
+pub type RGB666_FMT_W<'a> = crate::FieldWriter<'a, u32, DBI_CTL_1_SPEC, u8, RGB666_FMT_A, 2, 26>;
 impl<'a> RGB666_FMT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RGB666_FMT_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -255,12 +181,6 @@ impl<'a> RGB666_FMT_W<'a> {
     pub fn special_new_vision(self) -> &'a mut W {
         self.variant(RGB666_FMT_A::SPECIAL_NEW_VISION)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 26)) | ((value as u32 & 3) << 26);
-        self.w
-    }
 }
 #[doc = "DBI RX Clock Inverse\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -277,13 +197,9 @@ impl From<DBI_RXCLK_INV_A> for bool {
     }
 }
 #[doc = "Field `dbi_rxclk_inv` reader - DBI RX Clock Inverse"]
-pub struct DBI_RXCLK_INV_R(crate::FieldReader<bool>);
+pub type DBI_RXCLK_INV_R = crate::BitReader<DBI_RXCLK_INV_A>;
 impl DBI_RXCLK_INV_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DBI_RXCLK_INV_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DBI_RXCLK_INV_A {
         match self.bits {
@@ -294,31 +210,17 @@ impl DBI_RXCLK_INV_R {
     #[doc = "Checks if the value of the field is `POSITIVE`"]
     #[inline(always)]
     pub fn is_positive(&self) -> bool {
-        **self == DBI_RXCLK_INV_A::POSITIVE
+        *self == DBI_RXCLK_INV_A::POSITIVE
     }
     #[doc = "Checks if the value of the field is `NEGATIVE`"]
     #[inline(always)]
     pub fn is_negative(&self) -> bool {
-        **self == DBI_RXCLK_INV_A::NEGATIVE
-    }
-}
-impl core::ops::Deref for DBI_RXCLK_INV_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DBI_RXCLK_INV_A::NEGATIVE
     }
 }
 #[doc = "Field `dbi_rxclk_inv` writer - DBI RX Clock Inverse"]
-pub struct DBI_RXCLK_INV_W<'a> {
-    w: &'a mut W,
-}
+pub type DBI_RXCLK_INV_W<'a> = crate::BitWriter<'a, u32, DBI_CTL_1_SPEC, DBI_RXCLK_INV_A, 25>;
 impl<'a> DBI_RXCLK_INV_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DBI_RXCLK_INV_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn positive(self) -> &'a mut W {
@@ -329,22 +231,6 @@ impl<'a> DBI_RXCLK_INV_W<'a> {
     pub fn negative(self) -> &'a mut W {
         self.variant(DBI_RXCLK_INV_A::NEGATIVE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 25)) | ((value as u32 & 1) << 25);
-        self.w
-    }
 }
 #[doc = "DBI Output Clock Mode\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -361,13 +247,9 @@ impl From<DBI_CLKO_MOD_A> for bool {
     }
 }
 #[doc = "Field `dbi_clko_mod` reader - DBI Output Clock Mode"]
-pub struct DBI_CLKO_MOD_R(crate::FieldReader<bool>);
+pub type DBI_CLKO_MOD_R = crate::BitReader<DBI_CLKO_MOD_A>;
 impl DBI_CLKO_MOD_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DBI_CLKO_MOD_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> DBI_CLKO_MOD_A {
         match self.bits {
@@ -378,31 +260,17 @@ impl DBI_CLKO_MOD_R {
     #[doc = "Checks if the value of the field is `ALWAYS_ON`"]
     #[inline(always)]
     pub fn is_always_on(&self) -> bool {
-        **self == DBI_CLKO_MOD_A::ALWAYS_ON
+        *self == DBI_CLKO_MOD_A::ALWAYS_ON
     }
     #[doc = "Checks if the value of the field is `AUTO_GATING`"]
     #[inline(always)]
     pub fn is_auto_gating(&self) -> bool {
-        **self == DBI_CLKO_MOD_A::AUTO_GATING
-    }
-}
-impl core::ops::Deref for DBI_CLKO_MOD_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == DBI_CLKO_MOD_A::AUTO_GATING
     }
 }
 #[doc = "Field `dbi_clko_mod` writer - DBI Output Clock Mode"]
-pub struct DBI_CLKO_MOD_W<'a> {
-    w: &'a mut W,
-}
+pub type DBI_CLKO_MOD_W<'a> = crate::BitWriter<'a, u32, DBI_CTL_1_SPEC, DBI_CLKO_MOD_A, 24>;
 impl<'a> DBI_CLKO_MOD_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: DBI_CLKO_MOD_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn always_on(self) -> &'a mut W {
@@ -413,225 +281,31 @@ impl<'a> DBI_CLKO_MOD_W<'a> {
     pub fn auto_gating(self) -> &'a mut W {
         self.variant(DBI_CLKO_MOD_A::AUTO_GATING)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 24)) | ((value as u32 & 1) << 24);
-        self.w
-    }
 }
 #[doc = "Field `dbi_clko_inv` reader - DBI Clock Output Inverse"]
-pub struct DBI_CLKO_INV_R(crate::FieldReader<bool>);
-impl DBI_CLKO_INV_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DBI_CLKO_INV_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DBI_CLKO_INV_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DBI_CLKO_INV_R = crate::BitReader<bool>;
 #[doc = "Field `dbi_clko_inv` writer - DBI Clock Output Inverse"]
-pub struct DBI_CLKO_INV_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DBI_CLKO_INV_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
-        self.w
-    }
-}
+pub type DBI_CLKO_INV_W<'a> = crate::BitWriter<'a, u32, DBI_CTL_1_SPEC, bool, 23>;
 #[doc = "Field `dcx_data` reader - DCX Data Value"]
-pub struct DCX_DATA_R(crate::FieldReader<bool>);
-impl DCX_DATA_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        DCX_DATA_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DCX_DATA_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DCX_DATA_R = crate::BitReader<bool>;
 #[doc = "Field `dcx_data` writer - DCX Data Value"]
-pub struct DCX_DATA_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> DCX_DATA_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 22)) | ((value as u32 & 1) << 22);
-        self.w
-    }
-}
+pub type DCX_DATA_W<'a> = crate::BitWriter<'a, u32, DBI_CTL_1_SPEC, bool, 22>;
 #[doc = "Field `RGB16_data_source_select` reader - RGB 16 Data Source Select"]
-pub struct RGB16_DATA_SOURCE_SELECT_R(crate::FieldReader<bool>);
-impl RGB16_DATA_SOURCE_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RGB16_DATA_SOURCE_SELECT_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RGB16_DATA_SOURCE_SELECT_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RGB16_DATA_SOURCE_SELECT_R = crate::BitReader<bool>;
 #[doc = "Field `RGB16_data_source_select` writer - RGB 16 Data Source Select"]
-pub struct RGB16_DATA_SOURCE_SELECT_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RGB16_DATA_SOURCE_SELECT_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 21)) | ((value as u32 & 1) << 21);
-        self.w
-    }
-}
+pub type RGB16_DATA_SOURCE_SELECT_W<'a> = crate::BitWriter<'a, u32, DBI_CTL_1_SPEC, bool, 21>;
 #[doc = "Field `rdat_lsb` reader - Bit Order of Read Data"]
-pub struct RDAT_LSB_R(crate::FieldReader<bool>);
-impl RDAT_LSB_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RDAT_LSB_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RDAT_LSB_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RDAT_LSB_R = crate::BitReader<bool>;
 #[doc = "Field `rdat_lsb` writer - Bit Order of Read Data"]
-pub struct RDAT_LSB_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RDAT_LSB_W<'a> {
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 20)) | ((value as u32 & 1) << 20);
-        self.w
-    }
-}
+pub type RDAT_LSB_W<'a> = crate::BitWriter<'a, u32, DBI_CTL_1_SPEC, bool, 20>;
 #[doc = "Field `rcdc` reader - Read Command Dummy Cycles"]
-pub struct RCDC_R(crate::FieldReader<u8>);
-impl RCDC_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        RCDC_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RCDC_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RCDC_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `rcdc` writer - Read Command Dummy Cycles"]
-pub struct RCDC_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RCDC_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0xff << 8)) | ((value as u32 & 0xff) << 8);
-        self.w
-    }
-}
+pub type RCDC_W<'a> = crate::FieldWriter<'a, u32, DBI_CTL_1_SPEC, u8, u8, 8, 8>;
 #[doc = "Field `rdbn` reader - Read Data Number of Bytes"]
-pub struct RDBN_R(crate::FieldReader<u8>);
-impl RDBN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        RDBN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RDBN_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RDBN_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `rdbn` writer - Read Data Number of Bytes"]
-pub struct RDBN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RDBN_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
-        self.w
-    }
-}
+pub type RDBN_W<'a> = crate::FieldWriter<'a, u32, DBI_CTL_1_SPEC, u8, u8, 8, 0>;
 impl R {
     #[doc = "Bit 31 - DBI Soft Trigger"]
     #[inline(always)]
@@ -693,57 +367,57 @@ impl W {
     #[doc = "Bit 31 - DBI Soft Trigger"]
     #[inline(always)]
     pub fn dbi_soft_trg(&mut self) -> DBI_SOFT_TRG_W {
-        DBI_SOFT_TRG_W { w: self }
+        DBI_SOFT_TRG_W::new(self)
     }
     #[doc = "Bits 29:30 - DBI Enable Mode Select"]
     #[inline(always)]
     pub fn dbi_en_mode_sel(&mut self) -> DBI_EN_MODE_SEL_W {
-        DBI_EN_MODE_SEL_W { w: self }
+        DBI_EN_MODE_SEL_W::new(self)
     }
     #[doc = "Bits 26:27 - 2 Data Lane RGB666 Format"]
     #[inline(always)]
     pub fn rgb666_fmt(&mut self) -> RGB666_FMT_W {
-        RGB666_FMT_W { w: self }
+        RGB666_FMT_W::new(self)
     }
     #[doc = "Bit 25 - DBI RX Clock Inverse"]
     #[inline(always)]
     pub fn dbi_rxclk_inv(&mut self) -> DBI_RXCLK_INV_W {
-        DBI_RXCLK_INV_W { w: self }
+        DBI_RXCLK_INV_W::new(self)
     }
     #[doc = "Bit 24 - DBI Output Clock Mode"]
     #[inline(always)]
     pub fn dbi_clko_mod(&mut self) -> DBI_CLKO_MOD_W {
-        DBI_CLKO_MOD_W { w: self }
+        DBI_CLKO_MOD_W::new(self)
     }
     #[doc = "Bit 23 - DBI Clock Output Inverse"]
     #[inline(always)]
     pub fn dbi_clko_inv(&mut self) -> DBI_CLKO_INV_W {
-        DBI_CLKO_INV_W { w: self }
+        DBI_CLKO_INV_W::new(self)
     }
     #[doc = "Bit 22 - DCX Data Value"]
     #[inline(always)]
     pub fn dcx_data(&mut self) -> DCX_DATA_W {
-        DCX_DATA_W { w: self }
+        DCX_DATA_W::new(self)
     }
     #[doc = "Bit 21 - RGB 16 Data Source Select"]
     #[inline(always)]
     pub fn rgb16_data_source_select(&mut self) -> RGB16_DATA_SOURCE_SELECT_W {
-        RGB16_DATA_SOURCE_SELECT_W { w: self }
+        RGB16_DATA_SOURCE_SELECT_W::new(self)
     }
     #[doc = "Bit 20 - Bit Order of Read Data"]
     #[inline(always)]
     pub fn rdat_lsb(&mut self) -> RDAT_LSB_W {
-        RDAT_LSB_W { w: self }
+        RDAT_LSB_W::new(self)
     }
     #[doc = "Bits 8:15 - Read Command Dummy Cycles"]
     #[inline(always)]
     pub fn rcdc(&mut self) -> RCDC_W {
-        RCDC_W { w: self }
+        RCDC_W::new(self)
     }
     #[doc = "Bits 0:7 - Read Data Number of Bytes"]
     #[inline(always)]
     pub fn rdbn(&mut self) -> RDBN_W {
-        RDBN_W { w: self }
+        RDBN_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
