@@ -49,13 +49,9 @@ impl From<TCE_A> for bool {
     }
 }
 #[doc = "Field `tce` reader - Transfer Control Enable"]
-pub struct TCE_R(crate::FieldReader<bool, TCE_A>);
+pub type TCE_R = crate::BitReader<TCE_A>;
 impl TCE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TCE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TCE_A {
         match self.bits {
@@ -66,31 +62,17 @@ impl TCE_R {
     #[doc = "Checks if the value of the field is `IDLE`"]
     #[inline(always)]
     pub fn is_idle(&self) -> bool {
-        **self == TCE_A::IDLE
+        *self == TCE_A::IDLE
     }
     #[doc = "Checks if the value of the field is `INIT`"]
     #[inline(always)]
     pub fn is_init(&self) -> bool {
-        **self == TCE_A::INIT
-    }
-}
-impl core::ops::Deref for TCE_R {
-    type Target = crate::FieldReader<bool, TCE_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TCE_A::INIT
     }
 }
 #[doc = "Field `tce` writer - Transfer Control Enable"]
-pub struct TCE_W<'a> {
-    w: &'a mut W,
-}
+pub type TCE_W<'a> = crate::BitWriter<'a, u32, SPI_BATC_SPEC, TCE_A, 31>;
 impl<'a> TCE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TCE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn idle(self) -> &'a mut W {
@@ -101,22 +83,6 @@ impl<'a> TCE_W<'a> {
     pub fn init(self) -> &'a mut W {
         self.variant(TCE_A::INIT)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 31)) | ((value as u32 & 0x01) << 31);
-        self.w
-    }
 }
 #[doc = "Master Sample Standard\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -133,13 +99,9 @@ impl From<MSMS_A> for bool {
     }
 }
 #[doc = "Field `msms` reader - Master Sample Standard"]
-pub struct MSMS_R(crate::FieldReader<bool, MSMS_A>);
+pub type MSMS_R = crate::BitReader<MSMS_A>;
 impl MSMS_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        MSMS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> MSMS_A {
         match self.bits {
@@ -150,31 +112,17 @@ impl MSMS_R {
     #[doc = "Checks if the value of the field is `DELAY`"]
     #[inline(always)]
     pub fn is_delay(&self) -> bool {
-        **self == MSMS_A::DELAY
+        *self == MSMS_A::DELAY
     }
     #[doc = "Checks if the value of the field is `STANDARD`"]
     #[inline(always)]
     pub fn is_standard(&self) -> bool {
-        **self == MSMS_A::STANDARD
-    }
-}
-impl core::ops::Deref for MSMS_R {
-    type Target = crate::FieldReader<bool, MSMS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == MSMS_A::STANDARD
     }
 }
 #[doc = "Field `msms` writer - Master Sample Standard"]
-pub struct MSMS_W<'a> {
-    w: &'a mut W,
-}
+pub type MSMS_W<'a> = crate::BitWriter<'a, u32, SPI_BATC_SPEC, MSMS_A, 30>;
 impl<'a> MSMS_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: MSMS_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn delay(self) -> &'a mut W {
@@ -185,22 +133,6 @@ impl<'a> MSMS_W<'a> {
     pub fn standard(self) -> &'a mut W {
         self.variant(MSMS_A::STANDARD)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 30)) | ((value as u32 & 0x01) << 30);
-        self.w
-    }
 }
 #[doc = "Transfer Bits Completed\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -217,13 +149,9 @@ impl From<TBC_A> for bool {
     }
 }
 #[doc = "Field `tbc` reader - Transfer Bits Completed"]
-pub struct TBC_R(crate::FieldReader<bool, TBC_A>);
+pub type TBC_R = crate::BitReader<TBC_A>;
 impl TBC_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TBC_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TBC_A {
         match self.bits {
@@ -234,31 +162,17 @@ impl TBC_R {
     #[doc = "Checks if the value of the field is `BUSY`"]
     #[inline(always)]
     pub fn is_busy(&self) -> bool {
-        **self == TBC_A::BUSY
+        *self == TBC_A::BUSY
     }
     #[doc = "Checks if the value of the field is `COMPLETED`"]
     #[inline(always)]
     pub fn is_completed(&self) -> bool {
-        **self == TBC_A::COMPLETED
-    }
-}
-impl core::ops::Deref for TBC_R {
-    type Target = crate::FieldReader<bool, TBC_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TBC_A::COMPLETED
     }
 }
 #[doc = "Field `tbc` writer - Transfer Bits Completed"]
-pub struct TBC_W<'a> {
-    w: &'a mut W,
-}
+pub type TBC_W<'a> = crate::BitWriter<'a, u32, SPI_BATC_SPEC, TBC_A, 25>;
 impl<'a> TBC_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TBC_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn busy(self) -> &'a mut W {
@@ -269,22 +183,6 @@ impl<'a> TBC_W<'a> {
     pub fn completed(self) -> &'a mut W {
         self.variant(TBC_A::COMPLETED)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 25)) | ((value as u32 & 0x01) << 25);
-        self.w
-    }
 }
 #[doc = "Transfer Bits Completed Interrupt Enable\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -301,13 +199,9 @@ impl From<TBC_INT_EN_A> for bool {
     }
 }
 #[doc = "Field `tbc_int_en` reader - Transfer Bits Completed Interrupt Enable"]
-pub struct TBC_INT_EN_R(crate::FieldReader<bool, TBC_INT_EN_A>);
+pub type TBC_INT_EN_R = crate::BitReader<TBC_INT_EN_A>;
 impl TBC_INT_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        TBC_INT_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TBC_INT_EN_A {
         match self.bits {
@@ -318,31 +212,17 @@ impl TBC_INT_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == TBC_INT_EN_A::DISABLE
+        *self == TBC_INT_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == TBC_INT_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for TBC_INT_EN_R {
-    type Target = crate::FieldReader<bool, TBC_INT_EN_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == TBC_INT_EN_A::ENABLE
     }
 }
 #[doc = "Field `tbc_int_en` writer - Transfer Bits Completed Interrupt Enable"]
-pub struct TBC_INT_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type TBC_INT_EN_W<'a> = crate::BitWriter<'a, u32, SPI_BATC_SPEC, TBC_INT_EN_A, 24>;
 impl<'a> TBC_INT_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: TBC_INT_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -353,77 +233,15 @@ impl<'a> TBC_INT_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(TBC_INT_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 24)) | ((value as u32 & 0x01) << 24);
-        self.w
-    }
 }
 #[doc = "Field `rx_frm_len` reader - Configure the length of serial data frame of RX"]
-pub struct RX_FRM_LEN_R(crate::FieldReader<u8, u8>);
-impl RX_FRM_LEN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        RX_FRM_LEN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RX_FRM_LEN_R {
-    type Target = crate::FieldReader<u8, u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RX_FRM_LEN_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `rx_frm_len` writer - Configure the length of serial data frame of RX"]
-pub struct RX_FRM_LEN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> RX_FRM_LEN_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x3f << 16)) | ((value as u32 & 0x3f) << 16);
-        self.w
-    }
-}
+pub type RX_FRM_LEN_W<'a> = crate::FieldWriter<'a, u32, SPI_BATC_SPEC, u8, u8, 6, 16>;
 #[doc = "Field `tx_frm_len` reader - Configure the length of serial data frame of TX"]
-pub struct TX_FRM_LEN_R(crate::FieldReader<u8, u8>);
-impl TX_FRM_LEN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        TX_FRM_LEN_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TX_FRM_LEN_R {
-    type Target = crate::FieldReader<u8, u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TX_FRM_LEN_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `tx_frm_len` writer - Configure the length of serial data frame of TX"]
-pub struct TX_FRM_LEN_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TX_FRM_LEN_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x3f << 8)) | ((value as u32 & 0x3f) << 8);
-        self.w
-    }
-}
+pub type TX_FRM_LEN_W<'a> = crate::FieldWriter<'a, u32, SPI_BATC_SPEC, u8, u8, 6, 8>;
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum SS_LEVEL_A {
@@ -439,13 +257,9 @@ impl From<SS_LEVEL_A> for bool {
     }
 }
 #[doc = "Field `ss_level` reader - "]
-pub struct SS_LEVEL_R(crate::FieldReader<bool, SS_LEVEL_A>);
+pub type SS_LEVEL_R = crate::BitReader<SS_LEVEL_A>;
 impl SS_LEVEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SS_LEVEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SS_LEVEL_A {
         match self.bits {
@@ -456,31 +270,17 @@ impl SS_LEVEL_R {
     #[doc = "Checks if the value of the field is `LOW`"]
     #[inline(always)]
     pub fn is_low(&self) -> bool {
-        **self == SS_LEVEL_A::LOW
+        *self == SS_LEVEL_A::LOW
     }
     #[doc = "Checks if the value of the field is `HIGH`"]
     #[inline(always)]
     pub fn is_high(&self) -> bool {
-        **self == SS_LEVEL_A::HIGH
-    }
-}
-impl core::ops::Deref for SS_LEVEL_R {
-    type Target = crate::FieldReader<bool, SS_LEVEL_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SS_LEVEL_A::HIGH
     }
 }
 #[doc = "Field `ss_level` writer - "]
-pub struct SS_LEVEL_W<'a> {
-    w: &'a mut W,
-}
+pub type SS_LEVEL_W<'a> = crate::BitWriter<'a, u32, SPI_BATC_SPEC, SS_LEVEL_A, 7>;
 impl<'a> SS_LEVEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SS_LEVEL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn low(self) -> &'a mut W {
@@ -491,22 +291,6 @@ impl<'a> SS_LEVEL_W<'a> {
     pub fn high(self) -> &'a mut W {
         self.variant(SS_LEVEL_A::HIGH)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
-        self.w
-    }
 }
 #[doc = "SS Output Owner Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -523,13 +307,9 @@ impl From<SS_OWNER_A> for bool {
     }
 }
 #[doc = "Field `ss_owner` reader - SS Output Owner Select"]
-pub struct SS_OWNER_R(crate::FieldReader<bool, SS_OWNER_A>);
+pub type SS_OWNER_R = crate::BitReader<SS_OWNER_A>;
 impl SS_OWNER_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SS_OWNER_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SS_OWNER_A {
         match self.bits {
@@ -540,31 +320,17 @@ impl SS_OWNER_R {
     #[doc = "Checks if the value of the field is `SPI_CONTROLLER`"]
     #[inline(always)]
     pub fn is_spi_controller(&self) -> bool {
-        **self == SS_OWNER_A::SPI_CONTROLLER
+        *self == SS_OWNER_A::SPI_CONTROLLER
     }
     #[doc = "Checks if the value of the field is `SOFTWARE`"]
     #[inline(always)]
     pub fn is_software(&self) -> bool {
-        **self == SS_OWNER_A::SOFTWARE
-    }
-}
-impl core::ops::Deref for SS_OWNER_R {
-    type Target = crate::FieldReader<bool, SS_OWNER_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SS_OWNER_A::SOFTWARE
     }
 }
 #[doc = "Field `ss_owner` writer - SS Output Owner Select"]
-pub struct SS_OWNER_W<'a> {
-    w: &'a mut W,
-}
+pub type SS_OWNER_W<'a> = crate::BitWriter<'a, u32, SPI_BATC_SPEC, SS_OWNER_A, 6>;
 impl<'a> SS_OWNER_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SS_OWNER_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn spi_controller(self) -> &'a mut W {
@@ -575,22 +341,6 @@ impl<'a> SS_OWNER_W<'a> {
     pub fn software(self) -> &'a mut W {
         self.variant(SS_OWNER_A::SOFTWARE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
-        self.w
-    }
 }
 #[doc = "SPI Chip Select Signal Polarity Control\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -607,13 +357,9 @@ impl From<SPOL_A> for bool {
     }
 }
 #[doc = "Field `spol` reader - SPI Chip Select Signal Polarity Control"]
-pub struct SPOL_R(crate::FieldReader<bool, SPOL_A>);
+pub type SPOL_R = crate::BitReader<SPOL_A>;
 impl SPOL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SPOL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SPOL_A {
         match self.bits {
@@ -624,31 +370,17 @@ impl SPOL_R {
     #[doc = "Checks if the value of the field is `HIGH`"]
     #[inline(always)]
     pub fn is_high(&self) -> bool {
-        **self == SPOL_A::HIGH
+        *self == SPOL_A::HIGH
     }
     #[doc = "Checks if the value of the field is `LOW`"]
     #[inline(always)]
     pub fn is_low(&self) -> bool {
-        **self == SPOL_A::LOW
-    }
-}
-impl core::ops::Deref for SPOL_R {
-    type Target = crate::FieldReader<bool, SPOL_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SPOL_A::LOW
     }
 }
 #[doc = "Field `spol` writer - SPI Chip Select Signal Polarity Control"]
-pub struct SPOL_W<'a> {
-    w: &'a mut W,
-}
+pub type SPOL_W<'a> = crate::BitWriter<'a, u32, SPI_BATC_SPEC, SPOL_A, 5>;
 impl<'a> SPOL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SPOL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
@@ -659,22 +391,6 @@ impl<'a> SPOL_W<'a> {
     pub fn low(self) -> &'a mut W {
         self.variant(SPOL_A::LOW)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
-        self.w
-    }
 }
 #[doc = "SPI Chip Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -696,13 +412,9 @@ impl From<SS_SEL_A> for u8 {
     }
 }
 #[doc = "Field `ss_sel` reader - SPI Chip Select"]
-pub struct SS_SEL_R(crate::FieldReader<u8, SS_SEL_A>);
+pub type SS_SEL_R = crate::FieldReader<u8, SS_SEL_A>;
 impl SS_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        SS_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SS_SEL_A {
         match self.bits {
@@ -716,41 +428,27 @@ impl SS_SEL_R {
     #[doc = "Checks if the value of the field is `SS0`"]
     #[inline(always)]
     pub fn is_ss0(&self) -> bool {
-        **self == SS_SEL_A::SS0
+        *self == SS_SEL_A::SS0
     }
     #[doc = "Checks if the value of the field is `SS1`"]
     #[inline(always)]
     pub fn is_ss1(&self) -> bool {
-        **self == SS_SEL_A::SS1
+        *self == SS_SEL_A::SS1
     }
     #[doc = "Checks if the value of the field is `SS2`"]
     #[inline(always)]
     pub fn is_ss2(&self) -> bool {
-        **self == SS_SEL_A::SS2
+        *self == SS_SEL_A::SS2
     }
     #[doc = "Checks if the value of the field is `SS3`"]
     #[inline(always)]
     pub fn is_ss3(&self) -> bool {
-        **self == SS_SEL_A::SS3
-    }
-}
-impl core::ops::Deref for SS_SEL_R {
-    type Target = crate::FieldReader<u8, SS_SEL_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SS_SEL_A::SS3
     }
 }
 #[doc = "Field `ss_sel` writer - SPI Chip Select"]
-pub struct SS_SEL_W<'a> {
-    w: &'a mut W,
-}
+pub type SS_SEL_W<'a> = crate::FieldWriterSafe<'a, u32, SPI_BATC_SPEC, u8, SS_SEL_A, 2, 2>;
 impl<'a> SS_SEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SS_SEL_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn ss0(self) -> &'a mut W {
@@ -771,12 +469,6 @@ impl<'a> SS_SEL_W<'a> {
     pub fn ss3(self) -> &'a mut W {
         self.variant(SS_SEL_A::SS3)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 2)) | ((value as u32 & 0x03) << 2);
-        self.w
-    }
 }
 #[doc = "Work Mode Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -796,13 +488,9 @@ impl From<WMS_A> for u8 {
     }
 }
 #[doc = "Field `wms` reader - Work Mode Select"]
-pub struct WMS_R(crate::FieldReader<u8, WMS_A>);
+pub type WMS_R = crate::FieldReader<u8, WMS_A>;
 impl WMS_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        WMS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> WMS_A {
         match self.bits {
@@ -815,36 +503,22 @@ impl WMS_R {
     #[doc = "Checks if the value of the field is `BYTE_ALIGNED`"]
     #[inline(always)]
     pub fn is_byte_aligned(&self) -> bool {
-        **self == WMS_A::BYTE_ALIGNED
+        *self == WMS_A::BYTE_ALIGNED
     }
     #[doc = "Checks if the value of the field is `BIT_ALIGNED_3WIRE`"]
     #[inline(always)]
     pub fn is_bit_aligned_3wire(&self) -> bool {
-        **self == WMS_A::BIT_ALIGNED_3WIRE
+        *self == WMS_A::BIT_ALIGNED_3WIRE
     }
     #[doc = "Checks if the value of the field is `BIT_ALIGNED_STANDARD`"]
     #[inline(always)]
     pub fn is_bit_aligned_standard(&self) -> bool {
-        **self == WMS_A::BIT_ALIGNED_STANDARD
-    }
-}
-impl core::ops::Deref for WMS_R {
-    type Target = crate::FieldReader<u8, WMS_A>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == WMS_A::BIT_ALIGNED_STANDARD
     }
 }
 #[doc = "Field `wms` writer - Work Mode Select"]
-pub struct WMS_W<'a> {
-    w: &'a mut W,
-}
+pub type WMS_W<'a> = crate::FieldWriter<'a, u32, SPI_BATC_SPEC, u8, WMS_A, 2, 0>;
 impl<'a> WMS_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: WMS_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn byte_aligned(self) -> &'a mut W {
@@ -860,33 +534,27 @@ impl<'a> WMS_W<'a> {
     pub fn bit_aligned_standard(self) -> &'a mut W {
         self.variant(WMS_A::BIT_ALIGNED_STANDARD)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x03) | (value as u32 & 0x03);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 31 - Transfer Control Enable"]
     #[inline(always)]
     pub fn tce(&self) -> TCE_R {
-        TCE_R::new(((self.bits >> 31) & 0x01) != 0)
+        TCE_R::new(((self.bits >> 31) & 1) != 0)
     }
     #[doc = "Bit 30 - Master Sample Standard"]
     #[inline(always)]
     pub fn msms(&self) -> MSMS_R {
-        MSMS_R::new(((self.bits >> 30) & 0x01) != 0)
+        MSMS_R::new(((self.bits >> 30) & 1) != 0)
     }
     #[doc = "Bit 25 - Transfer Bits Completed"]
     #[inline(always)]
     pub fn tbc(&self) -> TBC_R {
-        TBC_R::new(((self.bits >> 25) & 0x01) != 0)
+        TBC_R::new(((self.bits >> 25) & 1) != 0)
     }
     #[doc = "Bit 24 - Transfer Bits Completed Interrupt Enable"]
     #[inline(always)]
     pub fn tbc_int_en(&self) -> TBC_INT_EN_R {
-        TBC_INT_EN_R::new(((self.bits >> 24) & 0x01) != 0)
+        TBC_INT_EN_R::new(((self.bits >> 24) & 1) != 0)
     }
     #[doc = "Bits 16:21 - Configure the length of serial data frame of RX"]
     #[inline(always)]
@@ -901,84 +569,84 @@ impl R {
     #[doc = "Bit 7"]
     #[inline(always)]
     pub fn ss_level(&self) -> SS_LEVEL_R {
-        SS_LEVEL_R::new(((self.bits >> 7) & 0x01) != 0)
+        SS_LEVEL_R::new(((self.bits >> 7) & 1) != 0)
     }
     #[doc = "Bit 6 - SS Output Owner Select"]
     #[inline(always)]
     pub fn ss_owner(&self) -> SS_OWNER_R {
-        SS_OWNER_R::new(((self.bits >> 6) & 0x01) != 0)
+        SS_OWNER_R::new(((self.bits >> 6) & 1) != 0)
     }
     #[doc = "Bit 5 - SPI Chip Select Signal Polarity Control"]
     #[inline(always)]
     pub fn spol(&self) -> SPOL_R {
-        SPOL_R::new(((self.bits >> 5) & 0x01) != 0)
+        SPOL_R::new(((self.bits >> 5) & 1) != 0)
     }
     #[doc = "Bits 2:3 - SPI Chip Select"]
     #[inline(always)]
     pub fn ss_sel(&self) -> SS_SEL_R {
-        SS_SEL_R::new(((self.bits >> 2) & 0x03) as u8)
+        SS_SEL_R::new(((self.bits >> 2) & 3) as u8)
     }
     #[doc = "Bits 0:1 - Work Mode Select"]
     #[inline(always)]
     pub fn wms(&self) -> WMS_R {
-        WMS_R::new((self.bits & 0x03) as u8)
+        WMS_R::new((self.bits & 3) as u8)
     }
 }
 impl W {
     #[doc = "Bit 31 - Transfer Control Enable"]
     #[inline(always)]
     pub fn tce(&mut self) -> TCE_W {
-        TCE_W { w: self }
+        TCE_W::new(self)
     }
     #[doc = "Bit 30 - Master Sample Standard"]
     #[inline(always)]
     pub fn msms(&mut self) -> MSMS_W {
-        MSMS_W { w: self }
+        MSMS_W::new(self)
     }
     #[doc = "Bit 25 - Transfer Bits Completed"]
     #[inline(always)]
     pub fn tbc(&mut self) -> TBC_W {
-        TBC_W { w: self }
+        TBC_W::new(self)
     }
     #[doc = "Bit 24 - Transfer Bits Completed Interrupt Enable"]
     #[inline(always)]
     pub fn tbc_int_en(&mut self) -> TBC_INT_EN_W {
-        TBC_INT_EN_W { w: self }
+        TBC_INT_EN_W::new(self)
     }
     #[doc = "Bits 16:21 - Configure the length of serial data frame of RX"]
     #[inline(always)]
     pub fn rx_frm_len(&mut self) -> RX_FRM_LEN_W {
-        RX_FRM_LEN_W { w: self }
+        RX_FRM_LEN_W::new(self)
     }
     #[doc = "Bits 8:13 - Configure the length of serial data frame of TX"]
     #[inline(always)]
     pub fn tx_frm_len(&mut self) -> TX_FRM_LEN_W {
-        TX_FRM_LEN_W { w: self }
+        TX_FRM_LEN_W::new(self)
     }
     #[doc = "Bit 7"]
     #[inline(always)]
     pub fn ss_level(&mut self) -> SS_LEVEL_W {
-        SS_LEVEL_W { w: self }
+        SS_LEVEL_W::new(self)
     }
     #[doc = "Bit 6 - SS Output Owner Select"]
     #[inline(always)]
     pub fn ss_owner(&mut self) -> SS_OWNER_W {
-        SS_OWNER_W { w: self }
+        SS_OWNER_W::new(self)
     }
     #[doc = "Bit 5 - SPI Chip Select Signal Polarity Control"]
     #[inline(always)]
     pub fn spol(&mut self) -> SPOL_W {
-        SPOL_W { w: self }
+        SPOL_W::new(self)
     }
     #[doc = "Bits 2:3 - SPI Chip Select"]
     #[inline(always)]
     pub fn ss_sel(&mut self) -> SS_SEL_W {
-        SS_SEL_W { w: self }
+        SS_SEL_W::new(self)
     }
     #[doc = "Bits 0:1 - Work Mode Select"]
     #[inline(always)]
     pub fn wms(&mut self) -> WMS_W {
-        WMS_W { w: self }
+        WMS_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
