@@ -35,32 +35,9 @@ impl From<crate::W<EMAC_EPHY_CLK0_SPEC>> for W {
     }
 }
 #[doc = "Field `BPS_EFUSE` reader - "]
-pub struct BPS_EFUSE_R(crate::FieldReader<u8>);
-impl BPS_EFUSE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        BPS_EFUSE_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for BPS_EFUSE_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type BPS_EFUSE_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `BPS_EFUSE` writer - "]
-pub struct BPS_EFUSE_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> BPS_EFUSE_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 28)) | ((value as u32 & 0x0f) << 28);
-        self.w
-    }
-}
+pub type BPS_EFUSE_W<'a> = crate::FieldWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, u8, u8, 4, 28>;
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum XMII_SEL_A {
@@ -76,13 +53,9 @@ impl From<XMII_SEL_A> for bool {
     }
 }
 #[doc = "Field `XMII_SEL` reader - "]
-pub struct XMII_SEL_R(crate::FieldReader<bool>);
+pub type XMII_SEL_R = crate::BitReader<XMII_SEL_A>;
 impl XMII_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        XMII_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> XMII_SEL_A {
         match self.bits {
@@ -93,31 +66,17 @@ impl XMII_SEL_R {
     #[doc = "Checks if the value of the field is `INTERNAL`"]
     #[inline(always)]
     pub fn is_internal(&self) -> bool {
-        **self == XMII_SEL_A::INTERNAL
+        *self == XMII_SEL_A::INTERNAL
     }
     #[doc = "Checks if the value of the field is `EXTERNAL`"]
     #[inline(always)]
     pub fn is_external(&self) -> bool {
-        **self == XMII_SEL_A::EXTERNAL
-    }
-}
-impl core::ops::Deref for XMII_SEL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == XMII_SEL_A::EXTERNAL
     }
 }
 #[doc = "Field `XMII_SEL` writer - "]
-pub struct XMII_SEL_W<'a> {
-    w: &'a mut W,
-}
+pub type XMII_SEL_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, XMII_SEL_A, 27>;
 impl<'a> XMII_SEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: XMII_SEL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn internal(self) -> &'a mut W {
@@ -128,22 +87,6 @@ impl<'a> XMII_SEL_W<'a> {
     pub fn external(self) -> &'a mut W {
         self.variant(XMII_SEL_A::EXTERNAL)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 27)) | ((value as u32 & 1) << 27);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -163,13 +106,9 @@ impl From<EPHY_MODE_A> for u8 {
     }
 }
 #[doc = "Field `EPHY_MODE` reader - "]
-pub struct EPHY_MODE_R(crate::FieldReader<u8>);
+pub type EPHY_MODE_R = crate::FieldReader<u8, EPHY_MODE_A>;
 impl EPHY_MODE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        EPHY_MODE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<EPHY_MODE_A> {
         match self.bits {
@@ -182,36 +121,22 @@ impl EPHY_MODE_R {
     #[doc = "Checks if the value of the field is `NORMAL`"]
     #[inline(always)]
     pub fn is_normal(&self) -> bool {
-        **self == EPHY_MODE_A::NORMAL
+        *self == EPHY_MODE_A::NORMAL
     }
     #[doc = "Checks if the value of the field is `SIMULATION`"]
     #[inline(always)]
     pub fn is_simulation(&self) -> bool {
-        **self == EPHY_MODE_A::SIMULATION
+        *self == EPHY_MODE_A::SIMULATION
     }
     #[doc = "Checks if the value of the field is `AFE_TEST`"]
     #[inline(always)]
     pub fn is_afe_test(&self) -> bool {
-        **self == EPHY_MODE_A::AFE_TEST
-    }
-}
-impl core::ops::Deref for EPHY_MODE_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == EPHY_MODE_A::AFE_TEST
     }
 }
 #[doc = "Field `EPHY_MODE` writer - "]
-pub struct EPHY_MODE_W<'a> {
-    w: &'a mut W,
-}
+pub type EPHY_MODE_W<'a> = crate::FieldWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, u8, EPHY_MODE_A, 2, 25>;
 impl<'a> EPHY_MODE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: EPHY_MODE_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn normal(self) -> &'a mut W {
@@ -227,40 +152,11 @@ impl<'a> EPHY_MODE_W<'a> {
     pub fn afe_test(self) -> &'a mut W {
         self.variant(EPHY_MODE_A::AFE_TEST)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 25)) | ((value as u32 & 3) << 25);
-        self.w
-    }
 }
 #[doc = "Field `PHY_ADDR` reader - "]
-pub struct PHY_ADDR_R(crate::FieldReader<u8>);
-impl PHY_ADDR_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        PHY_ADDR_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for PHY_ADDR_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type PHY_ADDR_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `PHY_ADDR` writer - "]
-pub struct PHY_ADDR_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> PHY_ADDR_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x1f << 20)) | ((value as u32 & 0x1f) << 20);
-        self.w
-    }
-}
+pub type PHY_ADDR_W<'a> = crate::FieldWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, u8, u8, 5, 20>;
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum CLK_SEL_A {
@@ -276,13 +172,9 @@ impl From<CLK_SEL_A> for bool {
     }
 }
 #[doc = "Field `CLK_SEL` reader - "]
-pub struct CLK_SEL_R(crate::FieldReader<bool>);
+pub type CLK_SEL_R = crate::BitReader<CLK_SEL_A>;
 impl CLK_SEL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        CLK_SEL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CLK_SEL_A {
         match self.bits {
@@ -293,31 +185,17 @@ impl CLK_SEL_R {
     #[doc = "Checks if the value of the field is `F25M`"]
     #[inline(always)]
     pub fn is_f25m(&self) -> bool {
-        **self == CLK_SEL_A::F25M
+        *self == CLK_SEL_A::F25M
     }
     #[doc = "Checks if the value of the field is `F24M`"]
     #[inline(always)]
     pub fn is_f24m(&self) -> bool {
-        **self == CLK_SEL_A::F24M
-    }
-}
-impl core::ops::Deref for CLK_SEL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == CLK_SEL_A::F24M
     }
 }
 #[doc = "Field `CLK_SEL` writer - "]
-pub struct CLK_SEL_W<'a> {
-    w: &'a mut W,
-}
+pub type CLK_SEL_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, CLK_SEL_A, 18>;
 impl<'a> CLK_SEL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: CLK_SEL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn f25m(self) -> &'a mut W {
@@ -328,22 +206,6 @@ impl<'a> CLK_SEL_W<'a> {
     pub fn f24m(self) -> &'a mut W {
         self.variant(CLK_SEL_A::F24M)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 18)) | ((value as u32 & 1) << 18);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -360,13 +222,9 @@ impl From<LED_POL_A> for bool {
     }
 }
 #[doc = "Field `LED_POL` reader - "]
-pub struct LED_POL_R(crate::FieldReader<bool>);
+pub type LED_POL_R = crate::BitReader<LED_POL_A>;
 impl LED_POL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        LED_POL_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> LED_POL_A {
         match self.bits {
@@ -377,31 +235,17 @@ impl LED_POL_R {
     #[doc = "Checks if the value of the field is `HIGH`"]
     #[inline(always)]
     pub fn is_high(&self) -> bool {
-        **self == LED_POL_A::HIGH
+        *self == LED_POL_A::HIGH
     }
     #[doc = "Checks if the value of the field is `LOW`"]
     #[inline(always)]
     pub fn is_low(&self) -> bool {
-        **self == LED_POL_A::LOW
-    }
-}
-impl core::ops::Deref for LED_POL_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == LED_POL_A::LOW
     }
 }
 #[doc = "Field `LED_POL` writer - "]
-pub struct LED_POL_W<'a> {
-    w: &'a mut W,
-}
+pub type LED_POL_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, LED_POL_A, 17>;
 impl<'a> LED_POL_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: LED_POL_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn high(self) -> &'a mut W {
@@ -412,22 +256,6 @@ impl<'a> LED_POL_W<'a> {
     pub fn low(self) -> &'a mut W {
         self.variant(LED_POL_A::LOW)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 17)) | ((value as u32 & 1) << 17);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -444,13 +272,9 @@ impl From<SHUTDOWN_A> for bool {
     }
 }
 #[doc = "Field `SHUTDOWN` reader - "]
-pub struct SHUTDOWN_R(crate::FieldReader<bool>);
+pub type SHUTDOWN_R = crate::BitReader<SHUTDOWN_A>;
 impl SHUTDOWN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        SHUTDOWN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SHUTDOWN_A {
         match self.bits {
@@ -461,31 +285,17 @@ impl SHUTDOWN_R {
     #[doc = "Checks if the value of the field is `POWER_UP`"]
     #[inline(always)]
     pub fn is_power_up(&self) -> bool {
-        **self == SHUTDOWN_A::POWER_UP
+        *self == SHUTDOWN_A::POWER_UP
     }
     #[doc = "Checks if the value of the field is `SHUT_DOWN`"]
     #[inline(always)]
     pub fn is_shut_down(&self) -> bool {
-        **self == SHUTDOWN_A::SHUT_DOWN
-    }
-}
-impl core::ops::Deref for SHUTDOWN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == SHUTDOWN_A::SHUT_DOWN
     }
 }
 #[doc = "Field `SHUTDOWN` writer - "]
-pub struct SHUTDOWN_W<'a> {
-    w: &'a mut W,
-}
+pub type SHUTDOWN_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, SHUTDOWN_A, 16>;
 impl<'a> SHUTDOWN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: SHUTDOWN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn power_up(self) -> &'a mut W {
@@ -496,22 +306,6 @@ impl<'a> SHUTDOWN_W<'a> {
     pub fn shut_down(self) -> &'a mut W {
         self.variant(SHUTDOWN_A::SHUT_DOWN)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 16)) | ((value as u32 & 1) << 16);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -528,13 +322,9 @@ impl From<PHY_SELECT_A> for bool {
     }
 }
 #[doc = "Field `PHY_SELECT` reader - "]
-pub struct PHY_SELECT_R(crate::FieldReader<bool>);
+pub type PHY_SELECT_R = crate::BitReader<PHY_SELECT_A>;
 impl PHY_SELECT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        PHY_SELECT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> PHY_SELECT_A {
         match self.bits {
@@ -545,31 +335,17 @@ impl PHY_SELECT_R {
     #[doc = "Checks if the value of the field is `EXTERNAL`"]
     #[inline(always)]
     pub fn is_external(&self) -> bool {
-        **self == PHY_SELECT_A::EXTERNAL
+        *self == PHY_SELECT_A::EXTERNAL
     }
     #[doc = "Checks if the value of the field is `INTERNAL`"]
     #[inline(always)]
     pub fn is_internal(&self) -> bool {
-        **self == PHY_SELECT_A::INTERNAL
-    }
-}
-impl core::ops::Deref for PHY_SELECT_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == PHY_SELECT_A::INTERNAL
     }
 }
 #[doc = "Field `PHY_SELECT` writer - "]
-pub struct PHY_SELECT_W<'a> {
-    w: &'a mut W,
-}
+pub type PHY_SELECT_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, PHY_SELECT_A, 15>;
 impl<'a> PHY_SELECT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: PHY_SELECT_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn external(self) -> &'a mut W {
@@ -580,22 +356,6 @@ impl<'a> PHY_SELECT_W<'a> {
     pub fn internal(self) -> &'a mut W {
         self.variant(PHY_SELECT_A::INTERNAL)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 15)) | ((value as u32 & 1) << 15);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -612,13 +372,9 @@ impl From<RMII_EN_A> for bool {
     }
 }
 #[doc = "Field `RMII_EN` reader - "]
-pub struct RMII_EN_R(crate::FieldReader<bool>);
+pub type RMII_EN_R = crate::BitReader<RMII_EN_A>;
 impl RMII_EN_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        RMII_EN_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RMII_EN_A {
         match self.bits {
@@ -629,31 +385,17 @@ impl RMII_EN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == RMII_EN_A::DISABLE
+        *self == RMII_EN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == RMII_EN_A::ENABLE
-    }
-}
-impl core::ops::Deref for RMII_EN_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == RMII_EN_A::ENABLE
     }
 }
 #[doc = "Field `RMII_EN` writer - "]
-pub struct RMII_EN_W<'a> {
-    w: &'a mut W,
-}
+pub type RMII_EN_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, RMII_EN_A, 13>;
 impl<'a> RMII_EN_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: RMII_EN_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -664,77 +406,15 @@ impl<'a> RMII_EN_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(RMII_EN_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 13)) | ((value as u32 & 1) << 13);
-        self.w
-    }
 }
 #[doc = "Field `ETXDC` reader - "]
-pub struct ETXDC_R(crate::FieldReader<u8>);
-impl ETXDC_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        ETXDC_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for ETXDC_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ETXDC_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `ETXDC` writer - "]
-pub struct ETXDC_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ETXDC_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(7 << 10)) | ((value as u32 & 7) << 10);
-        self.w
-    }
-}
+pub type ETXDC_W<'a> = crate::FieldWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, u8, u8, 3, 10>;
 #[doc = "Field `ERXDC` reader - "]
-pub struct ERXDC_R(crate::FieldReader<u8>);
-impl ERXDC_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        ERXDC_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for ERXDC_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ERXDC_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `ERXDC` writer - "]
-pub struct ERXDC_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ERXDC_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x1f << 5)) | ((value as u32 & 0x1f) << 5);
-        self.w
-    }
-}
+pub type ERXDC_W<'a> = crate::FieldWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, u8, u8, 5, 5>;
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ERXIE_A {
@@ -750,13 +430,9 @@ impl From<ERXIE_A> for bool {
     }
 }
 #[doc = "Field `ERXIE` reader - "]
-pub struct ERXIE_R(crate::FieldReader<bool>);
+pub type ERXIE_R = crate::BitReader<ERXIE_A>;
 impl ERXIE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        ERXIE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ERXIE_A {
         match self.bits {
@@ -767,31 +443,17 @@ impl ERXIE_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == ERXIE_A::DISABLE
+        *self == ERXIE_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == ERXIE_A::ENABLE
-    }
-}
-impl core::ops::Deref for ERXIE_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == ERXIE_A::ENABLE
     }
 }
 #[doc = "Field `ERXIE` writer - "]
-pub struct ERXIE_W<'a> {
-    w: &'a mut W,
-}
+pub type ERXIE_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, ERXIE_A, 4>;
 impl<'a> ERXIE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ERXIE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -802,22 +464,6 @@ impl<'a> ERXIE_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(ERXIE_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 4)) | ((value as u32 & 1) << 4);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -834,13 +480,9 @@ impl From<ETXIE_A> for bool {
     }
 }
 #[doc = "Field `ETXIE` reader - "]
-pub struct ETXIE_R(crate::FieldReader<bool>);
+pub type ETXIE_R = crate::BitReader<ETXIE_A>;
 impl ETXIE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        ETXIE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ETXIE_A {
         match self.bits {
@@ -851,31 +493,17 @@ impl ETXIE_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        **self == ETXIE_A::DISABLE
+        *self == ETXIE_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        **self == ETXIE_A::ENABLE
-    }
-}
-impl core::ops::Deref for ETXIE_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == ETXIE_A::ENABLE
     }
 }
 #[doc = "Field `ETXIE` writer - "]
-pub struct ETXIE_W<'a> {
-    w: &'a mut W,
-}
+pub type ETXIE_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, ETXIE_A, 3>;
 impl<'a> ETXIE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ETXIE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn disable(self) -> &'a mut W {
@@ -886,22 +514,6 @@ impl<'a> ETXIE_W<'a> {
     pub fn enable(self) -> &'a mut W {
         self.variant(ETXIE_A::ENABLE)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 3)) | ((value as u32 & 1) << 3);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -918,13 +530,9 @@ impl From<EPIT_A> for bool {
     }
 }
 #[doc = "Field `EPIT` reader - "]
-pub struct EPIT_R(crate::FieldReader<bool>);
+pub type EPIT_R = crate::BitReader<EPIT_A>;
 impl EPIT_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        EPIT_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIT_A {
         match self.bits {
@@ -935,31 +543,17 @@ impl EPIT_R {
     #[doc = "Checks if the value of the field is `MII`"]
     #[inline(always)]
     pub fn is_mii(&self) -> bool {
-        **self == EPIT_A::MII
+        *self == EPIT_A::MII
     }
     #[doc = "Checks if the value of the field is `RGMII`"]
     #[inline(always)]
     pub fn is_rgmii(&self) -> bool {
-        **self == EPIT_A::RGMII
-    }
-}
-impl core::ops::Deref for EPIT_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == EPIT_A::RGMII
     }
 }
 #[doc = "Field `EPIT` writer - "]
-pub struct EPIT_W<'a> {
-    w: &'a mut W,
-}
+pub type EPIT_W<'a> = crate::BitWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, EPIT_A, 2>;
 impl<'a> EPIT_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: EPIT_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn mii(self) -> &'a mut W {
@@ -970,22 +564,6 @@ impl<'a> EPIT_W<'a> {
     pub fn rgmii(self) -> &'a mut W {
         self.variant(EPIT_A::RGMII)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 2)) | ((value as u32 & 1) << 2);
-        self.w
-    }
 }
 #[doc = "\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -1005,13 +583,9 @@ impl From<ETCS_A> for u8 {
     }
 }
 #[doc = "Field `ETCS` reader - "]
-pub struct ETCS_R(crate::FieldReader<u8>);
+pub type ETCS_R = crate::FieldReader<u8, ETCS_A>;
 impl ETCS_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        ETCS_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<ETCS_A> {
         match self.bits {
@@ -1024,36 +598,22 @@ impl ETCS_R {
     #[doc = "Checks if the value of the field is `MII`"]
     #[inline(always)]
     pub fn is_mii(&self) -> bool {
-        **self == ETCS_A::MII
+        *self == ETCS_A::MII
     }
     #[doc = "Checks if the value of the field is `EXTERNAL_GMII_RGMII`"]
     #[inline(always)]
     pub fn is_external_gmii_rgmii(&self) -> bool {
-        **self == ETCS_A::EXTERNAL_GMII_RGMII
+        *self == ETCS_A::EXTERNAL_GMII_RGMII
     }
     #[doc = "Checks if the value of the field is `INTERNAL_GMII_RGMII`"]
     #[inline(always)]
     pub fn is_internal_gmii_rgmii(&self) -> bool {
-        **self == ETCS_A::INTERNAL_GMII_RGMII
-    }
-}
-impl core::ops::Deref for ETCS_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == ETCS_A::INTERNAL_GMII_RGMII
     }
 }
 #[doc = "Field `ETCS` writer - "]
-pub struct ETCS_W<'a> {
-    w: &'a mut W,
-}
+pub type ETCS_W<'a> = crate::FieldWriter<'a, u32, EMAC_EPHY_CLK0_SPEC, u8, ETCS_A, 2, 0>;
 impl<'a> ETCS_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ETCS_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn mii(self) -> &'a mut W {
@@ -1069,12 +629,6 @@ impl<'a> ETCS_W<'a> {
     pub fn internal_gmii_rgmii(self) -> &'a mut W {
         self.variant(ETCS_A::INTERNAL_GMII_RGMII)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bits 28:31"]
@@ -1157,77 +711,77 @@ impl W {
     #[doc = "Bits 28:31"]
     #[inline(always)]
     pub fn bps_efuse(&mut self) -> BPS_EFUSE_W {
-        BPS_EFUSE_W { w: self }
+        BPS_EFUSE_W::new(self)
     }
     #[doc = "Bit 27"]
     #[inline(always)]
     pub fn xmii_sel(&mut self) -> XMII_SEL_W {
-        XMII_SEL_W { w: self }
+        XMII_SEL_W::new(self)
     }
     #[doc = "Bits 25:26"]
     #[inline(always)]
     pub fn ephy_mode(&mut self) -> EPHY_MODE_W {
-        EPHY_MODE_W { w: self }
+        EPHY_MODE_W::new(self)
     }
     #[doc = "Bits 20:24"]
     #[inline(always)]
     pub fn phy_addr(&mut self) -> PHY_ADDR_W {
-        PHY_ADDR_W { w: self }
+        PHY_ADDR_W::new(self)
     }
     #[doc = "Bit 18"]
     #[inline(always)]
     pub fn clk_sel(&mut self) -> CLK_SEL_W {
-        CLK_SEL_W { w: self }
+        CLK_SEL_W::new(self)
     }
     #[doc = "Bit 17"]
     #[inline(always)]
     pub fn led_pol(&mut self) -> LED_POL_W {
-        LED_POL_W { w: self }
+        LED_POL_W::new(self)
     }
     #[doc = "Bit 16"]
     #[inline(always)]
     pub fn shutdown(&mut self) -> SHUTDOWN_W {
-        SHUTDOWN_W { w: self }
+        SHUTDOWN_W::new(self)
     }
     #[doc = "Bit 15"]
     #[inline(always)]
     pub fn phy_select(&mut self) -> PHY_SELECT_W {
-        PHY_SELECT_W { w: self }
+        PHY_SELECT_W::new(self)
     }
     #[doc = "Bit 13"]
     #[inline(always)]
     pub fn rmii_en(&mut self) -> RMII_EN_W {
-        RMII_EN_W { w: self }
+        RMII_EN_W::new(self)
     }
     #[doc = "Bits 10:12"]
     #[inline(always)]
     pub fn etxdc(&mut self) -> ETXDC_W {
-        ETXDC_W { w: self }
+        ETXDC_W::new(self)
     }
     #[doc = "Bits 5:9"]
     #[inline(always)]
     pub fn erxdc(&mut self) -> ERXDC_W {
-        ERXDC_W { w: self }
+        ERXDC_W::new(self)
     }
     #[doc = "Bit 4"]
     #[inline(always)]
     pub fn erxie(&mut self) -> ERXIE_W {
-        ERXIE_W { w: self }
+        ERXIE_W::new(self)
     }
     #[doc = "Bit 3"]
     #[inline(always)]
     pub fn etxie(&mut self) -> ETXIE_W {
-        ETXIE_W { w: self }
+        ETXIE_W::new(self)
     }
     #[doc = "Bit 2"]
     #[inline(always)]
     pub fn epit(&mut self) -> EPIT_W {
-        EPIT_W { w: self }
+        EPIT_W::new(self)
     }
     #[doc = "Bits 0:1"]
     #[inline(always)]
     pub fn etcs(&mut self) -> ETCS_W {
-        ETCS_W { w: self }
+        ETCS_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
