@@ -14,20 +14,7 @@ impl From<crate::R<VER_SPEC>> for R {
     }
 }
 #[doc = "Field `BOOT_SEL_PAD_STA` reader - "]
-pub struct BOOT_SEL_PAD_STA_R(crate::FieldReader<u8>);
-impl BOOT_SEL_PAD_STA_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        BOOT_SEL_PAD_STA_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for BOOT_SEL_PAD_STA_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type BOOT_SEL_PAD_STA_R = crate::FieldReader<u8, u8>;
 #[doc = "Fel Select Pin Status\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum FEL_SEL_PAD_STA_A {
@@ -43,13 +30,9 @@ impl From<FEL_SEL_PAD_STA_A> for bool {
     }
 }
 #[doc = "Field `FEL_SEL_PAD_STA` reader - Fel Select Pin Status"]
-pub struct FEL_SEL_PAD_STA_R(crate::FieldReader<bool>);
+pub type FEL_SEL_PAD_STA_R = crate::BitReader<FEL_SEL_PAD_STA_A>;
 impl FEL_SEL_PAD_STA_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        FEL_SEL_PAD_STA_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FEL_SEL_PAD_STA_A {
         match self.bits {
@@ -60,19 +43,12 @@ impl FEL_SEL_PAD_STA_R {
     #[doc = "Checks if the value of the field is `RUN_FEL`"]
     #[inline(always)]
     pub fn is_run_fel(&self) -> bool {
-        **self == FEL_SEL_PAD_STA_A::RUN_FEL
+        *self == FEL_SEL_PAD_STA_A::RUN_FEL
     }
     #[doc = "Checks if the value of the field is `TRY_MEDIA_BOOT`"]
     #[inline(always)]
     pub fn is_try_media_boot(&self) -> bool {
-        **self == FEL_SEL_PAD_STA_A::TRY_MEDIA_BOOT
-    }
-}
-impl core::ops::Deref for FEL_SEL_PAD_STA_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FEL_SEL_PAD_STA_A::TRY_MEDIA_BOOT
     }
 }
 impl R {
