@@ -35,17 +35,7 @@ impl From<crate::W<WDOG_CFG_SPEC>> for W {
     }
 }
 #[doc = "Field `KEY_FIELD` writer - Key Field"]
-pub struct KEY_FIELD_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> KEY_FIELD_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0xffff << 16)) | ((value as u32 & 0xffff) << 16);
-        self.w
-    }
-}
+pub type KEY_FIELD_W<'a> = crate::FieldWriter<'a, u32, WDOG_CFG_SPEC, u16, u16, 16, 16>;
 #[doc = "Select the clock source for the watchdog.\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDOG_CLK_SRC_A {
@@ -61,13 +51,9 @@ impl From<WDOG_CLK_SRC_A> for bool {
     }
 }
 #[doc = "Field `WDOG_CLK_SRC` reader - Select the clock source for the watchdog."]
-pub struct WDOG_CLK_SRC_R(crate::FieldReader<bool>);
+pub type WDOG_CLK_SRC_R = crate::BitReader<WDOG_CLK_SRC_A>;
 impl WDOG_CLK_SRC_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        WDOG_CLK_SRC_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> WDOG_CLK_SRC_A {
         match self.bits {
@@ -78,31 +64,17 @@ impl WDOG_CLK_SRC_R {
     #[doc = "Checks if the value of the field is `HOSC_32K`"]
     #[inline(always)]
     pub fn is_hosc_32k(&self) -> bool {
-        **self == WDOG_CLK_SRC_A::HOSC_32K
+        *self == WDOG_CLK_SRC_A::HOSC_32K
     }
     #[doc = "Checks if the value of the field is `LOSC_32K`"]
     #[inline(always)]
     pub fn is_losc_32k(&self) -> bool {
-        **self == WDOG_CLK_SRC_A::LOSC_32K
-    }
-}
-impl core::ops::Deref for WDOG_CLK_SRC_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == WDOG_CLK_SRC_A::LOSC_32K
     }
 }
 #[doc = "Field `WDOG_CLK_SRC` writer - Select the clock source for the watchdog."]
-pub struct WDOG_CLK_SRC_W<'a> {
-    w: &'a mut W,
-}
+pub type WDOG_CLK_SRC_W<'a> = crate::BitWriter<'a, u32, WDOG_CFG_SPEC, WDOG_CLK_SRC_A, 8>;
 impl<'a> WDOG_CLK_SRC_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: WDOG_CLK_SRC_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn hosc_32k(self) -> &'a mut W {
@@ -113,22 +85,6 @@ impl<'a> WDOG_CLK_SRC_W<'a> {
     pub fn losc_32k(self) -> &'a mut W {
         self.variant(WDOG_CLK_SRC_A::LOSC_32K)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 8)) | ((value as u32 & 1) << 8);
-        self.w
-    }
 }
 #[doc = "Configure the operating mode for the watchdog\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -146,13 +102,9 @@ impl From<WDOG_MODE_A> for u8 {
     }
 }
 #[doc = "Field `WDOG_MODE` reader - Configure the operating mode for the watchdog"]
-pub struct WDOG_MODE_R(crate::FieldReader<u8>);
+pub type WDOG_MODE_R = crate::FieldReader<u8, WDOG_MODE_A>;
 impl WDOG_MODE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        WDOG_MODE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> Option<WDOG_MODE_A> {
         match self.bits {
@@ -164,31 +116,17 @@ impl WDOG_MODE_R {
     #[doc = "Checks if the value of the field is `WHOLD_SYSTEM`"]
     #[inline(always)]
     pub fn is_whold_system(&self) -> bool {
-        **self == WDOG_MODE_A::WHOLD_SYSTEM
+        *self == WDOG_MODE_A::WHOLD_SYSTEM
     }
     #[doc = "Checks if the value of the field is `ONLY_INTERRUPT`"]
     #[inline(always)]
     pub fn is_only_interrupt(&self) -> bool {
-        **self == WDOG_MODE_A::ONLY_INTERRUPT
-    }
-}
-impl core::ops::Deref for WDOG_MODE_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == WDOG_MODE_A::ONLY_INTERRUPT
     }
 }
 #[doc = "Field `WDOG_MODE` writer - Configure the operating mode for the watchdog"]
-pub struct WDOG_MODE_W<'a> {
-    w: &'a mut W,
-}
+pub type WDOG_MODE_W<'a> = crate::FieldWriter<'a, u32, WDOG_CFG_SPEC, u8, WDOG_MODE_A, 2, 0>;
 impl<'a> WDOG_MODE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: WDOG_MODE_A) -> &'a mut W {
-        unsafe { self.bits(variant.into()) }
-    }
     #[doc = "`1`"]
     #[inline(always)]
     pub fn whold_system(self) -> &'a mut W {
@@ -199,12 +137,6 @@ impl<'a> WDOG_MODE_W<'a> {
     pub fn only_interrupt(self) -> &'a mut W {
         self.variant(WDOG_MODE_A::ONLY_INTERRUPT)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !3) | (value as u32 & 3);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 8 - Select the clock source for the watchdog."]
@@ -222,17 +154,17 @@ impl W {
     #[doc = "Bits 16:31 - Key Field"]
     #[inline(always)]
     pub fn key_field(&mut self) -> KEY_FIELD_W {
-        KEY_FIELD_W { w: self }
+        KEY_FIELD_W::new(self)
     }
     #[doc = "Bit 8 - Select the clock source for the watchdog."]
     #[inline(always)]
     pub fn wdog_clk_src(&mut self) -> WDOG_CLK_SRC_W {
-        WDOG_CLK_SRC_W { w: self }
+        WDOG_CLK_SRC_W::new(self)
     }
     #[doc = "Bits 0:1 - Configure the operating mode for the watchdog"]
     #[inline(always)]
     pub fn wdog_mode(&mut self) -> WDOG_MODE_W {
-        WDOG_MODE_W { w: self }
+        WDOG_MODE_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
