@@ -35,17 +35,7 @@ impl From<crate::W<WDOG_CTRL_SPEC>> for W {
     }
 }
 #[doc = "Field `WDOG_KEY_FIELD` writer - Watchdog Key Field"]
-pub struct WDOG_KEY_FIELD_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> WDOG_KEY_FIELD_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0fff << 1)) | ((value as u32 & 0x0fff) << 1);
-        self.w
-    }
-}
+pub type WDOG_KEY_FIELD_W<'a> = crate::FieldWriter<'a, u32, WDOG_CTRL_SPEC, u16, u16, 12, 1>;
 #[doc = "Watchdog Restart\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum WDOG_RESTART_A {
@@ -61,13 +51,9 @@ impl From<WDOG_RESTART_A> for bool {
     }
 }
 #[doc = "Field `WDOG_RESTART` reader - Watchdog Restart"]
-pub struct WDOG_RESTART_R(crate::FieldReader<bool>);
+pub type WDOG_RESTART_R = crate::BitReader<WDOG_RESTART_A>;
 impl WDOG_RESTART_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        WDOG_RESTART_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> WDOG_RESTART_A {
         match self.bits {
@@ -78,31 +64,17 @@ impl WDOG_RESTART_R {
     #[doc = "Checks if the value of the field is `NO_EFFECT`"]
     #[inline(always)]
     pub fn is_no_effect(&self) -> bool {
-        **self == WDOG_RESTART_A::NO_EFFECT
+        *self == WDOG_RESTART_A::NO_EFFECT
     }
     #[doc = "Checks if the value of the field is `RESTART`"]
     #[inline(always)]
     pub fn is_restart(&self) -> bool {
-        **self == WDOG_RESTART_A::RESTART
-    }
-}
-impl core::ops::Deref for WDOG_RESTART_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == WDOG_RESTART_A::RESTART
     }
 }
 #[doc = "Field `WDOG_RESTART` writer - Watchdog Restart"]
-pub struct WDOG_RESTART_W<'a> {
-    w: &'a mut W,
-}
+pub type WDOG_RESTART_W<'a> = crate::BitWriter1S<'a, u32, WDOG_CTRL_SPEC, WDOG_RESTART_A, 0>;
 impl<'a> WDOG_RESTART_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: WDOG_RESTART_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "`0`"]
     #[inline(always)]
     pub fn no_effect(self) -> &'a mut W {
@@ -113,22 +85,6 @@ impl<'a> WDOG_RESTART_W<'a> {
     pub fn restart(self) -> &'a mut W {
         self.variant(WDOG_RESTART_A::RESTART)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
-        self.w
-    }
 }
 impl R {
     #[doc = "Bit 0 - Watchdog Restart"]
@@ -141,12 +97,12 @@ impl W {
     #[doc = "Bits 1:12 - Watchdog Key Field"]
     #[inline(always)]
     pub fn wdog_key_field(&mut self) -> WDOG_KEY_FIELD_W {
-        WDOG_KEY_FIELD_W { w: self }
+        WDOG_KEY_FIELD_W::new(self)
     }
     #[doc = "Bit 0 - Watchdog Restart"]
     #[inline(always)]
     pub fn wdog_restart(&mut self) -> WDOG_RESTART_W {
-        WDOG_RESTART_W { w: self }
+        WDOG_RESTART_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
