@@ -35,32 +35,9 @@ impl From<crate::W<TP_CTRL0_SPEC>> for W {
     }
 }
 #[doc = "Field `ADC_FIRST_DLY` reader - ADC First Convert Delay Time (T_FCDT) Setting"]
-pub struct ADC_FIRST_DLY_R(crate::FieldReader<u8>);
-impl ADC_FIRST_DLY_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        ADC_FIRST_DLY_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for ADC_FIRST_DLY_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type ADC_FIRST_DLY_R = crate::FieldReader<u8, u8>;
 #[doc = "Field `ADC_FIRST_DLY` writer - ADC First Convert Delay Time (T_FCDT) Setting"]
-pub struct ADC_FIRST_DLY_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> ADC_FIRST_DLY_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0xff << 24)) | ((value as u32 & 0xff) << 24);
-        self.w
-    }
-}
+pub type ADC_FIRST_DLY_W<'a> = crate::FieldWriter<'a, u32, TP_CTRL0_SPEC, u8, u8, 8, 24>;
 #[doc = "ADC First Convert Delay Mode Select\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum ADC_FIRST_DLY_MODE_A {
@@ -76,13 +53,9 @@ impl From<ADC_FIRST_DLY_MODE_A> for bool {
     }
 }
 #[doc = "Field `ADC_FIRST_DLY_MODE` reader - ADC First Convert Delay Mode Select"]
-pub struct ADC_FIRST_DLY_MODE_R(crate::FieldReader<bool>);
+pub type ADC_FIRST_DLY_MODE_R = crate::BitReader<ADC_FIRST_DLY_MODE_A>;
 impl ADC_FIRST_DLY_MODE_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: bool) -> Self {
-        ADC_FIRST_DLY_MODE_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ADC_FIRST_DLY_MODE_A {
         match self.bits {
@@ -93,31 +66,18 @@ impl ADC_FIRST_DLY_MODE_R {
     #[doc = "Checks if the value of the field is `C16`"]
     #[inline(always)]
     pub fn is_c16(&self) -> bool {
-        **self == ADC_FIRST_DLY_MODE_A::C16
+        *self == ADC_FIRST_DLY_MODE_A::C16
     }
     #[doc = "Checks if the value of the field is `C16_256`"]
     #[inline(always)]
     pub fn is_c16_256(&self) -> bool {
-        **self == ADC_FIRST_DLY_MODE_A::C16_256
-    }
-}
-impl core::ops::Deref for ADC_FIRST_DLY_MODE_R {
-    type Target = crate::FieldReader<bool>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == ADC_FIRST_DLY_MODE_A::C16_256
     }
 }
 #[doc = "Field `ADC_FIRST_DLY_MODE` writer - ADC First Convert Delay Mode Select"]
-pub struct ADC_FIRST_DLY_MODE_W<'a> {
-    w: &'a mut W,
-}
+pub type ADC_FIRST_DLY_MODE_W<'a> =
+    crate::BitWriter<'a, u32, TP_CTRL0_SPEC, ADC_FIRST_DLY_MODE_A, 23>;
 impl<'a> ADC_FIRST_DLY_MODE_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ADC_FIRST_DLY_MODE_A) -> &'a mut W {
-        self.bit(variant.into())
-    }
     #[doc = "CLK_IN / 16"]
     #[inline(always)]
     pub fn c16(self) -> &'a mut W {
@@ -128,22 +88,6 @@ impl<'a> ADC_FIRST_DLY_MODE_W<'a> {
     pub fn c16_256(self) -> &'a mut W {
         self.variant(ADC_FIRST_DLY_MODE_A::C16_256)
     }
-    #[doc = r"Sets the field bit"]
-    #[inline(always)]
-    pub fn set_bit(self) -> &'a mut W {
-        self.bit(true)
-    }
-    #[doc = r"Clears the field bit"]
-    #[inline(always)]
-    pub fn clear_bit(self) -> &'a mut W {
-        self.bit(false)
-    }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(1 << 23)) | ((value as u32 & 1) << 23);
-        self.w
-    }
 }
 #[doc = "ADC Clock Divider (CLK_IN)\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -165,13 +109,9 @@ impl From<ADC_CLK_DIVIDER_A> for u8 {
     }
 }
 #[doc = "Field `ADC_CLK_DIVIDER` reader - ADC Clock Divider (CLK_IN)"]
-pub struct ADC_CLK_DIVIDER_R(crate::FieldReader<u8>);
+pub type ADC_CLK_DIVIDER_R = crate::FieldReader<u8, ADC_CLK_DIVIDER_A>;
 impl ADC_CLK_DIVIDER_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        ADC_CLK_DIVIDER_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ADC_CLK_DIVIDER_A {
         match self.bits {
@@ -185,41 +125,28 @@ impl ADC_CLK_DIVIDER_R {
     #[doc = "Checks if the value of the field is `C2`"]
     #[inline(always)]
     pub fn is_c2(&self) -> bool {
-        **self == ADC_CLK_DIVIDER_A::C2
+        *self == ADC_CLK_DIVIDER_A::C2
     }
     #[doc = "Checks if the value of the field is `C3`"]
     #[inline(always)]
     pub fn is_c3(&self) -> bool {
-        **self == ADC_CLK_DIVIDER_A::C3
+        *self == ADC_CLK_DIVIDER_A::C3
     }
     #[doc = "Checks if the value of the field is `C6`"]
     #[inline(always)]
     pub fn is_c6(&self) -> bool {
-        **self == ADC_CLK_DIVIDER_A::C6
+        *self == ADC_CLK_DIVIDER_A::C6
     }
     #[doc = "Checks if the value of the field is `C1`"]
     #[inline(always)]
     pub fn is_c1(&self) -> bool {
-        **self == ADC_CLK_DIVIDER_A::C1
-    }
-}
-impl core::ops::Deref for ADC_CLK_DIVIDER_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == ADC_CLK_DIVIDER_A::C1
     }
 }
 #[doc = "Field `ADC_CLK_DIVIDER` writer - ADC Clock Divider (CLK_IN)"]
-pub struct ADC_CLK_DIVIDER_W<'a> {
-    w: &'a mut W,
-}
+pub type ADC_CLK_DIVIDER_W<'a> =
+    crate::FieldWriterSafe<'a, u32, TP_CTRL0_SPEC, u8, ADC_CLK_DIVIDER_A, 2, 20>;
 impl<'a> ADC_CLK_DIVIDER_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: ADC_CLK_DIVIDER_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
     #[doc = "CLK / 2"]
     #[inline(always)]
     pub fn c2(self) -> &'a mut W {
@@ -240,12 +167,6 @@ impl<'a> ADC_CLK_DIVIDER_W<'a> {
     pub fn c1(self) -> &'a mut W {
         self.variant(ADC_CLK_DIVIDER_A::C1)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(3 << 20)) | ((value as u32 & 3) << 20);
-        self.w
-    }
 }
 #[doc = "ADC Sample Frequency Divider\n\nValue on reset: 0"]
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -291,13 +212,9 @@ impl From<FS_DIV_A> for u8 {
     }
 }
 #[doc = "Field `FS_DIV` reader - ADC Sample Frequency Divider"]
-pub struct FS_DIV_R(crate::FieldReader<u8>);
+pub type FS_DIV_R = crate::FieldReader<u8, FS_DIV_A>;
 impl FS_DIV_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        FS_DIV_R(crate::FieldReader::new(bits))
-    }
-    #[doc = r"Get enumerated values variant"]
+    #[doc = "Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> FS_DIV_A {
         match self.bits {
@@ -323,101 +240,87 @@ impl FS_DIV_R {
     #[doc = "Checks if the value of the field is `C2P0`"]
     #[inline(always)]
     pub fn is_c2p0(&self) -> bool {
-        **self == FS_DIV_A::C2P0
+        *self == FS_DIV_A::C2P0
     }
     #[doc = "Checks if the value of the field is `C2P1`"]
     #[inline(always)]
     pub fn is_c2p1(&self) -> bool {
-        **self == FS_DIV_A::C2P1
+        *self == FS_DIV_A::C2P1
     }
     #[doc = "Checks if the value of the field is `C2P2`"]
     #[inline(always)]
     pub fn is_c2p2(&self) -> bool {
-        **self == FS_DIV_A::C2P2
+        *self == FS_DIV_A::C2P2
     }
     #[doc = "Checks if the value of the field is `C2P3`"]
     #[inline(always)]
     pub fn is_c2p3(&self) -> bool {
-        **self == FS_DIV_A::C2P3
+        *self == FS_DIV_A::C2P3
     }
     #[doc = "Checks if the value of the field is `C2P4`"]
     #[inline(always)]
     pub fn is_c2p4(&self) -> bool {
-        **self == FS_DIV_A::C2P4
+        *self == FS_DIV_A::C2P4
     }
     #[doc = "Checks if the value of the field is `C2P5`"]
     #[inline(always)]
     pub fn is_c2p5(&self) -> bool {
-        **self == FS_DIV_A::C2P5
+        *self == FS_DIV_A::C2P5
     }
     #[doc = "Checks if the value of the field is `C2P6`"]
     #[inline(always)]
     pub fn is_c2p6(&self) -> bool {
-        **self == FS_DIV_A::C2P6
+        *self == FS_DIV_A::C2P6
     }
     #[doc = "Checks if the value of the field is `C2P7`"]
     #[inline(always)]
     pub fn is_c2p7(&self) -> bool {
-        **self == FS_DIV_A::C2P7
+        *self == FS_DIV_A::C2P7
     }
     #[doc = "Checks if the value of the field is `C2P8`"]
     #[inline(always)]
     pub fn is_c2p8(&self) -> bool {
-        **self == FS_DIV_A::C2P8
+        *self == FS_DIV_A::C2P8
     }
     #[doc = "Checks if the value of the field is `C2P9`"]
     #[inline(always)]
     pub fn is_c2p9(&self) -> bool {
-        **self == FS_DIV_A::C2P9
+        *self == FS_DIV_A::C2P9
     }
     #[doc = "Checks if the value of the field is `C2P10`"]
     #[inline(always)]
     pub fn is_c2p10(&self) -> bool {
-        **self == FS_DIV_A::C2P10
+        *self == FS_DIV_A::C2P10
     }
     #[doc = "Checks if the value of the field is `C2P11`"]
     #[inline(always)]
     pub fn is_c2p11(&self) -> bool {
-        **self == FS_DIV_A::C2P11
+        *self == FS_DIV_A::C2P11
     }
     #[doc = "Checks if the value of the field is `C2P12`"]
     #[inline(always)]
     pub fn is_c2p12(&self) -> bool {
-        **self == FS_DIV_A::C2P12
+        *self == FS_DIV_A::C2P12
     }
     #[doc = "Checks if the value of the field is `C2P13`"]
     #[inline(always)]
     pub fn is_c2p13(&self) -> bool {
-        **self == FS_DIV_A::C2P13
+        *self == FS_DIV_A::C2P13
     }
     #[doc = "Checks if the value of the field is `C2P14`"]
     #[inline(always)]
     pub fn is_c2p14(&self) -> bool {
-        **self == FS_DIV_A::C2P14
+        *self == FS_DIV_A::C2P14
     }
     #[doc = "Checks if the value of the field is `C2P15`"]
     #[inline(always)]
     pub fn is_c2p15(&self) -> bool {
-        **self == FS_DIV_A::C2P15
-    }
-}
-impl core::ops::Deref for FS_DIV_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
+        *self == FS_DIV_A::C2P15
     }
 }
 #[doc = "Field `FS_DIV` writer - ADC Sample Frequency Divider"]
-pub struct FS_DIV_W<'a> {
-    w: &'a mut W,
-}
+pub type FS_DIV_W<'a> = crate::FieldWriterSafe<'a, u32, TP_CTRL0_SPEC, u8, FS_DIV_A, 4, 16>;
 impl<'a> FS_DIV_W<'a> {
-    #[doc = r"Writes `variant` to the field"]
-    #[inline(always)]
-    pub fn variant(self, variant: FS_DIV_A) -> &'a mut W {
-        self.bits(variant.into())
-    }
     #[doc = "CLK_IN / 2 ^ (20 - 0)"]
     #[inline(always)]
     pub fn c2p0(self) -> &'a mut W {
@@ -498,40 +401,11 @@ impl<'a> FS_DIV_W<'a> {
     pub fn c2p15(self) -> &'a mut W {
         self.variant(FS_DIV_A::C2P15)
     }
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 16)) | ((value as u32 & 0x0f) << 16);
-        self.w
-    }
 }
 #[doc = "Field `TACQ` reader - Touch panel ADC acquire time"]
-pub struct TACQ_R(crate::FieldReader<u16>);
-impl TACQ_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        TACQ_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TACQ_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TACQ_R = crate::FieldReader<u16, u16>;
 #[doc = "Field `TACQ` writer - Touch panel ADC acquire time"]
-pub struct TACQ_W<'a> {
-    w: &'a mut W,
-}
-impl<'a> TACQ_W<'a> {
-    #[doc = r"Writes raw bits to the field"]
-    #[inline(always)]
-    pub unsafe fn bits(self, value: u16) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0xffff) | (value as u32 & 0xffff);
-        self.w
-    }
-}
+pub type TACQ_W<'a> = crate::FieldWriter<'a, u32, TP_CTRL0_SPEC, u16, u16, 16, 0>;
 impl R {
     #[doc = "Bits 24:31 - ADC First Convert Delay Time (T_FCDT) Setting"]
     #[inline(always)]
@@ -563,27 +437,27 @@ impl W {
     #[doc = "Bits 24:31 - ADC First Convert Delay Time (T_FCDT) Setting"]
     #[inline(always)]
     pub fn adc_first_dly(&mut self) -> ADC_FIRST_DLY_W {
-        ADC_FIRST_DLY_W { w: self }
+        ADC_FIRST_DLY_W::new(self)
     }
     #[doc = "Bit 23 - ADC First Convert Delay Mode Select"]
     #[inline(always)]
     pub fn adc_first_dly_mode(&mut self) -> ADC_FIRST_DLY_MODE_W {
-        ADC_FIRST_DLY_MODE_W { w: self }
+        ADC_FIRST_DLY_MODE_W::new(self)
     }
     #[doc = "Bits 20:21 - ADC Clock Divider (CLK_IN)"]
     #[inline(always)]
     pub fn adc_clk_divider(&mut self) -> ADC_CLK_DIVIDER_W {
-        ADC_CLK_DIVIDER_W { w: self }
+        ADC_CLK_DIVIDER_W::new(self)
     }
     #[doc = "Bits 16:19 - ADC Sample Frequency Divider"]
     #[inline(always)]
     pub fn fs_div(&mut self) -> FS_DIV_W {
-        FS_DIV_W { w: self }
+        FS_DIV_W::new(self)
     }
     #[doc = "Bits 0:15 - Touch panel ADC acquire time"]
     #[inline(always)]
     pub fn tacq(&mut self) -> TACQ_W {
-        TACQ_W { w: self }
+        TACQ_W::new(self)
     }
     #[doc = "Writes raw bits to the register."]
     #[inline(always)]
