@@ -14,20 +14,7 @@ impl From<crate::R<TWI_DRV_RECV_FIFO_ACC_SPEC>> for R {
     }
 }
 #[doc = "Field `recv_data_fifo` reader - "]
-pub struct RECV_DATA_FIFO_R(crate::FieldReader<u8>);
-impl RECV_DATA_FIFO_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        RECV_DATA_FIFO_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RECV_DATA_FIFO_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RECV_DATA_FIFO_R = crate::FieldReader<u8, u8>;
 impl R {
     #[doc = "Bits 0:7"]
     #[inline(always)]
