@@ -14,20 +14,7 @@ impl From<crate::R<DBG_DLL_SPEC>> for R {
     }
 }
 #[doc = "Field `DBG_DLL` reader - "]
-pub struct DBG_DLL_R(crate::FieldReader<u8>);
-impl DBG_DLL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        DBG_DLL_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for DBG_DLL_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type DBG_DLL_R = crate::FieldReader<u8, u8>;
 impl R {
     #[doc = "Bits 0:7"]
     #[inline(always)]
