@@ -14,20 +14,7 @@ impl From<crate::R<RBR_SPEC>> for R {
     }
 }
 #[doc = "Field `rbr` reader - "]
-pub struct RBR_R(crate::FieldReader<u8>);
-impl RBR_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u8) -> Self {
-        RBR_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RBR_R {
-    type Target = crate::FieldReader<u8>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RBR_R = crate::FieldReader<u8, u8>;
 impl R {
     #[doc = "Bits 0:7"]
     #[inline(always)]
