@@ -14,20 +14,7 @@ impl From<crate::R<RFL_SPEC>> for R {
     }
 }
 #[doc = "Field `rfl` reader - RX FIFO Level"]
-pub struct RFL_R(crate::FieldReader<u16>);
-impl RFL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        RFL_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for RFL_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type RFL_R = crate::FieldReader<u16, u16>;
 impl R {
     #[doc = "Bits 0:8 - RX FIFO Level"]
     #[inline(always)]
