@@ -14,20 +14,7 @@ impl From<crate::R<TFL_SPEC>> for R {
     }
 }
 #[doc = "Field `tfl` reader - TX FIFO Level"]
-pub struct TFL_R(crate::FieldReader<u16>);
-impl TFL_R {
-    #[inline(always)]
-    pub(crate) fn new(bits: u16) -> Self {
-        TFL_R(crate::FieldReader::new(bits))
-    }
-}
-impl core::ops::Deref for TFL_R {
-    type Target = crate::FieldReader<u16>;
-    #[inline(always)]
-    fn deref(&self) -> &Self::Target {
-        &self.0
-    }
-}
+pub type TFL_R = crate::FieldReader<u16, u16>;
 impl R {
     #[doc = "Bits 0:8 - TX FIFO Level"]
     #[inline(always)]
